@@ -2,13 +2,13 @@ import { css } from '@emotion/css';
 import React from 'react';
 import { useLocation } from 'react-router-dom';
 
-import { locationUtil } from '@grafana/data';
+import { GrafanaTheme2, locationUtil, textUtil } from '@grafana/data';
 import { useStyles2 } from '@grafana/ui';
 
 export function SignInLink() {
   const location = useLocation();
   const styles = useStyles2(getStyles);
-  const loginUrl = locationUtil.getUrlForPartial(location, { forceLogin: 'true' });
+  const loginUrl = textUtil.sanitizeUrl(locationUtil.getUrlForPartial(location, { forceLogin: 'true' }));
 
   return (
     <a className={styles.link} href={loginUrl} target="_self">
@@ -17,9 +17,10 @@ export function SignInLink() {
   );
 }
 
-const getStyles = () => {
+const getStyles = (theme: GrafanaTheme2) => {
   return {
     link: css({
+      paddingRight: theme.spacing(1),
       whiteSpace: 'nowrap',
       '&:hover': {
         textDecoration: 'underline',
