@@ -3,7 +3,8 @@ import { css } from '@emotion/css';
 import React from 'react';
 
 // Components
-import { Alert, HorizontalGroup, LinkButton } from '@grafana/ui';
+import { GrafanaTheme2 } from '@grafana/data';
+import { Alert, HorizontalGroup, LinkButton, useStyles2 } from '@grafana/ui';
 import { Branding } from 'app/core/components/Branding/Branding';
 import config from 'app/core/config';
 import { t } from 'app/core/internationalization';
@@ -16,17 +17,10 @@ import { LoginLayout, InnerBox } from './LoginLayout';
 import { LoginServiceButtons } from './LoginServiceButtons';
 import { UserSignup } from './UserSignup';
 
-const forgottenPasswordStyles = css`
-  padding: 0;
-  margin-top: 4px;
-`;
-
-const alertStyles = css({
-  width: '100%',
-});
-
 export const LoginPage = () => {
+  const styles = useStyles2(getStyles);
   document.title = Branding.AppTitle;
+
   return (
     <LoginCtrl>
       {({
@@ -46,7 +40,7 @@ export const LoginPage = () => {
           {!isChangingPassword && (
             <InnerBox>
               {loginErrorMessage && (
-                <Alert className={alertStyles} severity="error" title={t('login.error.title', 'Login failed')}>
+                <Alert className={styles.alert} severity="error" title={t('login.error.title', 'Login failed')}>
                   {loginErrorMessage}
                 </Alert>
               )}
@@ -55,7 +49,7 @@ export const LoginPage = () => {
                 <LoginForm onSubmit={login} loginHint={loginHint} passwordHint={passwordHint} isLoggingIn={isLoggingIn}>
                   <HorizontalGroup justify="flex-end">
                     <LinkButton
-                      className={forgottenPasswordStyles}
+                      className={styles.forgottenPassword}
                       fill="text"
                       href={`${config.appSubUrl}/user/password/send-reset-email`}
                     >
@@ -83,3 +77,16 @@ export const LoginPage = () => {
     </LoginCtrl>
   );
 };
+
+const getStyles = (theme: GrafanaTheme2) => {
+  return {
+    forgottenPassword: css({
+      padding: 0,
+      marginTop: theme.spacing(0.5),
+    }),
+
+    alert: css({
+      width: '100%',
+    }),
+  };
+};
