@@ -1,10 +1,10 @@
 import { css } from '@emotion/css';
-import React, { FC } from 'react';
+import React from 'react';
 
 import { LinkButton, VerticalGroup } from '@grafana/ui';
 import { getConfig } from 'app/core/config';
 
-export const UserSignup: FC<{}> = () => {
+export const UserSignup = () => {
   const href = getConfig().verifyEmailEnabled ? `${getConfig().appSubUrl}/verify` : `${getConfig().appSubUrl}/signup`;
   const paddingTop = css({ paddingTop: '16px' });
 
@@ -12,10 +12,10 @@ export const UserSignup: FC<{}> = () => {
     <VerticalGroup>
       <div className={paddingTop}>New to Grafana?</div>
       <LinkButton
-        className={css`
-          width: 100%;
-          justify-content: center;
-        `}
+        className={css({
+          width: '100%',
+          justifyContent: 'center',
+        })}
         href={href}
         variant="secondary"
         fill="outline"
