@@ -3,13 +3,13 @@ import { Global } from '@emotion/react';
 import Slider from 'rc-slider';
 import React, { useCallback, useEffect, useRef, useState } from 'react';
 
-import { FieldConfigEditorProps, GrafanaTheme2, SliderFieldConfigSettings } from '@grafana/data';
+import { StandardEditorProps, GrafanaTheme2, SliderFieldConfigSettings } from '@grafana/data';
 import { useTheme2 } from '@grafana/ui';
 import { getStyles } from '@grafana/ui/src/components/Slider/styles';
 
 import { NumberInput } from './NumberInput';
 
-type Props = FieldConfigEditorProps<number, SliderFieldConfigSettings>;
+type Props = StandardEditorProps<number, SliderFieldConfigSettings>;
 
 export const SliderValueEditor = ({ value, onChange, item }: Props) => {
   // Input reference
@@ -130,13 +130,13 @@ function getTextWidth(text: string, font: string): number | null {
 
 const getStylesSlider = (theme: GrafanaTheme2, width: number) => {
   return {
-    numberInputWrapper: css`
-      margin-left: ${theme.spacing(3)};
-      max-height: 32px;
-      max-width: ${width}px;
-      min-width: ${width}px;
-      overflow: visible;
-      width: 100%;
-    `,
+    numberInputWrapper: css({
+      marginLeft: theme.spacing(3),
+      maxHeight: '32px',
+      maxWidth: width,
+      minWidth: width,
+      overflow: 'visible',
+      width: '100%',
+    }),
   };
 };
