@@ -11,11 +11,16 @@ import { IntervalInput } from '../IntervalInput/IntervalInput';
 
 import { TagMappingInput } from './TagMappingInput';
 
+export interface TraceToLogsTag {
+  key: string;
+  value?: string;
+}
+
 // @deprecated use getTraceToLogsOptions to get the v2 version of this config from jsonData
 export interface TraceToLogsOptions {
   datasourceUid?: string;
   tags?: string[];
-  mappedTags?: Array<{ key: string; value?: string }>;
+  mappedTags?: TraceToLogsTag[];
   mapTagNamesEnabled?: boolean;
   spanStartTimeShift?: string;
   spanEndTimeShift?: string;
@@ -26,7 +31,7 @@ export interface TraceToLogsOptions {
 
 export interface TraceToLogsOptionsV2 {
   datasourceUid?: string;
-  tags?: Array<{ key: string; value?: string }>;
+  tags?: TraceToLogsTag[];
   spanStartTimeShift?: string;
   spanEndTimeShift?: string;
   filterByTraceID?: boolean;
@@ -128,7 +133,7 @@ export function TraceToLogsSettings({ options, onOptionsChange }: Props) {
       <InlineFieldRow>
         <IntervalInput
           label={getTimeShiftLabel('start')}
-          tooltip={getTimeShiftTooltip('start')}
+          tooltip={getTimeShiftTooltip('start', '0')}
           value={traceToLogs.spanStartTimeShift || ''}
           onChange={(val) => {
             updateTracesToLogs({ spanStartTimeShift: val });
@@ -140,7 +145,7 @@ export function TraceToLogsSettings({ options, onOptionsChange }: Props) {
       <InlineFieldRow>
         <IntervalInput
           label={getTimeShiftLabel('end')}
-          tooltip={getTimeShiftTooltip('end')}
+          tooltip={getTimeShiftTooltip('end', '0')}
           value={traceToLogs.spanEndTimeShift || ''}
           onChange={(val) => {
             updateTracesToLogs({ spanEndTimeShift: val });
@@ -151,7 +156,7 @@ export function TraceToLogsSettings({ options, onOptionsChange }: Props) {
 
       <InlineFieldRow>
         <InlineField
-          tooltip="Tags that will be used in the query. Default tags: 'cluster', 'hostname', 'namespace', 'pod'"
+          tooltip="Tags that will be used in the query. Default tags: 'cluster', 'hostname', 'namespace', 'pod', 'service.name', 'service.namespace'"
           label="Tags"
           labelWidth={26}
         >
@@ -241,20 +246,23 @@ export const getTimeShiftLabel = (type: 'start' | 'end') => {
   return `Span ${type} time shift`;
 };
 
-export const getTimeShiftTooltip = (type: 'start' | 'end') => {
-  return `Shifts the ${type} time of the span. Default: 0 (Time units can be used here, for example: 5s, -1m, 3h)`;
+export const getTimeShiftTooltip = (type: 'start' | 'end', defaultVal: string) => {
+  return `Shifts the ${type} time of the span. Default: ${defaultVal} (Time units can be used here, for example: 5s, -1m, 3h)`;
 };
 
 export const invalidTimeShiftError = 'Invalid time shift. See tooltip for examples.';
 
 export const TraceToLogsSection = ({ options, onOptionsChange }: DataSourcePluginOptionsEditorProps) => {
+  let suffix = options.type;
+  suffix += options.type === 'tempo' ? '/configure-tempo-data-source/#trace-to-logs' : '/#trace-to-logs';
+
   return (
     <ConfigSection
       title="Trace to logs"
       description={
         <ConfigDescriptionLink
           description="Navigate from a trace span to the selected data source's logs."
-          suffix={`${options.type}/#trace-to-logs`}
+          suffix={suffix}
           feature="trace to logs"
         />
       }
