@@ -1,7 +1,9 @@
 import { of } from 'rxjs';
 
+import { Preferences as UserPreferencesDTO } from '@grafana/schema/src/raw/preferences/x/preferences_types.gen';
+
 import { DatasourceSrv } from '../../features/plugins/datasource_srv';
-import { RichHistoryQuery, UserPreferencesDTO } from '../../types';
+import { RichHistoryQuery } from '../../types';
 import { SortOrder } from '../utils/richHistoryTypes';
 
 import RichHistoryRemoteStorage, { RichHistoryRemoteStorageDTO } from './RichHistoryRemoteStorage';
@@ -53,7 +55,12 @@ describe('RichHistoryRemoteStorage', () => {
     storage = new RichHistoryRemoteStorage();
   });
 
-  const setup = (): { richHistoryQuery: RichHistoryQuery; dto: RichHistoryRemoteStorageDTO } => {
+  const setup = (): {
+    richHistoryQuery: RichHistoryQuery;
+    richHistoryStarredQuery: RichHistoryQuery;
+    dto: RichHistoryRemoteStorageDTO;
+    dtoStarred: RichHistoryRemoteStorageDTO;
+  } => {
     const richHistoryQuery: RichHistoryQuery = {
       id: '123',
       createdAt: 200 * 1000,
@@ -64,6 +71,11 @@ describe('RichHistoryRemoteStorage', () => {
       queries: [{ refId: 'foo' }],
     };
 
+    const richHistoryStarredQuery: RichHistoryQuery = {
+      ...richHistoryQuery,
+      starred: false,
+    };
+
     const dto = {
       uid: richHistoryQuery.id,
       createdAt: richHistoryQuery.createdAt / 1000,
@@ -73,9 +85,16 @@ describe('RichHistoryRemoteStorage', () => {
       queries: richHistoryQuery.queries,
     };
 
+    const dtoStarred = {
+      ...dto,
+      starred: richHistoryStarredQuery.starred,
+    };
+
     return {
       richHistoryQuery,
+      richHistoryStarredQuery,
       dto,
+      dtoStarred,
     };
   };
 
@@ -95,7 +114,7 @@ describe('RichHistoryRemoteStorage', () => {
     const search = 'foo';
     const datasourceFilters = ['name-of-ds1', 'name-of-ds2'];
     const sortOrder = SortOrder.Descending;
-    const starred = true;
+    const starred = false;
     const from = 100;
     const to = 200;
     const expectedLimit = 100;
@@ -112,13 +131,55 @@ describe('RichHistoryRemoteStorage', () => {
 
     expect(fetchMock).toBeCalledWith({
       method: 'GET',
-      url: `/api/query-history?datasourceUid=ds1&datasourceUid=ds2&searchString=${search}&sort=time-desc&to=now-${from}d&from=now-${to}d&limit=${expectedLimit}&page=${expectedPage}&onlyStarred=${starred}`,
+      url: `/api/query-history?datasourceUid=ds1&datasourceUid=ds2&searchString=${search}&sort=time-desc&to=now-${from}d&from=now-${to}d&limit=${expectedLimit}&page=${expectedPage}`,
       requestId: 'query-history-get-all',
     });
     expect(richHistory).toMatchObject([richHistoryQuery]);
     expect(total).toBe(1);
   });
 
+  it('returns list of all starred query history items', async () => {
+    const { richHistoryStarredQuery, dtoStarred } = setup();
+    const returnedDTOs: RichHistoryRemoteStorageDTO[] = [dtoStarred];
+
+    fetchMock.mockReturnValue(
+      of({
+        data: {
+          result: {
+            queryHistory: returnedDTOs,
+            totalCount: returnedDTOs.length,
+          },
+        },
+      })
+    );
+
+    const search = 'foo';
+    const datasourceFilters = ['name-of-ds1', 'name-of-ds2'];
+    const sortOrder = SortOrder.Descending;
+    const starred = true;
+    const from = 100;
+    const to = 200;
+    const expectedLimit = 100;
+    const expectedPage = 1;
+
+    const { richHistory, total } = await storage.getRichHistory({
+      search,
+      datasourceFilters,
+      sortOrder,
+      starred,
+      from,
+      to,
+    });
+
+    expect(fetchMock).toBeCalledWith({
+      method: 'GET',
+      url: `/api/query-history?datasourceUid=ds1&datasourceUid=ds2&searchString=${search}&sort=time-desc&limit=${expectedLimit}&page=${expectedPage}&onlyStarred=${starred}`,
+      requestId: 'query-history-get-starred',
+    });
+    expect(richHistory).toMatchObject([richHistoryStarredQuery]);
+    expect(total).toBe(1);
+  });
+
   it('read starred home tab preferences', async () => {
     preferencesServiceMock.load.mockResolvedValue({
       queryHistory: {
@@ -171,18 +232,6 @@ describe('RichHistoryRemoteStorage', () => {
     } as Partial<UserPreferencesDTO>);
   });
 
-  it('migrates provided rich history items', async () => {
-    const { richHistoryQuery, dto } = setup();
-    fetchMock.mockReturnValue(of({}));
-    await storage.migrate([richHistoryQuery]);
-    expect(fetchMock).toBeCalledWith({
-      url: '/api/query-history/migrate',
-      method: 'POST',
-      data: { queries: [dto] },
-      showSuccessAlert: false,
-    });
-  });
-
   it('stars query history items', async () => {
     const { richHistoryQuery, dto } = setup();
     postMock.mockResolvedValue({
