@@ -8,7 +8,7 @@ export function useMediaQueryChange({
   onChange: (e: MediaQueryListEvent) => void;
 }) {
   useEffect(() => {
-    const mediaQuery = window.matchMedia(`(max-width: ${breakpoint}px)`);
+    const mediaQuery = window.matchMedia(`(min-width: ${breakpoint}px)`);
     const onMediaQueryChange = (e: MediaQueryListEvent) => onChange(e);
     mediaQuery.addEventListener('change', onMediaQueryChange);
 
