@@ -1,16 +1,17 @@
 import 'whatwg-fetch'; // fetch polyfill needed for PhantomJs rendering
-import { Observable, of } from 'rxjs';
+import { Observable, of, lastValueFrom } from 'rxjs';
+import { fromFetch } from 'rxjs/fetch';
 import { delay } from 'rxjs/operators';
 
 import { AppEvents, DataQueryErrorType, EventBusExtended } from '@grafana/data';
-import { BackendSrvRequest, FetchError } from '@grafana/runtime';
+import { BackendSrvRequest, FetchError, config, FetchResponse } from '@grafana/runtime';
 
 import { TokenRevokedModal } from '../../features/users/TokenRevokedModal';
 import { ShowModalReactEvent } from '../../types/events';
-import { BackendSrv } from '../services/backend_srv';
+import { BackendSrv, BackendSrvDependencies } from '../services/backend_srv';
 import { ContextSrv, User } from '../services/context_srv';
 
-const getTestContext = (overides?: object) => {
+const getTestContext = (overides?: object, mockFromFetch = true) => {
   const defaults = {
     data: { test: 'hello world' },
     ok: true,
@@ -21,6 +22,7 @@ const getTestContext = (overides?: object) => {
     redirected: false,
     type: 'basic',
     url: 'http://localhost:3000/api/some-mock',
+    headers: new Map(),
   };
   const props = { ...defaults, ...overides };
   const textMock = jest.fn().mockResolvedValue(JSON.stringify(props.data));
@@ -29,6 +31,7 @@ const getTestContext = (overides?: object) => {
       ok: props.ok,
       status: props.status,
       statusText: props.statusText,
+      headers: props.headers,
       text: textMock,
       redirected: false,
       type: 'basic',
@@ -53,7 +56,7 @@ const getTestContext = (overides?: object) => {
   const parseRequestOptionsMock = jest.fn().mockImplementation((options) => options);
 
   const backendSrv = new BackendSrv({
-    fromFetch: fromFetchMock,
+    fromFetch: mockFromFetch ? fromFetchMock : fromFetch,
     appEvents: appEventsMock,
     contextSrv: contextSrvMock,
     logout: logoutMock,
@@ -61,14 +64,14 @@ const getTestContext = (overides?: object) => {
 
   backendSrv['parseRequestOptions'] = parseRequestOptionsMock;
 
-  const expectCallChain = () => {
-    expect(fromFetchMock).toHaveBeenCalledTimes(1);
+  const expectCallChain = (calls = 1) => {
+    expect(fromFetchMock).toHaveBeenCalledTimes(calls);
   };
 
-  const expectRequestCallChain = (options: any) => {
+  const expectRequestCallChain = (options: unknown, calls = 1) => {
     expect(parseRequestOptionsMock).toHaveBeenCalledTimes(1);
     expect(parseRequestOptionsMock).toHaveBeenCalledWith(options);
-    expectCallChain();
+    expectCallChain(calls);
   };
 
   return {
@@ -109,7 +112,7 @@ describe('backendSrv', () => {
               orgId: orgId,
             },
           },
-        } as any);
+        } as BackendSrvDependencies);
 
         if (noBackendCache) {
           await srv.withNoBackendCache(async () => {
@@ -123,15 +126,18 @@ describe('backendSrv', () => {
   });
 
   describe('request', () => {
+    const testMessage = 'Datasource updated';
+    const errorMessage = 'UnAuthorized';
+
     describe('when making a successful call and conditions for showSuccessAlert are not favorable', () => {
       it('then it should return correct result and not emit anything', async () => {
         const { backendSrv, appEventsMock, expectRequestCallChain } = getTestContext({
-          data: { message: 'A message' },
+          data: { message: testMessage },
         });
         const url = '/api/dashboard/';
         const result = await backendSrv.request({ url, method: 'DELETE', showSuccessAlert: false });
 
-        expect(result).toEqual({ message: 'A message' });
+        expect(result).toEqual({ message: testMessage });
         expect(appEventsMock.emit).not.toHaveBeenCalled();
         expectRequestCallChain({ url, method: 'DELETE', showSuccessAlert: false });
       });
@@ -140,51 +146,84 @@ describe('backendSrv', () => {
     describe('when making a successful call and conditions for showSuccessAlert are favorable', () => {
       it('then it should emit correct message', async () => {
         const { backendSrv, appEventsMock, expectRequestCallChain } = getTestContext({
-          data: { message: 'A message' },
+          data: { message: testMessage },
         });
         const url = '/api/dashboard/';
         const result = await backendSrv.request({ url, method: 'DELETE', showSuccessAlert: true });
 
-        expect(result).toEqual({ message: 'A message' });
+        expect(result).toEqual({ message: testMessage });
         expect(appEventsMock.emit).toHaveBeenCalledTimes(1);
-        expect(appEventsMock.emit).toHaveBeenCalledWith(AppEvents.alertSuccess, ['A message']);
+        expect(appEventsMock.emit).toHaveBeenCalledWith(AppEvents.alertSuccess, [testMessage]);
         expectRequestCallChain({ url, method: 'DELETE', showSuccessAlert: true });
       });
     });
 
     describe('when making an unsuccessful call and conditions for retry are favorable and loginPing does not throw', () => {
-      it('then it should retry', async () => {
-        jest.useFakeTimers();
-        const url = '/api/dashboard/';
-        const { backendSrv, appEventsMock, logoutMock, expectRequestCallChain } = getTestContext({
-          ok: false,
-          status: 401,
-          statusText: 'UnAuthorized',
-          data: { message: 'UnAuthorized' },
-          url,
-        });
+      const url = '/api/dashboard/';
+      const okResponse = { ok: true, status: 200, statusText: 'OK', data: { message: 'Ok' } };
+      let fetchMock: jest.SpyInstance;
 
-        backendSrv.loginPing = jest
-          .fn()
-          .mockResolvedValue({ ok: true, status: 200, statusText: 'OK', data: { message: 'Ok' } });
+      afterEach(() => {
+        fetchMock.mockClear();
+      });
 
-        await backendSrv
-          .request({ url, method: 'GET', retry: 0 })
-          .catch((error) => {
-            expect(error.status).toBe(401);
-            expect(error.statusText).toBe('UnAuthorized');
-            expect(error.data).toEqual({ message: 'UnAuthorized' });
-            expect(appEventsMock.emit).not.toHaveBeenCalled();
-            expect(logoutMock).not.toHaveBeenCalled();
-            expect(backendSrv.loginPing).toHaveBeenCalledTimes(1);
-            expectRequestCallChain({ url, method: 'GET', retry: 0 });
-            jest.advanceTimersByTime(50);
+      afterAll(() => {
+        fetchMock.mockRestore();
+        config.featureToggles.clientTokenRotation = false;
+      });
+
+      it.each`
+        clientTokenRotation
+        ${true}
+        ${false}
+      `('then it should retry (clientTokenRotation = %s)', async ({ clientTokenRotation }) => {
+        config.featureToggles.clientTokenRotation = clientTokenRotation;
+
+        fetchMock = jest
+          .spyOn(global, 'fetch')
+          .mockRejectedValueOnce({
+            ok: false,
+            status: 401,
+            statusText: errorMessage,
+            headers: new Map(),
+            text: jest.fn().mockResolvedValue(JSON.stringify({ test: 'hello world' })),
+            data: { message: errorMessage },
+            url,
           })
-          .catch((error) => {
-            expect(error).toEqual({ message: 'UnAuthorized' });
-            expect(appEventsMock.emit).toHaveBeenCalledTimes(1);
-            expect(appEventsMock.emit).toHaveBeenCalledWith(AppEvents.alertWarning, ['UnAuthorized', '']);
-          });
+          .mockResolvedValueOnce({
+            ok: true,
+            status: 200,
+            headers: new Map(),
+            text: jest.fn().mockResolvedValue(JSON.stringify({ test: 'hello world' })),
+            data: { message: 'OK' },
+            url,
+          } as unknown as Response);
+
+        const { backendSrv, appEventsMock, logoutMock } = getTestContext(
+          {
+            ok: false,
+            status: 401,
+            statusText: errorMessage,
+            data: { message: errorMessage },
+            url,
+          },
+          false
+        );
+
+        backendSrv.loginPing = jest.fn().mockResolvedValue(okResponse);
+
+        backendSrv.rotateToken = jest.fn().mockResolvedValue(okResponse);
+
+        await backendSrv.request({ url, method: 'GET', retry: 0 }).finally(() => {
+          expect(appEventsMock.emit).not.toHaveBeenCalled();
+          expect(logoutMock).not.toHaveBeenCalled();
+          if (config.featureToggles.clientTokenRotation) {
+            expect(backendSrv.rotateToken).toHaveBeenCalledTimes(1);
+          } else {
+            expect(backendSrv.loginPing).toHaveBeenCalledTimes(1);
+          }
+          expect(fetchMock).toHaveBeenCalledTimes(2); // expecting 2 calls because of retry and because the loginPing/tokenRotation is mocked
+        });
       });
     });
 
@@ -194,7 +233,7 @@ describe('backendSrv', () => {
         const { backendSrv, appEventsMock, logoutMock, expectRequestCallChain } = getTestContext({
           ok: false,
           status: 401,
-          statusText: 'UnAuthorized',
+          statusText: errorMessage,
           data: { message: 'Token revoked', error: { id: 'ERR_TOKEN_REVOKED', maxConcurrentSessions: 3 } },
           url,
         });
@@ -224,8 +263,8 @@ describe('backendSrv', () => {
         const { backendSrv, appEventsMock, logoutMock, expectRequestCallChain } = getTestContext({
           ok: false,
           status: 401,
-          statusText: 'UnAuthorized',
-          data: { message: 'UnAuthorized' },
+          statusText: errorMessage,
+          data: { message: errorMessage },
         });
 
         backendSrv.loginPing = jest
@@ -275,6 +314,26 @@ describe('backendSrv', () => {
             'bogus-trace-id',
           ]);
         });
+
+        it('It should favor error.message for fetch errors when error.data.message is Unexpected error', async () => {
+          const { backendSrv, appEventsMock } = getTestContext({});
+          backendSrv.showErrorAlert(
+            {
+              url: 'api/do/something',
+            } as BackendSrvRequest,
+            {
+              data: {
+                message: 'Unexpected error',
+              },
+              message: 'Failed to fetch',
+              status: 500,
+              config: {
+                url: '',
+              },
+            } as FetchError
+          );
+          expect(appEventsMock.emit).toHaveBeenCalledWith(AppEvents.alertError, ['Failed to fetch', '']);
+        });
       });
     });
 
@@ -335,6 +394,63 @@ describe('backendSrv', () => {
         });
       });
     });
+
+    describe('traceId handling', () => {
+      const opts = { url: '/something', method: 'GET' };
+      it('should handle a success-response without traceId', async () => {
+        const ctx = getTestContext({ status: 200, statusText: 'OK', headers: new Headers() });
+        const res = await lastValueFrom(ctx.backendSrv.fetch(opts));
+        expect(res.traceId).toBeUndefined();
+      });
+
+      it('should handle a success-response with traceId', async () => {
+        const ctx = getTestContext({
+          status: 200,
+          statusText: 'OK',
+          headers: new Headers({
+            'grafana-trace-id': 'traceId1',
+          }),
+        });
+        const res = await lastValueFrom(ctx.backendSrv.fetch(opts));
+        expect(res.traceId).toBe('traceId1');
+      });
+
+      it('should handle an error-response without traceId', () => {
+        const ctx = getTestContext({
+          ok: false,
+          status: 500,
+          statusText: 'INTERNAL SERVER ERROR',
+          headers: new Headers(),
+        });
+        return lastValueFrom(ctx.backendSrv.fetch(opts)).then(
+          (data) => {
+            throw new Error('must not get here');
+          },
+          (error) => {
+            expect(error.traceId).toBeUndefined();
+          }
+        );
+      });
+
+      it('should handle an error-response with traceId', () => {
+        const ctx = getTestContext({
+          ok: false,
+          status: 500,
+          statusText: 'INTERNAL SERVER ERROR',
+          headers: new Headers({
+            'grafana-trace-id': 'traceId1',
+          }),
+        });
+        return lastValueFrom(ctx.backendSrv.fetch(opts)).then(
+          (data) => {
+            throw new Error('must not get here');
+          },
+          (error) => {
+            expect(error.traceId).toBe('traceId1');
+          }
+        );
+      });
+    });
   });
 
   describe('datasourceRequest', () => {
@@ -349,6 +465,7 @@ describe('backendSrv', () => {
             ok: true,
             status: 200,
             statusText: 'Ok',
+            headers: new Map(),
             text: () => Promise.resolve(JSON.stringify(slowData)),
             redirected: false,
             type: 'basic',
@@ -362,6 +479,7 @@ describe('backendSrv', () => {
           ok: true,
           status: 200,
           statusText: 'Ok',
+          headers: new Map(),
           text: () => Promise.resolve(JSON.stringify(fastData)),
           redirected: false,
           type: 'basic',
@@ -377,7 +495,7 @@ describe('backendSrv', () => {
           requestId: 'A',
         };
 
-        let slowError: any = null;
+        let slowError = null;
         backendSrv.request(options).catch((err) => {
           slowError = err;
         });
@@ -402,32 +520,68 @@ describe('backendSrv', () => {
     });
 
     describe('when making an unsuccessful call and conditions for retry are favorable and loginPing does not throw', () => {
-      it('then it should retry', async () => {
-        const { backendSrv, logoutMock, expectRequestCallChain } = getTestContext({
-          ok: false,
-          status: 401,
-          statusText: 'UnAuthorized',
-          data: { message: 'UnAuthorized' },
-        });
+      const url = '/api/dashboard/';
+      const okResponse = { ok: true, status: 200, statusText: 'OK', data: { message: 'Ok' } };
+      let fetchMock: jest.SpyInstance;
 
-        backendSrv.loginPing = jest
-          .fn()
-          .mockResolvedValue({ ok: true, status: 200, statusText: 'OK', data: { message: 'Ok' } });
-        const url = '/api/dashboard/';
+      afterEach(() => {
+        fetchMock.mockClear();
+      });
 
-        let inspectorPacket: any = null;
-        backendSrv.getInspectorStream().subscribe({
-          next: (rsp) => (inspectorPacket = rsp),
-        });
+      afterAll(() => {
+        fetchMock.mockRestore();
+        config.featureToggles.clientTokenRotation = false;
+      });
 
-        await backendSrv.datasourceRequest({ url, method: 'GET', retry: 0 }).catch((error) => {
-          expect(error.status).toBe(401);
-          expect(error.statusText).toBe('UnAuthorized');
-          expect(error.data).toEqual({ message: 'UnAuthorized' });
-          expect(inspectorPacket).toBe(error);
-          expect(backendSrv.loginPing).toHaveBeenCalledTimes(1);
+      it.each`
+        clientTokenRotation
+        ${true}
+        ${false}
+      `('then it should retry (clientTokenRotation = %s)', async ({ clientTokenRotation }) => {
+        config.featureToggles.clientTokenRotation = clientTokenRotation;
+
+        fetchMock = jest
+          .spyOn(global, 'fetch')
+          .mockRejectedValueOnce({
+            ok: false,
+            status: 401,
+            statusText: 'UnAuthorized',
+            headers: new Map(),
+            text: jest.fn().mockResolvedValue(JSON.stringify({ test: 'hello world' })),
+            data: { message: 'UnAuthorized' },
+            url,
+          })
+          .mockResolvedValueOnce({
+            ok: true,
+            status: 200,
+            headers: new Map(),
+            text: jest.fn().mockResolvedValue(JSON.stringify({ test: 'hello world' })),
+            data: { message: 'OK' },
+            url,
+          } as unknown as Response);
+
+        const { backendSrv, logoutMock } = getTestContext(
+          {
+            ok: false,
+            status: 401,
+            statusText: 'UnAuthorized',
+            data: { message: 'UnAuthorized' },
+          },
+          false
+        );
+
+        backendSrv.loginPing = jest.fn().mockResolvedValue(okResponse);
+
+        backendSrv.rotateToken = jest.fn().mockResolvedValue(okResponse);
+
+        await backendSrv.datasourceRequest({ url, method: 'GET', retry: 0 }).finally(() => {
           expect(logoutMock).not.toHaveBeenCalled();
-          expectRequestCallChain({ url, method: 'GET', retry: 0 });
+          if (config.featureToggles.clientTokenRotation) {
+            expect(backendSrv.rotateToken).toHaveBeenCalledTimes(1);
+          } else {
+            expect(backendSrv.loginPing).toHaveBeenCalledTimes(1);
+          }
+          expect(fetchMock).toHaveBeenCalledTimes(2); // expecting 2 calls because of retry and because the loginPing/tokenRotation is mocked
         });
       });
     });
@@ -536,7 +690,7 @@ describe('backendSrv', () => {
           method: 'GET',
         };
 
-        let inspectorPacket: any = null;
+        let inspectorPacket: FetchResponse | FetchError;
         backendSrv.getInspectorStream().subscribe({
           next: (rsp) => (inspectorPacket = rsp),
         });
@@ -563,7 +717,7 @@ describe('backendSrv', () => {
     describe('when called with 2 separate requests and then cancelAllInFlightRequests is called', () => {
       const url = '/api/dashboard/';
 
-      const getRequestObservable = (message: string, unsubscribe: any) =>
+      const getRequestObservable = (message: string, unsubscribe: jest.Mock) =>
         new Observable((subscriber) => {
           subscriber.next({
             ok: true,
