@@ -1,6 +1,6 @@
 /**
  * Check to see if browser is not supported by Grafana
- * This function is copied to index-template.html but is here so we can write tests
+ * This function is copied to index.html but is here so we can write tests
  *  */
 export function checkBrowserCompatibility() {
   const isIE = navigator.userAgent.indexOf('MSIE') > -1;
@@ -32,3 +32,12 @@ export function checkBrowserCompatibility() {
 
   return true;
 }
+
+export function userAgentIsApple() {
+  const appleRe = /(iPhone|iPad|Mac)/;
+  return appleRe.test(navigator.platform);
+}
+
+export function getModKey() {
+  return userAgentIsApple() ? 'cmd' : 'ctrl';
+}
