@@ -1,42 +1,20 @@
 import React, { useState, useEffect } from 'react';
 import { useAsyncFn } from 'react-use';
 
-import { NavModelItem, UrlQueryValue } from '@grafana/data';
-import { getBackendSrv } from '@grafana/runtime';
-import { Form, Field, Input, Button, Legend, Alert, VerticalGroup, HorizontalGroup, Pagination } from '@grafana/ui';
+import { NavModelItem } from '@grafana/data';
+import { Form, Field, Input, Button, Legend, Alert } from '@grafana/ui';
 import { Page } from 'app/core/components/Page/Page';
 import { contextSrv } from 'app/core/core';
 import { GrafanaRouteComponentProps } from 'app/core/navigation/types';
-import { accessControlQueryParam } from 'app/core/utils/accessControl';
 import { OrgUser, AccessControlAction, OrgRole } from 'app/types';
 
-import { UsersTable } from '../users/UsersTable';
-
-const perPage = 30;
+import { OrgUsersTable } from './Users/OrgUsersTable';
+import { getOrg, getOrgUsers, getUsersRoles, removeOrgUser, updateOrgName, updateOrgUserRole } from './api';
 
 interface OrgNameDTO {
   orgName: string;
 }
 
-const getOrg = async (orgId: UrlQueryValue) => {
-  return await getBackendSrv().get(`/api/orgs/${orgId}`);
-};
-
-const getOrgUsers = async (orgId: UrlQueryValue, page: number) => {
-  if (contextSrv.hasPermission(AccessControlAction.OrgUsersRead)) {
-    return getBackendSrv().get(`/api/orgs/${orgId}/users/search`, accessControlQueryParam({ perpage: perPage, page }));
-  }
-  return { orgUsers: [] };
-};
-
-const updateOrgUserRole = (orgUser: OrgUser, orgId: UrlQueryValue) => {
-  return getBackendSrv().patch(`/api/orgs/${orgId}/users/${orgUser.userId}`, orgUser);
-};
-
-const removeOrgUser = (orgUser: OrgUser, orgId: UrlQueryValue) => {
-  return getBackendSrv().delete(`/api/orgs/${orgId}/users/${orgUser.userId}`);
-};
-
 interface Props extends GrafanaRouteComponentProps<{ id: string }> {}
 
 const AdminEditOrgPage = ({ match }: Props) => {
@@ -51,6 +29,11 @@ const AdminEditOrgPage = ({ match }: Props) => {
   const [orgState, fetchOrg] = useAsyncFn(() => getOrg(orgId), []);
   const [, fetchOrgUsers] = useAsyncFn(async (page) => {
     const result = await getOrgUsers(orgId, page);
+
+    if (contextSrv.licensedAccessControlEnabled()) {
+      await getUsersRoles(orgId, result.orgUsers);
+    }
+
     const totalPages = result?.perPage !== 0 ? Math.ceil(result.totalCount / result.perPage) : 0;
     setTotalPages(totalPages);
     setUsers(result.orgUsers);
@@ -62,8 +45,8 @@ const AdminEditOrgPage = ({ match }: Props) => {
     fetchOrgUsers(page);
   }, [fetchOrg, fetchOrgUsers, page]);
 
-  const updateOrgName = async (name: string) => {
-    return await getBackendSrv().put(`/api/orgs/${orgId}`, { ...orgState.value, name });
+  const onUpdateOrgName = async (name: string) => {
+    await updateOrgName(name, orgId);
   };
 
   const renderMissingPermissionMessage = () => (
@@ -101,7 +84,7 @@ const AdminEditOrgPage = ({ match }: Props) => {
           {orgState.value && (
             <Form
               defaultValues={{ orgName: orgState.value.name }}
-              onSubmit={(values: OrgNameDTO) => updateOrgName(values.orgName)}
+              onSubmit={(values: OrgNameDTO) => onUpdateOrgName(values.orgName)}
             >
               {({ register, errors }) => (
                 <>
@@ -120,17 +103,15 @@ const AdminEditOrgPage = ({ match }: Props) => {
             <Legend>Organization users</Legend>
             {!canReadUsers && renderMissingPermissionMessage()}
             {canReadUsers && !!users.length && (
-              <VerticalGroup spacing="md">
-                <UsersTable users={users} orgId={orgId} onRoleChange={onRoleChange} onRemoveUser={onRemoveUser} />
-                <HorizontalGroup justify="flex-end">
-                  <Pagination
-                    onNavigate={onPageChange}
-                    currentPage={page}
-                    numberOfPages={totalPages}
-                    hideWhenSinglePage={true}
-                  />
-                </HorizontalGroup>
-              </VerticalGroup>
+              <OrgUsersTable
+                users={users}
+                orgId={orgId}
+                onRoleChange={onRoleChange}
+                onRemoveUser={onRemoveUser}
+                changePage={onPageChange}
+                page={page}
+                totalPages={totalPages}
+              />
             )}
           </div>
         </>
