@@ -1,6 +1,9 @@
+import { css } from '@emotion/css';
 import React, { useState } from 'react';
+import Skeleton from 'react-loading-skeleton';
 
-import { Button, ConfirmModal } from '@grafana/ui';
+import { GrafanaTheme2 } from '@grafana/data';
+import { Button, ConfirmModal, useStyles2 } from '@grafana/ui';
 import { contextSrv } from 'app/core/core';
 import { AccessControlAction, Organization } from 'app/types';
 
@@ -9,19 +12,23 @@ interface Props {
   onDelete: (orgId: number) => void;
 }
 
+const getTableHeader = () => (
+  <thead>
+    <tr>
+      <th>ID</th>
+      <th>Name</th>
+      <th style={{ width: '1%' }}></th>
+    </tr>
+  </thead>
+);
+
 export function AdminOrgsTable({ orgs, onDelete }: Props) {
   const canDeleteOrgs = contextSrv.hasPermission(AccessControlAction.OrgsDelete);
 
   const [deleteOrg, setDeleteOrg] = useState<Organization>();
   return (
     <table className="filter-table form-inline filter-table--hover">
-      <thead>
-        <tr>
-          <th>ID</th>
-          <th>Name</th>
-          <th style={{ width: '1%' }}></th>
-        </tr>
-      </thead>
+      {getTableHeader()}
       <tbody>
         {orgs.map((org) => (
           <tr key={`${org.id}-${org.name}`}>
@@ -66,3 +73,38 @@ export function AdminOrgsTable({ orgs, onDelete }: Props) {
     </table>
   );
 }
+
+const AdminOrgsTableSkeleton = () => {
+  const styles = useStyles2(getSkeletonStyles);
+  return (
+    <table className="filter-table">
+      {getTableHeader()}
+      <tbody>
+        {new Array(3).fill(null).map((_, index) => (
+          <tr key={index}>
+            <td>
+              <Skeleton width={16} />
+            </td>
+            <td>
+              <Skeleton width={240} />
+            </td>
+            <td>
+              <Skeleton containerClassName={styles.deleteButton} width={22} height={24} />
+            </td>
+          </tr>
+        ))}
+      </tbody>
+    </table>
+  );
+};
+
+AdminOrgsTable.Skeleton = AdminOrgsTableSkeleton;
+
+const getSkeletonStyles = (theme: GrafanaTheme2) => ({
+  deleteButton: css({
+    alignItems: 'center',
+    display: 'flex',
+    height: 30,
+    lineHeight: 1,
+  }),
+});
