@@ -1,6 +1,8 @@
 import { render, screen } from '@testing-library/react';
 import React from 'react';
 
+import config from 'app/core/config';
+
 import { ServerStats } from './ServerStats';
 import { ServerStat } from './state/apis';
 
@@ -10,6 +12,7 @@ const stats: ServerStat = {
   activeSessions: 1,
   activeUsers: 1,
   activeViewers: 0,
+  activeDevices: 1,
   admins: 1,
   alerts: 5,
   dashboards: 1599,
@@ -29,7 +32,7 @@ jest.mock('./state/apis', () => ({
 }));
 jest.mock('../../core/services/context_srv', () => ({
   contextSrv: {
-    hasAccess: () => true,
+    hasPermission: () => true,
   },
 }));
 
@@ -46,4 +49,12 @@ describe('ServerStats', () => {
     expect(screen.getByRole('link', { name: 'Alerts' })).toBeInTheDocument();
     expect(screen.getByRole('link', { name: 'Manage users' })).toBeInTheDocument();
   });
+
+  it('Should render page with anonymous stats', async () => {
+    config.featureToggles.displayAnonymousStats = true;
+    render(<ServerStats />);
+    expect(await screen.findByRole('heading', { name: /instance statistics/i })).toBeInTheDocument();
+    expect(screen.getByText('Active anonymous devices in last 30 days')).toBeInTheDocument();
+    expect(screen.getByText('Active anonymous users in last 30 days')).toBeInTheDocument();
+  });
 });
