@@ -2,7 +2,7 @@ import { render, screen } from '@testing-library/react';
 import React from 'react';
 
 import { PanelModel } from '../dashboard/state';
-import { createDashboardModelFixture, createPanelJSONFixture } from '../dashboard/state/__fixtures__/dashboardFixtures';
+import { createDashboardModelFixture, createPanelSaveModel } from '../dashboard/state/__fixtures__/dashboardFixtures';
 
 import { TestRuleResult } from './TestRuleResult';
 
@@ -22,7 +22,7 @@ jest.mock('@grafana/runtime', () => {
 const props: React.ComponentProps<typeof TestRuleResult> = {
   panel: new PanelModel({ id: 1 }),
   dashboard: createDashboardModelFixture({
-    panels: [createPanelJSONFixture({ id: 1 })],
+    panels: [createPanelSaveModel({ id: 1 })],
   }),
 };
 
