@@ -1,25 +1,18 @@
 import { createSlice, PayloadAction } from '@reduxjs/toolkit';
-import { ApplyFieldOverrideOptions, DataTransformerConfig, dateTime, FieldColorModeId } from '@grafana/data';
-import alertDef from './alertDef';
+
+import { dateTime } from '@grafana/data';
 import {
-  AlertCondition,
-  AlertDefinition,
-  AlertDefinitionState,
-  AlertDefinitionUiState,
   AlertRule,
   AlertRuleDTO,
   AlertRulesState,
   NotificationChannelOption,
   NotificationChannelState,
   NotifierDTO,
-  QueryGroupOptions,
 } from 'app/types';
-import store from 'app/core/store';
-import { config } from '@grafana/runtime';
-import { PanelQueryRunner } from '../../query/state/PanelQueryRunner';
 
-export const ALERT_DEFINITION_UI_STATE_STORAGE_KEY = 'grafana.alerting.alertDefinition.ui';
-const DEFAULT_ALERT_DEFINITION_UI_STATE: AlertDefinitionUiState = { rightPaneSize: 400, topPaneSize: 0.45 };
+import unifiedAlertingReducer from '../unified/state/reducers';
+
+import alertDef from './alertDef';
 
 export const initialState: AlertRulesState = {
   items: [],
@@ -33,39 +26,6 @@ export const initialChannelState: NotificationChannelState = {
   notifiers: [],
 };
 
-const options: ApplyFieldOverrideOptions = {
-  fieldConfig: {
-    defaults: {
-      color: {
-        mode: FieldColorModeId.PaletteClassic,
-      },
-    },
-    overrides: [],
-  },
-  replaceVariables: (v: string) => v,
-  theme: config.theme,
-};
-
-const dataConfig = {
-  getTransformations: () => [] as DataTransformerConfig[],
-  getFieldOverrideOptions: () => options,
-};
-
-export const initialAlertDefinitionState: AlertDefinitionState = {
-  alertDefinition: {
-    id: 0,
-    title: '',
-    description: '',
-    condition: {} as AlertCondition,
-    interval: 60,
-  },
-  queryOptions: { maxDataPoints: 100, dataSource: {}, queries: [] },
-  queryRunner: new PanelQueryRunner(dataConfig),
-  uiState: { ...store.getObject(ALERT_DEFINITION_UI_STATE_STORAGE_KEY, DEFAULT_ALERT_DEFINITION_UI_STATE) },
-  data: [],
-  alertDefinitions: [] as AlertDefinition[],
-};
-
 function convertToAlertRule(dto: AlertRuleDTO, state: string): AlertRule {
   const stateModel = alertDef.getStateDisplayModel(state);
 
@@ -152,49 +112,18 @@ const notificationChannelSlice = createSlice({
   },
 });
 
-const alertDefinitionSlice = createSlice({
-  name: 'alertDefinition',
-  initialState: initialAlertDefinitionState,
-  reducers: {
-    setAlertDefinition: (state: AlertDefinitionState, action: PayloadAction<any>) => {
-      return { ...state, alertDefinition: action.payload };
-    },
-    updateAlertDefinition: (state: AlertDefinitionState, action: PayloadAction<Partial<AlertDefinition>>) => {
-      return { ...state, alertDefinition: { ...state.alertDefinition, ...action.payload } };
-    },
-    setUiState: (state: AlertDefinitionState, action: PayloadAction<AlertDefinitionUiState>) => {
-      return { ...state, uiState: { ...state.uiState, ...action.payload } };
-    },
-    setQueryOptions: (state: AlertDefinitionState, action: PayloadAction<QueryGroupOptions>) => {
-      return {
-        ...state,
-        queryOptions: action.payload,
-      };
-    },
-    setAlertDefinitions: (state: AlertDefinitionState, action: PayloadAction<AlertDefinition[]>) => {
-      return { ...state, alertDefinitions: action.payload };
-    },
-  },
-});
-
 export const { loadAlertRules, loadedAlertRules, setSearchQuery } = alertRulesSlice.actions;
 
-export const {
-  setNotificationChannels,
-  notificationChannelLoaded,
-  resetSecureField,
-} = notificationChannelSlice.actions;
-
-export const { setUiState, updateAlertDefinition, setQueryOptions, setAlertDefinitions } = alertDefinitionSlice.actions;
+export const { setNotificationChannels, notificationChannelLoaded, resetSecureField } =
+  notificationChannelSlice.actions;
 
 export const alertRulesReducer = alertRulesSlice.reducer;
 export const notificationChannelReducer = notificationChannelSlice.reducer;
-export const alertDefinitionsReducer = alertDefinitionSlice.reducer;
 
 export default {
   alertRules: alertRulesReducer,
   notificationChannel: notificationChannelReducer,
-  alertDefinition: alertDefinitionsReducer,
+  unifiedAlerting: unifiedAlertingReducer,
 };
 
 function migrateSecureFields(
