@@ -3,6 +3,7 @@ import React from 'react';
 import { Alert } from '@grafana/ui';
 import { AlertManagerCortexConfig } from 'app/plugins/datasource/alertmanager/types';
 
+import { AlertmanagerAction, useAlertmanagerAbility } from '../../hooks/useAbilities';
 import { GRAFANA_RULES_SOURCE_NAME } from '../../utils/datasource';
 
 import { CloudReceiverForm } from './form/CloudReceiverForm';
@@ -15,6 +16,8 @@ interface Props {
 }
 
 export const EditReceiverView = ({ config, receiverName, alertManagerSourceName }: Props) => {
+  const [editSupported, editAllowed] = useAlertmanagerAbility(AlertmanagerAction.UpdateContactPoint);
+
   const receiver = config.alertmanager_config.receivers?.find(({ name }) => name === receiverName);
   if (!receiver) {
     return (
@@ -24,9 +27,25 @@ export const EditReceiverView = ({ config, receiverName, alertManagerSourceName
     );
   }
 
+  const readOnly = !editSupported || !editAllowed;
+
   if (alertManagerSourceName === GRAFANA_RULES_SOURCE_NAME) {
-    return <GrafanaReceiverForm config={config} alertManagerSourceName={alertManagerSourceName} existing={receiver} />;
+    return (
+      <GrafanaReceiverForm
+        config={config}
+        alertManagerSourceName={alertManagerSourceName}
+        existing={receiver}
+        readOnly={readOnly}
+      />
+    );
   } else {
-    return <CloudReceiverForm config={config} alertManagerSourceName={alertManagerSourceName} existing={receiver} />;
+    return (
+      <CloudReceiverForm
+        config={config}
+        alertManagerSourceName={alertManagerSourceName}
+        existing={receiver}
+        readOnly={readOnly}
+      />
+    );
   }
 };
