@@ -1,15 +1,15 @@
-import React, { FC } from 'react';
+import React from 'react';
 import { useFormContext } from 'react-hook-form';
 
 import { Checkbox, Field } from '@grafana/ui';
 
 import { CommonSettingsComponentProps } from '../../../types/receiver-form';
 
-export const CloudCommonChannelSettings: FC<CommonSettingsComponentProps> = ({
+export const CloudCommonChannelSettings = ({
   pathPrefix,
   className,
   readOnly = false,
-}) => {
+}: CommonSettingsComponentProps) => {
   const { register } = useFormContext();
   return (
     <div className={className}>
