@@ -3,7 +3,8 @@ import { isEmpty } from 'lodash';
 import React, { FC, useEffect } from 'react';
 import { useFormContext, FieldError, DeepMap } from 'react-hook-form';
 
-import { Checkbox, Field, Input, InputControl, Select, TextArea } from '@grafana/ui';
+import { GrafanaTheme2 } from '@grafana/data';
+import { Checkbox, Field, Input, InputControl, RadioButtonList, Select, TextArea, useStyles2 } from '@grafana/ui';
 import { NotificationChannelOption } from 'app/types';
 
 import { KeyValueMapInput } from './KeyValueMapInput';
@@ -19,6 +20,7 @@ interface Props {
   pathSuffix?: string;
   error?: FieldError | DeepMap<any, FieldError>;
   readOnly?: boolean;
+  customValidator?: (value: string) => boolean | string | Promise<boolean | string>;
 }
 
 export const OptionField: FC<Props> = ({
@@ -29,6 +31,7 @@ export const OptionField: FC<Props> = ({
   error,
   defaultValue,
   readOnly = false,
+  customValidator,
 }) => {
   const optionPath = `${pathPrefix}${pathSuffix}`;
 
@@ -38,7 +41,7 @@ export const OptionField: FC<Props> = ({
         readOnly={readOnly}
         defaultValue={defaultValue}
         option={option}
-        errors={error as DeepMap<any, FieldError> | undefined}
+        errors={error}
         pathPrefix={optionPath}
       />
     );
@@ -56,10 +59,11 @@ export const OptionField: FC<Props> = ({
   }
   return (
     <Field
-      label={option.element !== 'checkbox' ? option.label : undefined}
+      label={option.element !== 'checkbox' && option.element !== 'radio' ? option.label : undefined}
       description={option.description || undefined}
       invalid={!!error}
       error={error?.message}
+      data-testid={`${optionPath}${option.propertyName}`}
     >
       <OptionInput
         id={`${optionPath}${option.propertyName}`}
@@ -69,6 +73,7 @@ export const OptionField: FC<Props> = ({
         pathPrefix={optionPath}
         readOnly={readOnly}
         pathIndex={pathPrefix}
+        customValidator={customValidator}
       />
     </Field>
   );
@@ -81,7 +86,9 @@ const OptionInput: FC<Props & { id: string; pathIndex?: string }> = ({
   pathPrefix = '',
   pathIndex = '',
   readOnly = false,
+  customValidator,
 }) => {
+  const styles = useStyles2(getStyles);
   const { control, register, unregister, getValues } = useFormContext();
   const name = `${pathPrefix}${option.propertyName}`;
 
@@ -114,7 +121,10 @@ const OptionInput: FC<Props & { id: string; pathIndex?: string }> = ({
           type={option.inputType}
           {...register(name, {
             required: determineRequired(option, getValues, pathIndex),
-            validate: (v) => (option.validationRule !== '' ? validateOption(v, option.validationRule) : true),
+            validate: {
+              validationRule: (v) => (option.validationRule ? validateOption(v, option.validationRule) : true),
+              customValidator: (v) => (customValidator ? customValidator(v) : true),
+            },
             setValueAs: option.setValueAs,
           })}
           placeholder={option.placeholder}
@@ -127,18 +137,43 @@ const OptionInput: FC<Props & { id: string; pathIndex?: string }> = ({
           render={({ field: { onChange, ref, ...field } }) => (
             <Select
               disabled={readOnly}
-              {...field}
-              defaultValue={option.defaultValue}
               options={option.selectOptions ?? undefined}
               invalid={invalid}
               onChange={(value) => onChange(value.value)}
+              {...field}
             />
           )}
           control={control}
           name={name}
+          defaultValue={option.defaultValue}
+          rules={{
+            validate: {
+              customValidator: (v) => (customValidator ? customValidator(v) : true),
+            },
+          }}
         />
       );
-
+    case 'radio':
+      return (
+        <>
+          <legend className={styles.legend}>{option.label}</legend>
+          <InputControl
+            render={({ field: { ref, ...field } }) => (
+              <RadioButtonList disabled={readOnly} options={option.selectOptions ?? []} {...field} />
+            )}
+            control={control}
+            defaultValue={option.defaultValue?.value}
+            name={name}
+            rules={{
+              required: option.required ? 'Option is required' : false,
+              validate: {
+                validationRule: (v) => (option.validationRule ? validateOption(v, option.validationRule) : true),
+                customValidator: (v) => (customValidator ? customValidator(v) : true),
+              },
+            }}
+          />
+        </>
+      );
     case 'textarea':
       return (
         <TextArea
@@ -179,11 +214,14 @@ const OptionInput: FC<Props & { id: string; pathIndex?: string }> = ({
   }
 };
 
-const styles = {
+const getStyles = (theme: GrafanaTheme2) => ({
   checkbox: css`
     height: auto; // native checkbox has fixed height which does not take into account description
   `,
-};
+  legend: css`
+    font-size: ${theme.typography.h6.fontSize};
+  `,
+});
 
 const validateOption = (value: string, validationRule: string) => {
   return RegExp(validationRule).test(value) ? true : 'Invalid format';
