@@ -1,8 +1,15 @@
 import { xor } from 'lodash';
 import { ValidateResult } from 'react-hook-form';
 
-import { DataFrame, ThresholdsConfig, ThresholdsMode, isTimeSeriesFrames, PanelData } from '@grafana/data';
-import { GraphTresholdsStyleMode, LoadingState } from '@grafana/schema';
+import {
+  DataFrame,
+  isTimeSeriesFrames,
+  LoadingState,
+  PanelData,
+  ThresholdsConfig,
+  ThresholdsMode,
+} from '@grafana/data';
+import { GraphTresholdsStyleMode } from '@grafana/schema';
 import { config } from 'app/core/config';
 import { EvalFunction } from 'app/features/alerting/state/alertDef';
 import { isExpressionQuery } from 'app/features/expressions/guards';
@@ -95,12 +102,13 @@ export function checkForPathSeparator(value: string): ValidateResult {
   return true;
 }
 
-export function errorFromSeries(series: DataFrame[]): Error | undefined {
-  if (series.length === 0) {
+// this function assumes we've already checked if the data passed in to the function is of the alert condition
+export function errorFromCurrentCondition(data: PanelData): Error | undefined {
+  if (data.series.length === 0) {
     return;
   }
 
-  const isTimeSeriesResults = isTimeSeriesFrames(series);
+  const isTimeSeriesResults = isTimeSeriesFrames(data.series);
 
   let error;
   if (isTimeSeriesResults) {
@@ -110,6 +118,15 @@ export function errorFromSeries(series: DataFrame[]): Error | undefined {
   return error;
 }
 
+export function errorFromPreviewData(data: PanelData): Error | undefined {
+  // give preference to QueryErrors
+  if (data.errors?.length) {
+    return new Error(data.errors[0].message);
+  }
+
+  return;
+}
+
 export function warningFromSeries(series: DataFrame[]): Error | undefined {
   const notices = series[0]?.meta?.notices ?? [];
   const warning = notices.find((notice) => notice.severity === 'warning')?.text;
