@@ -1,5 +1,5 @@
 import { css } from '@emotion/css';
-import React, { FC } from 'react';
+import React from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { Icon, Tooltip, useStyles2 } from '@grafana/ui';
@@ -9,8 +9,9 @@ interface Prom {
   rule: Rule;
 }
 
-export const RuleHealth: FC<Prom> = ({ rule }) => {
+export const RuleHealth = ({ rule }: Prom) => {
   const style = useStyles2(getStyle);
+
   if (rule.health === 'err' || rule.health === 'error') {
     return (
       <Tooltip theme="error" content={rule.lastError || 'No error message provided.'}>
@@ -21,6 +22,7 @@ export const RuleHealth: FC<Prom> = ({ rule }) => {
       </Tooltip>
     );
   }
+
   return <>{rule.health}</>;
 };
 
@@ -28,9 +30,9 @@ const getStyle = (theme: GrafanaTheme2) => ({
   warn: css`
     display: inline-flex;
     flex-direction: row;
+    align-items: center;
+    gap: ${theme.spacing(1)};
+
     color: ${theme.colors.warning.text};
-    & > * + * {
-      margin-left: ${theme.spacing(1)};
-    }
   `,
 });
