@@ -1,7 +1,11 @@
-import { isEqual } from 'lodash';
+import { countBy, isEqual } from 'lodash';
 import { useMemo, useRef } from 'react';
 
 import {
+  AlertGroupTotals,
+  AlertingRule,
+  AlertInstanceTotals,
+  AlertInstanceTotalState,
   CombinedRule,
   CombinedRuleGroup,
   CombinedRuleNamespace,
@@ -10,15 +14,27 @@ import {
   RuleNamespace,
   RulesSource,
 } from 'app/types/unified-alerting';
-import { RulerRuleDTO, RulerRuleGroupDTO, RulerRulesConfigDTO } from 'app/types/unified-alerting-dto';
+import {
+  PromAlertingRuleState,
+  RulerRuleDTO,
+  RulerRuleGroupDTO,
+  RulerRulesConfigDTO,
+} from 'app/types/unified-alerting-dto';
 
 import {
   getAllRulesSources,
   getRulesSourceByName,
+  GRAFANA_RULES_SOURCE_NAME,
   isCloudRulesSource,
   isGrafanaRulesSource,
 } from '../utils/datasource';
-import { isAlertingRule, isAlertingRulerRule, isRecordingRulerRule } from '../utils/rules';
+import {
+  isAlertingRule,
+  isAlertingRulerRule,
+  isGrafanaRulerRule,
+  isRecordingRule,
+  isRecordingRulerRule,
+} from '../utils/rules';
 
 import { useUnifiedAlertingSelector } from './useUnifiedAlertingSelector';
 
@@ -30,7 +46,10 @@ interface CacheValue {
 
 // this little monster combines prometheus rules and ruler rules to produce a unified data structure
 // can limit to a single rules source
-export function useCombinedRuleNamespaces(rulesSourceName?: string): CombinedRuleNamespace[] {
+export function useCombinedRuleNamespaces(
+  rulesSourceName?: string,
+  grafanaPromRuleNamespaces?: RuleNamespace[]
+): CombinedRuleNamespace[] {
   const promRulesResponses = useUnifiedAlertingSelector((state) => state.promRules);
   const rulerRulesResponses = useUnifiedAlertingSelector((state) => state.rulerRules);
 
@@ -48,50 +67,118 @@ export function useCombinedRuleNamespaces(rulesSourceName?: string): CombinedRul
     return getAllRulesSources();
   }, [rulesSourceName]);
 
-  return useMemo(
-    () =>
-      rulesSources
-        .map((rulesSource): CombinedRuleNamespace[] => {
-          const rulesSourceName = isCloudRulesSource(rulesSource) ? rulesSource.name : rulesSource;
-          const promRules = promRulesResponses[rulesSourceName]?.result;
-          const rulerRules = rulerRulesResponses[rulesSourceName]?.result;
+  return useMemo(() => {
+    return rulesSources
+      .map((rulesSource): CombinedRuleNamespace[] => {
+        const rulesSourceName = isCloudRulesSource(rulesSource) ? rulesSource.name : rulesSource;
+        const rulerRules = rulerRulesResponses[rulesSourceName]?.result;
 
-          const cached = cache.current[rulesSourceName];
-          if (cached && cached.promRules === promRules && cached.rulerRules === rulerRules) {
-            return cached.result;
-          }
-          const namespaces: Record<string, CombinedRuleNamespace> = {};
+        let promRules = promRulesResponses[rulesSourceName]?.result;
+        if (rulesSourceName === GRAFANA_RULES_SOURCE_NAME && grafanaPromRuleNamespaces) {
+          promRules = grafanaPromRuleNamespaces;
+        }
 
-          // first get all the ruler rules in
-          Object.entries(rulerRules || {}).forEach(([namespaceName, groups]) => {
-            const namespace: CombinedRuleNamespace = {
-              rulesSource,
-              name: namespaceName,
-              groups: [],
-            };
-            namespaces[namespaceName] = namespace;
-            addRulerGroupsToCombinedNamespace(namespace, groups);
+        const cached = cache.current[rulesSourceName];
+        if (cached && cached.promRules === promRules && cached.rulerRules === rulerRules) {
+          return cached.result;
+        }
+        const namespaces: Record<string, CombinedRuleNamespace> = {};
+
+        // first get all the ruler rules from the data source
+        Object.entries(rulerRules || {}).forEach(([namespaceName, groups]) => {
+          const namespace: CombinedRuleNamespace = {
+            rulesSource,
+            name: namespaceName,
+            groups: [],
+          };
+          namespaces[namespaceName] = namespace;
+          addRulerGroupsToCombinedNamespace(namespace, groups);
+        });
+
+        // then correlate with prometheus rules
+        promRules?.forEach(({ name: namespaceName, groups }) => {
+          const ns = (namespaces[namespaceName] = namespaces[namespaceName] || {
+            rulesSource,
+            name: namespaceName,
+            groups: [],
           });
 
-          // then correlate with prometheus rules
-          promRules?.forEach(({ name: namespaceName, groups }) => {
-            const ns = (namespaces[namespaceName] = namespaces[namespaceName] || {
-              rulesSource,
-              name: namespaceName,
-              groups: [],
-            });
+          addPromGroupsToCombinedNamespace(ns, groups);
+        });
 
-            addPromGroupsToCombinedNamespace(ns, groups);
-          });
+        const result = Object.values(namespaces);
 
-          const result = Object.values(namespaces);
+        cache.current[rulesSourceName] = { promRules, rulerRules, result };
+        return result;
+      })
+      .flat();
+  }, [promRulesResponses, rulerRulesResponses, rulesSources, grafanaPromRuleNamespaces]);
+}
 
-          cache.current[rulesSourceName] = { promRules, rulerRules, result };
-          return result;
-        })
-        .flat(),
-    [promRulesResponses, rulerRulesResponses, rulesSources]
-  );
+export function combineRulesNamespaces(
+  rulesSource: RulesSource,
+  promNamespaces: RuleNamespace[],
+  rulerRules?: RulerRulesConfigDTO
+): CombinedRuleNamespace[] {
+  const namespaces: Record<string, CombinedRuleNamespace> = {};
+
+  // first get all the ruler rules from the data source
+  Object.entries(rulerRules || {}).forEach(([namespaceName, groups]) => {
+    const namespace: CombinedRuleNamespace = {
+      rulesSource,
+      name: namespaceName,
+      groups: [],
+    };
+    namespaces[namespaceName] = namespace;
+    addRulerGroupsToCombinedNamespace(namespace, groups);
+  });
+
+  // then correlate with prometheus rules
+  promNamespaces?.forEach(({ name: namespaceName, groups }) => {
+    const ns = (namespaces[namespaceName] = namespaces[namespaceName] || {
+      rulesSource,
+      name: namespaceName,
+      groups: [],
+    });
+
+    addPromGroupsToCombinedNamespace(ns, groups);
+  });
+
+  return Object.values(namespaces);
+}
+
+export function attachRulerRulesToCombinedRules(
+  rulesSource: RulesSource,
+  promNamespace: RuleNamespace,
+  rulerGroups: RulerRuleGroupDTO[]
+): CombinedRuleNamespace {
+  const ns: CombinedRuleNamespace = {
+    rulesSource: rulesSource,
+    name: promNamespace.name,
+    groups: [],
+  };
+
+  // The order is important. Adding Ruler rules overrides Prometheus rules.
+  addRulerGroupsToCombinedNamespace(ns, rulerGroups);
+  addPromGroupsToCombinedNamespace(ns, promNamespace.groups);
+
+  // Remove ruler rules which does not have Prom rule counterpart
+  // This function should only attach Ruler rules to existing Prom rules
+  ns.groups.forEach((group) => {
+    group.rules = group.rules.filter((rule) => rule.promRule);
+  });
+
+  return ns;
+}
+
+export function addCombinedPromAndRulerGroups(
+  ns: CombinedRuleNamespace,
+  promGroups: RuleGroup[],
+  rulerGroups: RulerRuleGroupDTO[]
+): CombinedRuleNamespace {
+  addRulerGroupsToCombinedNamespace(ns, rulerGroups);
+  addPromGroupsToCombinedNamespace(ns, promGroups);
+  return ns;
 }
 
 // merge all groups in case of grafana managed, essentially treating namespaces (folders) as groups
@@ -106,6 +193,7 @@ export function flattenGrafanaManagedRules(namespaces: CombinedRuleNamespace[])
     newNamespace.groups.push({
       name: 'default',
       rules: sortRulesByName(namespace.groups.flatMap((group) => group.rules)),
+      totals: calculateAllGroupsTotals(namespace.groups),
     });
 
     return newNamespace;
@@ -118,11 +206,18 @@ export function sortRulesByName(rules: CombinedRule[]) {
 
 function addRulerGroupsToCombinedNamespace(namespace: CombinedRuleNamespace, groups: RulerRuleGroupDTO[] = []): void {
   namespace.groups = groups.map((group) => {
+    const numRecordingRules = group.rules.filter((rule) => isRecordingRulerRule(rule)).length;
+    const numPaused = group.rules.filter((rule) => isGrafanaRulerRule(rule) && rule.grafana_alert.is_paused).length;
+
     const combinedGroup: CombinedRuleGroup = {
       name: group.name,
       interval: group.interval,
       source_tenants: group.source_tenants,
       rules: [],
+      totals: {
+        paused: numPaused,
+        recording: numRecordingRules,
+      },
     };
     combinedGroup.rules = group.rules.map((rule) => rulerRuleToCombinedRule(rule, namespace, combinedGroup));
     return combinedGroup;
@@ -139,11 +234,18 @@ function addPromGroupsToCombinedNamespace(namespace: CombinedRuleNamespace, grou
       combinedGroup = {
         name: group.name,
         rules: [],
+        totals: calculateGroupTotals(group),
       };
       namespace.groups.push(combinedGroup);
       existingGroupsByName.set(group.name, combinedGroup);
     }
 
+    // combine totals from ruler with totals from prometheus state API
+    combinedGroup.totals = {
+      ...combinedGroup.totals,
+      ...calculateGroupTotals(group),
+    };
+
     const combinedRulesByName = new Map<string, CombinedRule[]>();
     combinedGroup!.rules.forEach((r) => {
       // Prometheus rules do not have to be unique by name
@@ -155,6 +257,8 @@ function addPromGroupsToCombinedNamespace(namespace: CombinedRuleNamespace, grou
       const existingRule = getExistingRuleInGroup(rule, combinedRulesByName, namespace.rulesSource);
       if (existingRule) {
         existingRule.promRule = rule;
+        existingRule.instanceTotals = isAlertingRule(rule) ? calculateRuleTotals(rule) : {};
+        existingRule.filteredInstanceTotals = isAlertingRule(rule) ? calculateRuleFilteredTotals(rule) : {};
       } else {
         combinedGroup!.rules.push(promRuleToCombinedRule(rule, namespace, combinedGroup!));
       }
@@ -162,6 +266,74 @@ function addPromGroupsToCombinedNamespace(namespace: CombinedRuleNamespace, grou
   });
 }
 
+export function calculateRuleTotals(rule: Pick<AlertingRule, 'alerts' | 'totals'>): AlertInstanceTotals {
+  const result = countBy(rule.alerts, 'state');
+
+  if (rule.totals) {
+    const { normal, ...totals } = rule.totals;
+    return { ...totals, inactive: normal };
+  }
+
+  return {
+    alerting: result[AlertInstanceTotalState.Alerting],
+    pending: result[AlertInstanceTotalState.Pending],
+    inactive: result[AlertInstanceTotalState.Normal],
+    nodata: result[AlertInstanceTotalState.NoData],
+    error: result[AlertInstanceTotalState.Error] + result['err'], // Prometheus uses "err" instead of "error"
+  };
+}
+
+export function calculateRuleFilteredTotals(
+  rule: Pick<AlertingRule, 'alerts' | 'totalsFiltered'>
+): AlertInstanceTotals {
+  if (rule.totalsFiltered) {
+    const { normal, ...totals } = rule.totalsFiltered;
+    return { ...totals, inactive: normal };
+  }
+  return {};
+}
+
+export function calculateGroupTotals(group: Pick<RuleGroup, 'rules' | 'totals'>): AlertGroupTotals {
+  if (group.totals) {
+    const { firing, ...totals } = group.totals;
+
+    return {
+      ...totals,
+      alerting: firing,
+    };
+  }
+
+  const countsByState = countBy(group.rules, (rule) => isAlertingRule(rule) && rule.state);
+  const countsByHealth = countBy(group.rules, (rule) => rule.health);
+  const recordingCount = group.rules.filter((rule) => isRecordingRule(rule)).length;
+
+  return {
+    alerting: countsByState[PromAlertingRuleState.Firing],
+    error: countsByHealth.error,
+    nodata: countsByHealth.nodata,
+    inactive: countsByState[PromAlertingRuleState.Inactive],
+    pending: countsByState[PromAlertingRuleState.Pending],
+    recording: recordingCount,
+  };
+}
+
+function calculateAllGroupsTotals(groups: CombinedRuleGroup[]): AlertGroupTotals {
+  const totals: Record<string, number> = {};
+
+  groups.forEach((group) => {
+    const groupTotals = group.totals;
+    Object.entries(groupTotals).forEach(([key, value]) => {
+      if (!totals[key]) {
+        totals[key] = 0;
+      }
+
+      totals[key] += value;
+    });
+  });
+
+  return totals;
+}
+
 function promRuleToCombinedRule(rule: Rule, namespace: CombinedRuleNamespace, group: CombinedRuleGroup): CombinedRule {
   return {
     name: rule.name,
@@ -171,6 +343,8 @@ function promRuleToCombinedRule(rule: Rule, namespace: CombinedRuleNamespace, gr
     promRule: rule,
     namespace: namespace,
     group,
+    instanceTotals: isAlertingRule(rule) ? calculateRuleTotals(rule) : {},
+    filteredInstanceTotals: isAlertingRule(rule) ? calculateRuleFilteredTotals(rule) : {},
   };
 }
 
@@ -188,6 +362,8 @@ function rulerRuleToCombinedRule(
         rulerRule: rule,
         namespace,
         group,
+        instanceTotals: {},
+        filteredInstanceTotals: {},
       }
     : isRecordingRulerRule(rule)
     ? {
@@ -198,6 +374,8 @@ function rulerRuleToCombinedRule(
         rulerRule: rule,
         namespace,
         group,
+        instanceTotals: {},
+        filteredInstanceTotals: {},
       }
     : {
         name: rule.grafana_alert.title,
@@ -207,6 +385,8 @@ function rulerRuleToCombinedRule(
         rulerRule: rule,
         namespace,
         group,
+        instanceTotals: {},
+        filteredInstanceTotals: {},
       };
 }
 
