@@ -1,6 +1,7 @@
 import React from 'react';
 
 import { Checkbox } from '@grafana/ui';
+import { t } from 'app/core/internationalization';
 
 import { DashboardTreeHeaderProps, SelectionState } from '../types';
 
@@ -11,6 +12,7 @@ export default function CheckboxHeaderCell({ isSelected, onAllSelectionChange }:
     <Checkbox
       value={state === SelectionState.Selected}
       indeterminate={state === SelectionState.Mixed}
+      aria-label={t('browse-dashboards.dashboards-tree.select-all-header-checkbox', 'Select all')}
       onChange={(ev) => {
         if (state === SelectionState.Mixed) {
           // Ensure clicking an indeterminate checkbox always clears the selection
