@@ -10,7 +10,6 @@ import {
   SelectableValue,
 } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
-import { Stack } from '@grafana/experimental';
 import { getDataSourceSrv, locationService } from '@grafana/runtime';
 import { AnnotationPanelFilter } from '@grafana/schema/src/raw/dashboard/x/dashboard_types.gen';
 import {
@@ -23,6 +22,7 @@ import {
   MultiSelect,
   Select,
   useStyles2,
+  Stack,
 } from '@grafana/ui';
 import { ColorValueEditor } from 'app/core/components/OptionsUI/color';
 import config from 'app/core/config';
@@ -72,10 +72,26 @@ export const AnnotationSettingsEdit = ({ editIdx, dashboard }: Props) => {
   };
 
   const onDataSourceChange = (ds: DataSourceInstanceSettings) => {
-    onUpdate({
-      ...annotation,
-      datasource: getDataSourceRef(ds),
-    });
+    const dsRef = getDataSourceRef(ds);
+
+    if (annotation.datasource?.type !== dsRef.type) {
+      onUpdate({
+        datasource: dsRef,
+        builtIn: annotation.builtIn,
+        enable: annotation.enable,
+        iconColor: annotation.iconColor,
+        name: annotation.name,
+        hide: annotation.hide,
+        filter: annotation.filter,
+        mappings: annotation.mappings,
+        type: annotation.type,
+      });
+    } else {
+      onUpdate({
+        ...annotation,
+        datasource: dsRef,
+      });
+    }
   };
 
   const onChange = (ev: React.FocusEvent<HTMLInputElement>) => {
