@@ -30,8 +30,6 @@ const setupTestContext = (options: Partial<Props>) => {
         timepicker: {
           refresh_intervals: ['5s', '10s', '30s', '1m', '5m', '15m', '30m', '1h', '2h', '1d', '2d'],
           time_options: ['5m', '15m', '1h', '6h', '12h', '24h', '2d', '7d', '30d'],
-          collapse: true,
-          enable: true,
           hidden: false,
         },
         timezone: 'utc',
