@@ -1,13 +1,27 @@
-import React, { useState } from 'react';
+import React, { ChangeEvent, useState } from 'react';
 import { connect, ConnectedProps } from 'react-redux';
 
 import { TimeZone } from '@grafana/data';
-import { CollapsableSection, Field, Input, RadioButtonGroup, TagsInput } from '@grafana/ui';
+import { config } from '@grafana/runtime';
+import {
+  CollapsableSection,
+  Field,
+  Input,
+  RadioButtonGroup,
+  TagsInput,
+  Label,
+  HorizontalGroup,
+  TextArea,
+  Box,
+} from '@grafana/ui';
 import { Page } from 'app/core/components/Page/Page';
 import { FolderPicker } from 'app/core/components/Select/FolderPicker';
+import { t, Trans } from 'app/core/internationalization';
 import { updateTimeZoneDashboard, updateWeekStartDashboard } from 'app/features/dashboard/state/actions';
 
 import { DeleteDashboardButton } from '../DeleteDashboard/DeleteDashboardButton';
+import { GenAIDashDescriptionButton } from '../GenAI/GenAIDashDescriptionButton';
+import { GenAIDashTitleButton } from '../GenAI/GenAIDashTitleButton';
 
 import { TimePickerSettings } from './TimePickerSettings';
 import { SettingsPageProps } from './types';
@@ -27,6 +41,9 @@ export function GeneralSettingsUnconnected({
   sectionNav,
 }: Props): JSX.Element {
   const [renderCounter, setRenderCounter] = useState(0);
+  const [dashboardTitle, setDashboardTitle] = useState(dashboard.title);
+  const [dashboardDescription, setDashboardDescription] = useState(dashboard.description);
+  const pageNav = config.featureToggles.dockedMegaMenu ? sectionNav.node.parentItem : undefined;
 
   const onFolderChange = (newUID: string, newTitle: string) => {
     dashboard.meta.folderUid = newUID;
@@ -35,11 +52,21 @@ export function GeneralSettingsUnconnected({
     setRenderCounter(renderCounter + 1);
   };
 
-  const onBlur = (event: React.FocusEvent<HTMLInputElement>) => {
-    if (event.currentTarget.name === 'title' || event.currentTarget.name === 'description') {
-      dashboard[event.currentTarget.name] = event.currentTarget.value;
-    }
-  };
+  const onTitleChange = React.useCallback(
+    (title: string) => {
+      dashboard.title = title;
+      setDashboardTitle(title);
+    },
+    [setDashboardTitle, dashboard]
+  );
+
+  const onDescriptionChange = React.useCallback(
+    (description: string) => {
+      dashboard.description = description;
+      setDashboardDescription(description);
+    },
+    [setDashboardDescription, dashboard]
+  );
 
   const onTooltipChange = (graphTooltip: number) => {
     dashboard.graphTooltip = graphTooltip;
@@ -92,20 +119,54 @@ export function GeneralSettingsUnconnected({
   ];
 
   return (
-    <Page navModel={sectionNav}>
+    <Page navModel={sectionNav} pageNav={pageNav}>
       <div style={{ maxWidth: '600px' }}>
-        <div className="gf-form-group">
-          <Field label="Name">
-            <Input id="title-input" name="title" onBlur={onBlur} defaultValue={dashboard.title} />
+        <Box marginBottom={5}>
+          <Field
+            label={
+              <HorizontalGroup justify="space-between">
+                <Label htmlFor="title-input">
+                  <Trans i18nKey="dashboard-settings.general.title-label">Title</Trans>
+                </Label>
+
+                {config.featureToggles.dashgpt && (
+                  <GenAIDashTitleButton onGenerate={onTitleChange} dashboard={dashboard} />
+                )}
+              </HorizontalGroup>
+            }
+          >
+            <Input
+              id="title-input"
+              name="title"
+              value={dashboardTitle}
+              onChange={(e: ChangeEvent<HTMLInputElement>) => onTitleChange(e.target.value)}
+            />
           </Field>
-          <Field label="Description">
-            <Input id="description-input" name="description" onBlur={onBlur} defaultValue={dashboard.description} />
+          <Field
+            label={
+              <HorizontalGroup justify="space-between">
+                <Label htmlFor="description-input">
+                  {t('dashboard-settings.general.description-label', 'Description')}
+                </Label>
+
+                {config.featureToggles.dashgpt && (
+                  <GenAIDashDescriptionButton onGenerate={onDescriptionChange} dashboard={dashboard} />
+                )}
+              </HorizontalGroup>
+            }
+          >
+            <TextArea
+              id="description-input"
+              name="description"
+              value={dashboardDescription}
+              onChange={(e: ChangeEvent<HTMLTextAreaElement>) => onDescriptionChange(e.target.value)}
+            />
           </Field>
-          <Field label="Tags">
+          <Field label={t('dashboard-settings.general.tags-label', 'Tags')}>
             <TagsInput id="tags-input" tags={dashboard.tags} onChange={onTagsChange} width={40} />
           </Field>
 
-          <Field label="Folder">
+          <Field label={t('dashboard-settings.general.folder-label', 'Folder')}>
             <FolderPicker
               value={dashboard.meta.folderUid}
               onChange={onFolderChange}
@@ -119,12 +180,15 @@ export function GeneralSettingsUnconnected({
           </Field>
 
           <Field
-            label="Editable"
-            description="Set to read-only to disable all editing. Reload the dashboard for changes to take effect"
+            label={t('dashboard-settings.general.editable-label', 'Editable')}
+            description={t(
+              'dashboard-settings.general.editable-description',
+              'Set to read-only to disable all editing. Reload the dashboard for changes to take effect'
+            )}
           >
             <RadioButtonGroup value={dashboard.editable} options={editableOptions} onChange={onEditableChange} />
           </Field>
-        </div>
+        </Box>
 
         <TimePickerSettings
           onTimeZoneChange={onTimeZoneChange}
@@ -142,10 +206,13 @@ export function GeneralSettingsUnconnected({
         />
 
         {/* @todo: Update "Graph tooltip" description to remove prompt about reloading when resolving #46581 */}
-        <CollapsableSection label="Panel options" isOpen={true}>
+        <CollapsableSection label={t('dashboard-settings.general.panel-options-label', 'Panel options')} isOpen={true}>
           <Field
-            label="Graph tooltip"
-            description="Controls tooltip and hover highlight behavior across different panels. Reload the dashboard for changes to take effect"
+            label={t('dashboard-settings.general.panel-options-graph-tooltip-label', 'Graph tooltip')}
+            description={t(
+              'dashboard-settings.general.panel-options-graph-tooltip-description',
+              'Controls tooltip and hover highlight behavior across different panels. Reload the dashboard for changes to take effect'
+            )}
           >
             <RadioButtonGroup
               onChange={onTooltipChange}
@@ -155,9 +222,7 @@ export function GeneralSettingsUnconnected({
           </Field>
         </CollapsableSection>
 
-        <div className="gf-form-button-row">
-          {dashboard.meta.canDelete && <DeleteDashboardButton dashboard={dashboard} />}
-        </div>
+        <Box marginTop={3}>{dashboard.meta.canDelete && <DeleteDashboardButton />}</Box>
       </div>
     </Page>
   );
