@@ -1,10 +1,12 @@
+import { css } from '@emotion/css';
 import React, { useState } from 'react';
 
 import { arrayUtils } from '@grafana/data';
-import { DeleteButton, HorizontalGroup, Icon, IconButton, TagList } from '@grafana/ui';
+import { DashboardLink } from '@grafana/schema';
+import { DeleteButton, HorizontalGroup, Icon, IconButton, TagList, useStyles2 } from '@grafana/ui';
 import EmptyListCTA from 'app/core/components/EmptyListCTA/EmptyListCTA';
 
-import { DashboardModel, DashboardLink } from '../../state/DashboardModel';
+import { DashboardModel } from '../../state/DashboardModel';
 import { ListNewButton } from '../DashboardSettings/ListNewButton';
 
 type LinkSettingsListProps = {
@@ -14,6 +16,8 @@ type LinkSettingsListProps = {
 };
 
 export const LinkSettingsList = ({ dashboard, onNew, onEdit }: LinkSettingsListProps) => {
+  const styles = useStyles2(getStyles);
+
   const [links, setLinks] = useState(dashboard.links);
 
   const moveLink = (idx: number, direction: number) => {
@@ -69,8 +73,8 @@ export const LinkSettingsList = ({ dashboard, onNew, onEdit }: LinkSettingsListP
               </td>
               <td role="gridcell">
                 <HorizontalGroup>
-                  {link.title && <span>{link.title}</span>}
-                  {link.type === 'link' && <span>{link.url}</span>}
+                  {link.title && <span className={styles.titleWrapper}>{link.title}</span>}
+                  {link.type === 'link' && <span className={styles.urlWrapper}>{link.url}</span>}
                   {link.type === 'dashboards' && <TagList tags={link.tags ?? []} />}
                 </HorizontalGroup>
               </td>
@@ -100,3 +104,16 @@ export const LinkSettingsList = ({ dashboard, onNew, onEdit }: LinkSettingsListP
     </>
   );
 };
+
+const getStyles = () => ({
+  titleWrapper: css`
+    width: 20vw;
+    text-overflow: ellipsis;
+    overflow: hidden;
+  `,
+  urlWrapper: css`
+    width: 40vw;
+    text-overflow: ellipsis;
+    overflow: hidden;
+  `,
+});
