@@ -1,5 +1,5 @@
 import { css, cx } from '@emotion/css';
-import React from 'react';
+import React, { useId } from 'react';
 import Highlighter from 'react-highlight-words';
 
 import {
@@ -23,7 +23,7 @@ interface DynamicConfigValueEditorProps {
   searchQuery: string;
 }
 
-export const DynamicConfigValueEditor: React.FC<DynamicConfigValueEditorProps> = ({
+export const DynamicConfigValueEditor = ({
   property,
   context,
   registry,
@@ -31,10 +31,12 @@ export const DynamicConfigValueEditor: React.FC<DynamicConfigValueEditorProps> =
   onRemove,
   isSystemOverride,
   searchQuery,
-}) => {
+}: DynamicConfigValueEditorProps) => {
   const styles = useStyles2(getStyles);
   const item = registry?.getIfExists(property.id);
 
+  const componentId = useId();
+
   if (!item) {
     return null;
   }
@@ -51,26 +53,29 @@ export const DynamicConfigValueEditor: React.FC<DynamicConfigValueEditorProps> =
   /* eslint-disable react/display-name */
   const renderLabel =
     (includeDescription = true, includeCounter = false) =>
-    (isExpanded = false) =>
-      (
-        <HorizontalGroup justify="space-between">
-          <Label category={labelCategory} description={includeDescription ? item.description : undefined}>
-            <Highlighter
-              textToHighlight={item.name}
-              searchWords={[searchQuery]}
-              highlightClassName={'search-fragment-highlight'}
-            />
-            {!isExpanded && includeCounter && item.getItemsCount && (
-              <Counter value={item.getItemsCount(property.value)} />
-            )}
-          </Label>
-          {!isSystemOverride && (
-            <div>
-              <IconButton name="times" onClick={onRemove} />
-            </div>
+    (isExpanded = false) => (
+      <HorizontalGroup justify="space-between">
+        <Label
+          category={labelCategory}
+          description={includeDescription ? item.description : undefined}
+          htmlFor={componentId}
+        >
+          <Highlighter
+            textToHighlight={item.name}
+            searchWords={[searchQuery]}
+            highlightClassName={'search-fragment-highlight'}
+          />
+          {!isExpanded && includeCounter && item.getItemsCount && (
+            <Counter value={item.getItemsCount(property.value)} />
           )}
-        </HorizontalGroup>
-      );
+        </Label>
+        {!isSystemOverride && (
+          <div>
+            <IconButton name="times" onClick={onRemove} tooltip="Remove label" />
+          </div>
+        )}
+      </HorizontalGroup>
+    );
   /* eslint-enable react/display-name */
 
   if (isCollapsible) {
@@ -106,6 +111,7 @@ export const DynamicConfigValueEditor: React.FC<DynamicConfigValueEditorProps> =
             }}
             item={item}
             context={context}
+            id={componentId}
           />
         </Field>
       </div>
