@@ -6,20 +6,19 @@ import { Subscription } from 'rxjs';
 
 import { FieldConfigSource, GrafanaTheme2, NavModel, NavModelItem, PageLayoutType } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
-import { Stack } from '@grafana/experimental';
-import { config, locationService } from '@grafana/runtime';
+import { locationService } from '@grafana/runtime';
 import {
   Button,
   HorizontalGroup,
   InlineSwitch,
   ModalsController,
-  PageToolbar,
   RadioButtonGroup,
   stylesFactory,
   Themeable2,
   ToolbarButton,
   ToolbarButtonRow,
   withTheme2,
+  Stack,
 } from '@grafana/ui';
 import { AppChromeUpdate } from 'app/core/components/AppChrome/AppChromeUpdate';
 import { Page } from 'app/core/components/Page/Page';
@@ -47,7 +46,7 @@ import { PanelEditorTableView } from './PanelEditorTableView';
 import { PanelEditorTabs } from './PanelEditorTabs';
 import { VisualizationButton } from './VisualizationButton';
 import { discardPanelChanges, initPanelEditor, updatePanelEditorUIState } from './state/actions';
-import { toggleTableView } from './state/reducers';
+import { PanelEditorUIState, toggleTableView } from './state/reducers';
 import { getPanelEditorTabs } from './state/selectors';
 import { DisplayMode, displayModes, PanelEditorTab } from './types';
 import { calculatePanelSize } from './utils';
@@ -167,13 +166,13 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
     });
   };
 
-  onPanelOptionsChanged = (options: any) => {
+  onPanelOptionsChanged = (options: PanelModel['options']) => {
     // we do not need to trigger force update here as the function call below
     // fires PanelOptionsChangedEvent which we subscribe to above
     this.props.panel.updateOptions(options);
   };
 
-  onPanelConfigChanged = (configKey: keyof PanelModel, value: any) => {
+  onPanelConfigChanged = (configKey: keyof PanelModel, value: unknown) => {
     this.props.panel.setProperty(configKey, value);
     this.props.panel.render();
     this.forceUpdate();
@@ -241,32 +240,45 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
     );
   }
 
-  renderPanelAndEditor(styles: EditorStyles) {
+  renderPanelAndEditor(uiState: PanelEditorUIState, styles: EditorStyles) {
     const { panel, dashboard, plugin, tab } = this.props;
     const tabs = getPanelEditorTabs(tab, plugin);
     const isOnlyPanel = tabs.length === 0;
     const panelPane = this.renderPanel(styles, isOnlyPanel);
 
     if (tabs.length === 0) {
-      return panelPane;
+      return <div className={styles.onlyPanel}>{panelPane}</div>;
     }
 
-    return [
-      panelPane,
-      <div
-        className={styles.tabsWrapper}
-        aria-label={selectors.components.PanelEditor.DataPane.content}
-        key="panel-editor-tabs"
+    return (
+      <SplitPaneWrapper
+        splitOrientation="horizontal"
+        maxSize={-200}
+        paneSize={uiState.topPaneSize}
+        primary="first"
+        secondaryPaneStyle={{ minHeight: 0 }}
+        onDragFinished={(size) => {
+          if (size) {
+            updatePanelEditorUIState({ topPaneSize: size / window.innerHeight });
+          }
+        }}
       >
-        <PanelEditorTabs
-          key={panel.key}
-          panel={panel}
-          dashboard={dashboard}
-          tabs={tabs}
-          onChangeTab={this.onChangeTab}
-        />
-      </div>,
-    ];
+        {panelPane}
+        <div
+          className={styles.tabsWrapper}
+          aria-label={selectors.components.PanelEditor.DataPane.content}
+          key="panel-editor-tabs"
+        >
+          <PanelEditorTabs
+            key={panel.key}
+            panel={panel}
+            dashboard={dashboard}
+            tabs={tabs}
+            onChangeTab={this.onChangeTab}
+          />
+        </div>
+      </SplitPaneWrapper>
+    );
   }
 
   renderTemplateVariables(styles: EditorStyles) {
@@ -309,7 +321,7 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
   }
 
   renderEditorActions() {
-    const size = config.featureToggles.topnav ? 'sm' : 'md';
+    const size = 'sm';
     let editorActions = [
       <Button
         onClick={this.onDiscard}
@@ -417,24 +429,8 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
     this.setState({ showSaveLibraryPanelModal: false });
   };
 
-  renderToolbar() {
-    if (config.featureToggles.topnav) {
-      return (
-        <AppChromeUpdate
-          actions={<ToolbarButtonRow alignment="right">{this.renderEditorActions()}</ToolbarButtonRow>}
-        />
-      );
-    }
-
-    return (
-      <PageToolbar title={this.props.dashboard.title} section="Edit Panel" onGoBack={this.onGoBackToDashboard}>
-        {this.renderEditorActions()}
-      </PageToolbar>
-    );
-  }
-
   render() {
-    const { initDone, updatePanelEditorUIState, uiState, theme, sectionNav, pageNav, className } = this.props;
+    const { initDone, uiState, theme, sectionNav, pageNav, className, updatePanelEditorUIState } = this.props;
     const styles = getStyles(theme, this.props);
 
     if (!initDone) {
@@ -447,23 +443,36 @@ export class PanelEditorUnconnected extends PureComponent<Props> {
         pageNav={pageNav}
         aria-label={selectors.components.PanelEditor.General.content}
         layout={PageLayoutType.Custom}
-        toolbar={this.renderToolbar()}
         className={className}
       >
+        <AppChromeUpdate
+          actions={<ToolbarButtonRow alignment="right">{this.renderEditorActions()}</ToolbarButtonRow>}
+        />
         <div className={styles.wrapper}>
           <div className={styles.verticalSplitPanesWrapper}>
-            <SplitPaneWrapper
-              leftPaneComponents={this.renderPanelAndEditor(styles)}
-              rightPaneComponents={this.renderOptionsPane()}
-              uiState={uiState}
-              updateUiState={updatePanelEditorUIState}
-              rightPaneVisible={uiState.isPanelOptionsVisible}
-            />
+            {!uiState.isPanelOptionsVisible ? (
+              this.renderPanelAndEditor(uiState, styles)
+            ) : (
+              <SplitPaneWrapper
+                splitOrientation="vertical"
+                maxSize={-300}
+                paneSize={uiState.rightPaneSize}
+                primary="second"
+                onDragFinished={(size) => {
+                  if (size) {
+                    updatePanelEditorUIState({ rightPaneSize: size / window.innerWidth });
+                  }
+                }}
+              >
+                {this.renderPanelAndEditor(uiState, styles)}
+                {this.renderOptionsPane()}
+              </SplitPaneWrapper>
+            )}
           </div>
           {this.state.showSaveLibraryPanelModal && (
             <SaveLibraryPanelModal
               panel={this.props.panel as PanelModelWithLibraryPanel}
-              folderId={this.props.dashboard.meta.folderId as number}
+              folderUid={this.props.dashboard.meta.folderUid ?? ''}
               onConfirm={this.onConfirmAndDismissLibarayPanelModel}
               onDiscard={this.onDiscard}
               onDismiss={this.onConfirmAndDismissLibarayPanelModel}
@@ -490,7 +499,7 @@ export const getStyles = stylesFactory((theme: GrafanaTheme2, props: Props) => {
       flexGrow: 1,
       minHeight: 0,
       display: 'flex',
-      paddingTop: config.featureToggles.topnav ? theme.spacing(2) : 0,
+      paddingTop: theme.spacing(2),
     }),
     verticalSplitPanesWrapper: css`
       display: flex;
@@ -529,6 +538,11 @@ export const getStyles = stylesFactory((theme: GrafanaTheme2, props: Props) => {
       justify-content: space-between;
       flex-wrap: wrap;
     `,
+    angularWarning: css`
+      display: flex;
+      height: theme.spacing(4);
+      align-items: center;
+    `,
     toolbarLeft: css`
       padding-left: ${theme.spacing(1)};
     `,
@@ -539,6 +553,12 @@ export const getStyles = stylesFactory((theme: GrafanaTheme2, props: Props) => {
       position: relative;
       flex-direction: column;
     `,
+    onlyPanel: css`
+      height: 100%;
+      position: absolute;
+      overflow: hidden;
+      width: 100%;
+    `,
   };
 });
 
