@@ -1,4 +1,4 @@
-import React, { FC, useCallback, useMemo } from 'react';
+import React, { useCallback, useMemo } from 'react';
 
 import { SelectableValue } from '@grafana/data';
 import { Select } from '@grafana/ui';
@@ -12,13 +12,13 @@ export interface Props {
   onChange: (name: string | null) => void;
 }
 
-export const RepeatRowSelect: FC<Props> = ({ repeat, onChange, id }) => {
+export const RepeatRowSelect = ({ repeat, onChange, id }: Props) => {
   const variables = useSelector((state) => {
     return getVariablesByKey(getLastKey(state), state);
   });
 
   const variableOptions = useMemo(() => {
-    const options = variables.map((item: any) => {
+    const options: Array<SelectableValue<string | null>> = variables.map((item) => {
       return { label: item.name, value: item.name };
     });
 
