@@ -9,9 +9,10 @@ export interface RowOptionsButtonProps {
   title: string;
   repeat?: string | null;
   onUpdate: OnRowOptionsUpdate;
+  warning?: React.ReactNode;
 }
 
-export const RowOptionsButton = ({ repeat, title, onUpdate }: RowOptionsButtonProps) => {
+export const RowOptionsButton = ({ repeat, title, onUpdate, warning }: RowOptionsButtonProps) => {
   const onUpdateChange = (hideModal: () => void) => (title: string, repeat?: string | null) => {
     onUpdate(title, repeat);
     hideModal();
@@ -26,7 +27,13 @@ export const RowOptionsButton = ({ repeat, title, onUpdate }: RowOptionsButtonPr
             className="pointer"
             aria-label="Row options"
             onClick={() => {
-              showModal(RowOptionsModal, { title, repeat, onDismiss: hideModal, onUpdate: onUpdateChange(hideModal) });
+              showModal(RowOptionsModal, {
+                title,
+                repeat,
+                onDismiss: hideModal,
+                onUpdate: onUpdateChange(hideModal),
+                warning,
+              });
             }}
           >
             <Icon name="cog" />
