@@ -1,31 +1,31 @@
 import { css } from '@emotion/css';
 import React from 'react';
 
-import { Modal, stylesFactory } from '@grafana/ui';
+import { Modal, useStyles2 } from '@grafana/ui';
 
 import { OnRowOptionsUpdate, RowOptionsForm } from './RowOptionsForm';
 
 export interface RowOptionsModalProps {
   title: string;
   repeat?: string | null;
+  warning?: React.ReactNode;
   onDismiss: () => void;
   onUpdate: OnRowOptionsUpdate;
 }
 
-export const RowOptionsModal = ({ repeat, title, onDismiss, onUpdate }: RowOptionsModalProps) => {
-  const styles = getStyles();
+export const RowOptionsModal = ({ repeat, title, onDismiss, onUpdate, warning }: RowOptionsModalProps) => {
+  const styles = useStyles2(getStyles);
+
   return (
     <Modal isOpen={true} title="Row options" icon="copy" onDismiss={onDismiss} className={styles.modal}>
-      <RowOptionsForm repeat={repeat} title={title} onCancel={onDismiss} onUpdate={onUpdate} />
+      <RowOptionsForm repeat={repeat} title={title} onCancel={onDismiss} onUpdate={onUpdate} warning={warning} />
     </Modal>
   );
 };
 
-const getStyles = stylesFactory(() => {
-  return {
-    modal: css`
-      label: RowOptionsModal;
-      width: 500px;
-    `,
-  };
+const getStyles = () => ({
+  modal: css`
+    label: RowOptionsModal;
+    width: 500px;
+  `,
 });
