@@ -1,9 +1,7 @@
 import React, { useMemo, useState } from 'react';
-import { useAsync } from 'react-use';
 
 import { config, isFetchError } from '@grafana/runtime';
 import { Drawer, Tab, TabsBar } from '@grafana/ui';
-import { backendSrv } from 'app/core/services/backend_srv';
 
 import { jsonDiff } from '../VersionHistory/utils';
 
@@ -18,18 +16,10 @@ import { useDashboardSave } from './useDashboardSave';
 
 export const SaveDashboardDrawer = ({ dashboard, onDismiss, onSaveSuccess, isCopy }: SaveDashboardModalProps) => {
   const [options, setOptions] = useState<SaveDashboardOptions>({});
-
+  const previous = dashboard.getOriginalDashboard();
   const isProvisioned = dashboard.meta.provisioned;
   const isNew = dashboard.version === 0;
-
-  const previous = useAsync(async () => {
-    if (isNew) {
-      return undefined;
-    }
-
-    const result = await backendSrv.getDashboardByUid(dashboard.uid);
-    return result.dashboard;
-  }, [dashboard, isNew]);
+  const [errorIsHandled, setErrorIsHandled] = useState(false);
 
   const data = useMemo<SaveDashboardData>(() => {
     const clone = dashboard.getSaveModelClone({
@@ -37,14 +27,11 @@ export const SaveDashboardDrawer = ({ dashboard, onDismiss, onSaveSuccess, isCop
       saveVariables: Boolean(options.saveVariables),
     });
 
-    if (!previous.value) {
+    if (!previous) {
       return { clone, diff: {}, diffCount: 0, hasChanges: false };
     }
 
-    const cloneJSON = JSON.stringify(clone, null, 2);
-    const cloneSafe = JSON.parse(cloneJSON); // avoids undefined issues
-
-    const diff = jsonDiff(previous.value, cloneSafe);
+    const diff = jsonDiff(previous, clone);
     let diffCount = 0;
     for (const d of Object.values(diff)) {
       diffCount += d.length;
@@ -56,10 +43,10 @@ export const SaveDashboardDrawer = ({ dashboard, onDismiss, onSaveSuccess, isCop
       diffCount,
       hasChanges: diffCount > 0 && !isNew,
     };
-  }, [dashboard, previous.value, options, isNew]);
+  }, [dashboard, previous, options, isNew]);
 
   const [showDiff, setShowDiff] = useState(false);
-  const { state, onDashboardSave } = useDashboardSave(dashboard, isCopy);
+  const { state, onDashboardSave } = useDashboardSave(isCopy);
   const onSuccess = onSaveSuccess
     ? () => {
         onDismiss();
@@ -69,7 +56,7 @@ export const SaveDashboardDrawer = ({ dashboard, onDismiss, onSaveSuccess, isCop
 
   const renderSaveBody = () => {
     if (showDiff) {
-      return <SaveDashboardDiff diff={data.diff} oldValue={previous.value} newValue={data.clone} />;
+      return <SaveDashboardDiff diff={data.diff} oldValue={previous} newValue={data.clone} />;
     }
 
     if (isNew || isCopy) {
@@ -103,18 +90,14 @@ export const SaveDashboardDrawer = ({ dashboard, onDismiss, onSaveSuccess, isCop
     );
   };
 
-  if (
-    state.error &&
-    isFetchError(state.error) &&
-    !state.error.isHandled &&
-    proxyHandlesError(state.error.data.status)
-  ) {
+  if (state.error && !errorIsHandled && isFetchError(state.error) && proxyHandlesError(state.error.data.status)) {
     return (
       <SaveDashboardErrorProxy
         error={state.error}
         dashboard={dashboard}
         dashboardSaveModel={data.clone}
         onDismiss={onDismiss}
+        setErrorIsHandled={setErrorIsHandled}
       />
     );
   }
@@ -139,7 +122,6 @@ export const SaveDashboardDrawer = ({ dashboard, onDismiss, onSaveSuccess, isCop
           )}
         </TabsBar>
       }
-      scrollableContent
     >
       {renderSaveBody()}
 
