@@ -1,22 +1,24 @@
 import { useEffect } from 'react';
-import { useSelector } from 'react-redux';
 import { useAsyncFn } from 'react-use';
 
 import { locationUtil } from '@grafana/data';
 import { locationService } from '@grafana/runtime';
 import { useAppNotification } from 'app/core/copy/appNotification';
-import { StoreState } from 'app/types';
+import { useSelector } from 'app/types';
 
+import { dashboardWatcher } from '../../../live/dashboard/dashboardWatcher';
 import { DashboardModel } from '../../state';
 
 import { historySrv } from './HistorySrv';
 
 const restoreDashboard = async (version: number, dashboard: DashboardModel) => {
+  // Skip the watcher logic for this save since it's handled by the hook
+  dashboardWatcher.ignoreNextSave();
   return await historySrv.restoreDashboard(dashboard, version);
 };
 
 export const useDashboardRestore = (version: number) => {
-  const dashboard = useSelector((state: StoreState) => state.dashboard.getModel());
+  const dashboard = useSelector((state) => state.dashboard.getModel());
   const [state, onRestoreDashboard] = useAsyncFn(async () => await restoreDashboard(version, dashboard!), []);
   const notifyApp = useAppNotification();
 
