@@ -1,11 +1,9 @@
-import classNames from 'classnames';
 import React, { PureComponent } from 'react';
 import { connect, MapDispatchToProps, MapStateToProps } from 'react-redux';
 import { Subscription } from 'rxjs';
 
 import { getDefaultTimeRange, LoadingState, PanelData, PanelPlugin } from '@grafana/data';
-import { selectors } from '@grafana/e2e-selectors';
-import { AngularComponent, getAngularLoader, locationService } from '@grafana/runtime';
+import { AngularComponent, getAngularLoader } from '@grafana/runtime';
 import { PanelChrome } from '@grafana/ui';
 import config from 'app/core/config';
 import { PANEL_BORDER } from 'app/core/constants';
@@ -13,13 +11,11 @@ import { setPanelAngularComponent } from 'app/features/panel/state/reducers';
 import { getPanelStateForModel } from 'app/features/panel/state/selectors';
 import { StoreState } from 'app/types';
 
-import { isSoloRoute } from '../../../routes/utils';
 import { getTimeSrv, TimeSrv } from '../services/TimeSrv';
 import { DashboardModel, PanelModel } from '../state';
 import { getPanelChromeProps } from '../utils/getPanelChromeProps';
 
-import { PanelHeader } from './PanelHeader/PanelHeader';
-import { PanelHeaderMenuWrapperNew } from './PanelHeader/PanelHeaderMenuWrapper';
+import { PanelHeaderMenuWrapper } from './PanelHeader/PanelHeaderMenuWrapper';
 
 interface OwnProps {
   panel: PanelModel;
@@ -180,85 +176,44 @@ export class PanelChromeAngularUnconnected extends PureComponent<Props, State> {
   }
 
   render() {
-    const { dashboard, panel, isViewing, isEditing, plugin } = this.props;
+    const { dashboard, panel } = this.props;
     const { errorMessage, data } = this.state;
     const { transparent } = panel;
-    const alertState = data.alertState?.state;
 
     const panelChromeProps = getPanelChromeProps({ ...this.props, data });
 
-    const containerClassNames = classNames({
-      'panel-container': true,
-      'panel-container--absolute': isSoloRoute(locationService.getLocation().pathname),
-      'panel-container--transparent': transparent,
-      'panel-container--no-title': this.hasOverlayHeader(),
-      'panel-has-alert': panel.alert !== undefined,
-      [`panel-alert-state--${alertState}`]: alertState !== undefined,
-    });
+    // Shift the hover menu down if it's on the top row so it doesn't get clipped by topnav
+    const hoverHeaderOffset = (panel.gridPos?.y ?? 0) === 0 ? -16 : undefined;
 
-    const panelContentClassNames = classNames({
-      'panel-content': true,
-      'panel-content--no-padding': plugin.noPadding,
-    });
+    const menu = (
+      <div data-testid="panel-dropdown">
+        <PanelHeaderMenuWrapper panel={panel} dashboard={dashboard} loadingState={data.state} />
+      </div>
+    );
 
-    if (config.featureToggles.newPanelChromeUI) {
-      // Shift the hover menu down if it's on the top row so it doesn't get clipped by topnav
-      const hoverHeaderOffset = (panel.gridPos?.y ?? 0) === 0 ? -16 : undefined;
-
-      const menu = (
-        <div data-testid="panel-dropdown">
-          <PanelHeaderMenuWrapperNew panel={panel} dashboard={dashboard} loadingState={data.state} />
-        </div>
-      );
-
-      return (
-        <PanelChrome
-          width={this.props.width}
-          height={this.props.height}
-          title={panelChromeProps.title}
-          loadingState={data.state}
-          statusMessage={errorMessage}
-          statusMessageOnClick={panelChromeProps.onOpenErrorInspect}
-          description={panelChromeProps.description}
-          titleItems={panelChromeProps.titleItems}
-          menu={this.props.hideMenu ? undefined : menu}
-          dragClass={panelChromeProps.dragClass}
-          dragClassCancel="grid-drag-cancel"
-          padding={panelChromeProps.padding}
-          hoverHeaderOffset={hoverHeaderOffset}
-          hoverHeader={panelChromeProps.hasOverlayHeader()}
-          displayMode={transparent ? 'transparent' : 'default'}
-          onCancelQuery={panelChromeProps.onCancelQuery}
-          onOpenMenu={panelChromeProps.onOpenMenu}
-        >
-          {() => <div ref={(element) => (this.element = element)} className="panel-height-helper" />}
-        </PanelChrome>
-      );
-    } else {
-      return (
-        <div
-          className={containerClassNames}
-          data-testid={selectors.components.Panels.Panel.title(panel.title)}
-          aria-label={selectors.components.Panels.Panel.containerByTitle(panel.title)}
-        >
-          <PanelHeader
-            panel={panel}
-            dashboard={dashboard}
-            title={panel.title}
-            description={panel.description}
-            links={panel.links}
-            error={errorMessage}
-            isViewing={isViewing}
-            isEditing={isEditing}
-            data={data}
-            alertState={alertState}
-          />
-          <div className={panelContentClassNames}>
-            <div ref={(element) => (this.element = element)} className="panel-height-helper" />
-          </div>
-        </div>
-      );
-    }
+    return (
+      <PanelChrome
+        width={this.props.width}
+        height={this.props.height}
+        title={panelChromeProps.title}
+        loadingState={data.state}
+        statusMessage={errorMessage}
+        statusMessageOnClick={panelChromeProps.onOpenErrorInspect}
+        description={panelChromeProps.description}
+        titleItems={panelChromeProps.titleItems}
+        menu={this.props.hideMenu ? undefined : menu}
+        dragClass={panelChromeProps.dragClass}
+        dragClassCancel="grid-drag-cancel"
+        padding={panelChromeProps.padding}
+        hoverHeaderOffset={hoverHeaderOffset}
+        hoverHeader={panelChromeProps.hasOverlayHeader()}
+        displayMode={transparent ? 'transparent' : 'default'}
+        onCancelQuery={panelChromeProps.onCancelQuery}
+        onOpenMenu={panelChromeProps.onOpenMenu}
+      >
+        {() => <div ref={(element) => (this.element = element)} className="panel-height-helper" />}
+      </PanelChrome>
+    );
   }
 }
 
