@@ -128,9 +128,7 @@ describe('PanelStateWrapper', () => {
           </Provider>
         );
 
-        const button = screen.getByRole('button', {
-          name: selectors.components.Panels.Panel.headerCornerInfo('error'),
-        });
+        const button = screen.getByTestId(selectors.components.Panels.Panel.status('error'));
         expect(button).toBeInTheDocument();
         await act(async () => {
           fireEvent.focus(button);
