@@ -1,4 +1,3 @@
-import classNames from 'classnames';
 import React, { PureComponent } from 'react';
 import { Subscription } from 'rxjs';
 
@@ -17,13 +16,11 @@ import {
   PanelData,
   PanelPlugin,
   PanelPluginMeta,
-  PluginContextProvider,
   TimeRange,
   toDataFrameDTO,
   toUtc,
 } from '@grafana/data';
-import { selectors } from '@grafana/e2e-selectors';
-import { config, locationService, RefreshEvent } from '@grafana/runtime';
+import { RefreshEvent } from '@grafana/runtime';
 import { VizLegendOptions } from '@grafana/schema';
 import {
   ErrorBoundary,
@@ -33,7 +30,7 @@ import {
   SeriesVisibilityChangeMode,
   AdHocFilterItem,
 } from '@grafana/ui';
-import { PANEL_BORDER } from 'app/core/constants';
+import config from 'app/core/config';
 import { profiler } from 'app/core/profiler';
 import { applyPanelTimeOverrides } from 'app/features/dashboard/utils/panel';
 import { getDatasourceSrv } from 'app/features/plugins/datasource_srv';
@@ -43,7 +40,6 @@ import { changeSeriesColorConfigFactory } from 'app/plugins/panel/timeseries/ove
 import { dispatch } from 'app/store/store';
 import { RenderEvent } from 'app/types/events';
 
-import { isSoloRoute } from '../../../routes/utils';
 import { deleteAnnotation, saveAnnotation, updateAnnotation } from '../../annotations/api';
 import { getDashboardQueryRunner } from '../../query/state/DashboardQueryRunner/DashboardQueryRunner';
 import { getTimeSrv, TimeSrv } from '../services/TimeSrv';
@@ -51,10 +47,11 @@ import { DashboardModel, PanelModel } from '../state';
 import { getPanelChromeProps } from '../utils/getPanelChromeProps';
 import { loadSnapshotData } from '../utils/loadSnapshotData';
 
-import { PanelHeader } from './PanelHeader/PanelHeader';
-import { PanelHeaderMenuWrapperNew } from './PanelHeader/PanelHeaderMenuWrapper';
+import { PanelHeaderMenuWrapper } from './PanelHeader/PanelHeaderMenuWrapper';
+import { PanelLoadTimeMonitor } from './PanelLoadTimeMonitor';
 import { seriesVisibilityConfigFactory } from './SeriesVisibilityConfigFactory';
 import { liveTimer } from './liveTimer';
+import { PanelOptionsLogger } from './panelOptionsLogger';
 
 const DEFAULT_PLUGIN_ERROR = 'Error in plugin';
 
@@ -68,7 +65,7 @@ export interface Props {
   isDraggable?: boolean;
   width: number;
   height: number;
-  onInstanceStateChange: (value: any) => void;
+  onInstanceStateChange: (value: unknown) => void;
   timezone?: string;
   hideMenu?: boolean;
 }
@@ -77,7 +74,6 @@ export interface State {
   isFirstLoad: boolean;
   renderCounter: number;
   errorMessage?: string;
-  refreshWhenInView: boolean;
   context: PanelContext;
   data: PanelData;
   liveTime?: TimeRange;
@@ -87,6 +83,7 @@ export class PanelStateWrapper extends PureComponent<Props, State> {
   private readonly timeSrv: TimeSrv = getTimeSrv();
   private subs = new Subscription();
   private eventFilter: EventFilterOptions = { onlyLocal: true };
+  private panelOptionsLogger: PanelOptionsLogger | undefined = undefined;
 
   constructor(props: Props) {
     super(props);
@@ -97,7 +94,6 @@ export class PanelStateWrapper extends PureComponent<Props, State> {
     this.state = {
       isFirstLoad: true,
       renderCounter: 0,
-      refreshWhenInView: false,
       context: {
         eventsScope: '__global_',
         eventBus,
@@ -118,12 +114,22 @@ export class PanelStateWrapper extends PureComponent<Props, State> {
       },
       data: this.getInitialPanelDataState(),
     };
+
+    if (config.featureToggles.panelMonitoring && this.getPanelContextApp() === CoreApp.PanelEditor) {
+      const panelInfo = {
+        panelId: String(props.panel.id),
+        panelType: props.panel.type,
+        panelTitle: props.panel.title,
+      };
+
+      this.panelOptionsLogger = new PanelOptionsLogger(props.panel.getOptions(), props.panel.fieldConfig, panelInfo);
+    }
   }
 
   // Due to a mutable panel model we get the sync settings via function that proactively reads from the model
   getSync = () => (this.props.isEditing ? DashboardCursorSync.Off : this.props.dashboard.graphTooltip);
 
-  onInstanceStateChange = (value: any) => {
+  onInstanceStateChange = (value: unknown) => {
     this.props.onInstanceStateChange(value);
 
     this.setState({
@@ -250,7 +256,7 @@ export class PanelStateWrapper extends PureComponent<Props, State> {
   }
 
   componentDidUpdate(prevProps: Props) {
-    const { isInView, width } = this.props;
+    const { isInView, width, panel } = this.props;
     const { context } = this.state;
 
     const app = this.getPanelContextApp();
@@ -268,7 +274,7 @@ export class PanelStateWrapper extends PureComponent<Props, State> {
     if (isInView !== prevProps.isInView) {
       if (isInView) {
         // Check if we need a delayed refresh
-        if (this.state.refreshWhenInView) {
+        if (panel.refreshWhenInView) {
           this.onRefresh();
         }
       }
@@ -335,7 +341,7 @@ export class PanelStateWrapper extends PureComponent<Props, State> {
     const { dashboard, panel, isInView, width } = this.props;
 
     if (!isInView) {
-      this.setState({ refreshWhenInView: true });
+      panel.refreshWhenInView = true;
       return;
     }
 
@@ -347,13 +353,10 @@ export class PanelStateWrapper extends PureComponent<Props, State> {
         return;
       }
 
-      if (this.state.refreshWhenInView) {
-        this.setState({ refreshWhenInView: false });
-      }
+      panel.refreshWhenInView = false;
       panel.runAllPanelQueries({
         dashboardUID: dashboard.uid,
         dashboardTimezone: dashboard.getTimezone(),
-        publicDashboardAccessToken: dashboard.meta.publicDashboardAccessToken,
         timeData,
         width,
       });
@@ -380,8 +383,17 @@ export class PanelStateWrapper extends PureComponent<Props, State> {
     this.props.panel.updateFieldConfig(config);
   };
 
+  logPanelChangesOnError() {
+    this.panelOptionsLogger!.logChanges(this.props.panel.getOptions(), this.props.panel.fieldConfig);
+  }
+
   onPanelError = (error: Error) => {
+    if (config.featureToggles.panelMonitoring && this.getPanelContextApp() === CoreApp.PanelEditor) {
+      this.logPanelChangesOnError();
+    }
+
     const errorMessage = error.message || DEFAULT_PLUGIN_ERROR;
+
     if (this.state.errorMessage !== errorMessage) {
       this.setState({ errorMessage });
     }
@@ -519,186 +531,67 @@ export class PanelStateWrapper extends PureComponent<Props, State> {
             onChangeTimeRange={this.onChangeTimeRange}
             eventBus={dashboard.events}
           />
+          {config.featureToggles.panelMonitoring && this.state.errorMessage === undefined && (
+            <PanelLoadTimeMonitor panelType={plugin.meta.id} panelId={panel.id} panelTitle={panel.title} />
+          )}
         </PanelContextProvider>
       </>
     );
   }
 
-  renderPanel(width: number, height: number) {
-    const { panel, plugin, dashboard } = this.props;
-    const { renderCounter, data } = this.state;
-    const { theme } = config;
-    const { state: loadingState } = data;
-
-    // do not render component until we have first data
-    if (this.skipFirstRender(loadingState)) {
-      return null;
-    }
-
-    // This is only done to increase a counter that is used by backend
-    // image rendering to know when to capture image
-    if (this.shouldSignalRenderingCompleted(loadingState, plugin.meta)) {
-      profiler.renderingCompleted();
-    }
-
-    const PanelComponent = plugin.panel!;
-    const timeRange = this.state.liveTime ?? data.timeRange ?? this.timeSrv.timeRange();
-    const headerHeight = this.hasOverlayHeader() ? 0 : theme.panelHeaderHeight;
-    const chromePadding = plugin.noPadding ? 0 : theme.panelPadding;
-    const panelWidth = width - chromePadding * 2 - PANEL_BORDER;
-    const innerPanelHeight = height - headerHeight - chromePadding * 2 - PANEL_BORDER;
-    const panelContentClassNames = classNames({
-      'panel-content': true,
-      'panel-content--no-padding': plugin.noPadding,
-    });
-    const panelOptions = panel.getOptions();
-
-    // Update the event filter (dashboard settings may have changed)
-    // Yes this is called ever render for a function that is triggered on every mouse move
-    this.eventFilter.onlyLocal = dashboard.graphTooltip === 0;
-
-    const timeZone = this.props.timezone || this.props.dashboard.getTimezone();
-
-    return (
-      <>
-        <div className={panelContentClassNames}>
-          <PluginContextProvider meta={plugin.meta}>
-            <PanelContextProvider value={this.state.context}>
-              <PanelComponent
-                id={panel.id}
-                data={data}
-                title={panel.title}
-                timeRange={timeRange}
-                timeZone={timeZone}
-                options={panelOptions}
-                fieldConfig={panel.fieldConfig}
-                transparent={panel.transparent}
-                width={panelWidth}
-                height={innerPanelHeight}
-                renderCounter={renderCounter}
-                replaceVariables={panel.replaceVariables}
-                onOptionsChange={this.onOptionsChange}
-                onFieldConfigChange={this.onFieldConfigChange}
-                onChangeTimeRange={this.onChangeTimeRange}
-                eventBus={dashboard.events}
-              />
-            </PanelContextProvider>
-          </PluginContextProvider>
-        </div>
-      </>
-    );
-  }
-
-  hasOverlayHeader() {
-    const { panel } = this.props;
-    const { data } = this.state;
-
-    // always show normal header if we have time override
-    if (data.request && data.request.timeInfo) {
-      return false;
-    }
-
-    return !panel.hasTitle();
-  }
-
   render() {
-    const { dashboard, panel, isViewing, isEditing, width, height, plugin } = this.props;
+    const { dashboard, panel, width, height, plugin } = this.props;
     const { errorMessage, data } = this.state;
     const { transparent } = panel;
 
-    const alertState = data.alertState?.state;
-    const hasHoverHeader = this.hasOverlayHeader();
-
-    const containerClassNames = classNames({
-      'panel-container': true,
-      'panel-container--absolute': isSoloRoute(locationService.getLocation().pathname),
-      'panel-container--transparent': transparent,
-      'panel-container--no-title': hasHoverHeader,
-      [`panel-alert-state--${alertState}`]: alertState !== undefined,
-    });
-
     const panelChromeProps = getPanelChromeProps({ ...this.props, data });
 
-    if (config.featureToggles.newPanelChromeUI) {
-      // Shift the hover menu down if it's on the top row so it doesn't get clipped by topnav
-      const hoverHeaderOffset = (panel.gridPos?.y ?? 0) === 0 ? -16 : undefined;
+    // Shift the hover menu down if it's on the top row so it doesn't get clipped by topnav
+    const hoverHeaderOffset = (panel.gridPos?.y ?? 0) === 0 ? -16 : undefined;
 
-      const menu = (
-        <div data-testid="panel-dropdown">
-          <PanelHeaderMenuWrapperNew panel={panel} dashboard={dashboard} loadingState={data.state} />
-        </div>
-      );
+    const menu = (
+      <div data-testid="panel-dropdown">
+        <PanelHeaderMenuWrapper panel={panel} dashboard={dashboard} loadingState={data.state} />
+      </div>
+    );
 
-      return (
-        <PanelChrome
-          width={width}
-          height={height}
-          title={panelChromeProps.title}
-          loadingState={data.state}
-          statusMessage={errorMessage}
-          statusMessageOnClick={panelChromeProps.onOpenErrorInspect}
-          description={panelChromeProps.description}
-          titleItems={panelChromeProps.titleItems}
-          menu={this.props.hideMenu ? undefined : menu}
-          dragClass={panelChromeProps.dragClass}
-          dragClassCancel="grid-drag-cancel"
-          padding={panelChromeProps.padding}
-          hoverHeaderOffset={hoverHeaderOffset}
-          hoverHeader={panelChromeProps.hasOverlayHeader()}
-          displayMode={transparent ? 'transparent' : 'default'}
-          onCancelQuery={panelChromeProps.onCancelQuery}
-          onOpenMenu={panelChromeProps.onOpenMenu}
-        >
-          {(innerWidth, innerHeight) => (
-            <>
-              <ErrorBoundary
-                dependencies={[data, plugin, panel.getOptions()]}
-                onError={this.onPanelError}
-                onRecover={this.onPanelErrorRecover}
-              >
-                {({ error }) => {
-                  if (error) {
-                    return null;
-                  }
-                  return this.renderPanelContent(innerWidth, innerHeight);
-                }}
-              </ErrorBoundary>
-            </>
-          )}
-        </PanelChrome>
-      );
-    } else {
-      return (
-        <section
-          className={containerClassNames}
-          aria-label={selectors.components.Panels.Panel.containerByTitle(panel.title)}
-        >
-          <PanelHeader
-            panel={panel}
-            dashboard={dashboard}
-            title={panel.title}
-            description={panel.description}
-            links={panel.links}
-            error={errorMessage}
-            isEditing={isEditing}
-            isViewing={isViewing}
-            alertState={alertState}
-            data={data}
-          />
-          <ErrorBoundary
-            dependencies={[data, plugin, panel.getOptions()]}
-            onError={this.onPanelError}
-            onRecover={this.onPanelErrorRecover}
-          >
-            {({ error }) => {
-              if (error) {
-                return null;
-              }
-              return this.renderPanel(width, height);
-            }}
-          </ErrorBoundary>
-        </section>
-      );
-    }
+    return (
+      <PanelChrome
+        width={width}
+        height={height}
+        title={panelChromeProps.title}
+        loadingState={data.state}
+        statusMessage={errorMessage}
+        statusMessageOnClick={panelChromeProps.onOpenErrorInspect}
+        description={panelChromeProps.description}
+        titleItems={panelChromeProps.titleItems}
+        menu={this.props.hideMenu ? undefined : menu}
+        dragClass={panelChromeProps.dragClass}
+        dragClassCancel="grid-drag-cancel"
+        padding={panelChromeProps.padding}
+        hoverHeaderOffset={hoverHeaderOffset}
+        hoverHeader={panelChromeProps.hasOverlayHeader()}
+        displayMode={transparent ? 'transparent' : 'default'}
+        onCancelQuery={panelChromeProps.onCancelQuery}
+        onOpenMenu={panelChromeProps.onOpenMenu}
+      >
+        {(innerWidth, innerHeight) => (
+          <>
+            <ErrorBoundary
+              dependencies={[data, plugin, panel.getOptions()]}
+              onError={this.onPanelError}
+              onRecover={this.onPanelErrorRecover}
+            >
+              {({ error }) => {
+                if (error) {
+                  return null;
+                }
+                return this.renderPanelContent(innerWidth, innerHeight);
+              }}
+            </ErrorBoundary>
+          </>
+        )}
+      </PanelChrome>
+    );
   }
 }
