@@ -33,23 +33,3 @@ export const getPublicDashboardRoutes = (): RouteDescriptor[] => {
   }
   return [];
 };
-
-export const getEmbeddedDashboardRoutes = (): RouteDescriptor[] => {
-  if (config.featureToggles.dashboardEmbed) {
-    return [
-      {
-        path: '/d-embed',
-        pageClass: 'dashboard-embed',
-        routeName: DashboardRoutes.Embedded,
-        component: SafeDynamicImport(
-          () =>
-            import(
-              /* webpackChunkName: "EmbeddedDashboardPage" */ '../../features/dashboard/containers/EmbeddedDashboardPage'
-            )
-        ),
-      },
-    ];
-  }
-
-  return [];
-};
