@@ -197,6 +197,12 @@ function getEnterprisePhantomPlugins(): DataSourcePluginMeta[] {
       name: 'Azure Devops',
       imgUrl: 'public/img/plugins/azure-devops.png',
     }),
+    getPhantomPlugin({
+      id: 'grafana-sumologic-datasource',
+      description: 'SumoLogic integration and datasource',
+      name: 'SumoLogic',
+      imgUrl: 'public/img/plugins/sumo.svg',
+    }),
   ];
 }
 
