@@ -4,6 +4,7 @@ import React, { useEffect } from 'react';
 import { GrafanaTheme2, SelectableValue } from '@grafana/data';
 import { config } from '@grafana/runtime';
 import { useStyles2, Select, MultiSelect, FilterInput, Button } from '@grafana/ui';
+import { Trans, t } from 'app/core/internationalization';
 import {
   createDatasourcesList,
   SortOrder,
@@ -105,7 +106,11 @@ export function RichHistoryStarredTab(props: RichHistoryStarredTabProps) {
   }, []);
 
   if (!richHistorySearchFilters) {
-    return <span>Loading...</span>;
+    return (
+      <span>
+        <Trans i18nKey="explore.rich-history-starred-tab.loading">Loading...</Trans>;
+      </span>
+    );
   }
 
   const sortOrderOptions = getSortOrderOptions();
@@ -121,8 +126,14 @@ export function RichHistoryStarredTab(props: RichHistoryStarredTabProps) {
                 return { value: ds.name, label: ds.name };
               })}
               value={richHistorySearchFilters.datasourceFilters}
-              placeholder="Filter queries for data sources(s)"
-              aria-label="Filter queries for data sources(s)"
+              placeholder={t(
+                'explore.rich-history-starred-tab.filter-queries-placeholder',
+                'Filter queries for data sources(s)'
+              )}
+              aria-label={t(
+                'explore.rich-history-starred-tab.filter-queries-aria-label',
+                'Filter queries for data sources(s)'
+              )}
               onChange={(options: SelectableValue[]) => {
                 updateFilters({ datasourceFilters: options.map((option) => option.value) });
               }}
@@ -131,32 +142,53 @@ export function RichHistoryStarredTab(props: RichHistoryStarredTabProps) {
           <div className={styles.filterInput}>
             <FilterInput
               escapeRegex={false}
-              placeholder="Search queries"
+              placeholder={t('explore.rich-history-starred-tab.search-queries-placeholder', 'Search queries')}
               value={richHistorySearchFilters.search}
               onChange={(search: string) => updateFilters({ search })}
             />
           </div>
-          <div aria-label="Sort queries" className={styles.sort}>
+          <div
+            aria-label={t('explore.rich-history-starred-tab.sort-queries-aria-label', 'Sort queries')}
+            className={styles.sort}
+          >
             <Select
               value={sortOrderOptions.filter((order) => order.value === richHistorySearchFilters.sortOrder)}
               options={sortOrderOptions}
-              placeholder="Sort queries by"
+              placeholder={t('explore.rich-history-starred-tab.sort-queries-placeholder', 'Sort queries by')}
               onChange={(e: SelectableValue<SortOrder>) => updateFilters({ sortOrder: e.value })}
             />
           </div>
         </div>
-        {loading && <span>Loading results...</span>}
+        {loading && (
+          <span>
+            <Trans i18nKey="explore.rich-history-starred-tab.loading-results">Loading results...</Trans>
+          </span>
+        )}
         {!loading &&
           queries.map((q) => {
-            return <RichHistoryCard query={q} key={q.id} exploreId={exploreId} />;
+            return <RichHistoryCard queryHistoryItem={q} key={q.id} exploreId={exploreId} />;
           })}
         {queries.length && queries.length !== totalQueries ? (
           <div>
-            Showing {queries.length} of {totalQueries} <Button onClick={loadMoreRichHistory}>Load more</Button>
+            <Trans
+              i18nKey="explore.rich-history-starred-tab.showing-queries"
+              defaults="Showing {{ shown }} of {{ total }} <0>Load more</0>"
+              values={{ shown: queries.length, total: totalQueries }}
+              components={[
+                <Button onClick={loadMoreRichHistory} key="loadMoreButton">
+                  Load more
+                </Button>,
+              ]}
+            />
           </div>
         ) : null}
         <div className={styles.footer}>
-          {!config.queryHistoryEnabled ? 'The history is local to your browser and is not shared with others.' : ''}
+          {!config.queryHistoryEnabled
+            ? t(
+                'explore.rich-history-starred-tab.local-history-message',
+                'The history is local to your browser and is not shared with others.'
+              )
+            : ''}
         </div>
       </div>
     </div>
