@@ -1,11 +1,10 @@
-import React, { RefObject, useMemo } from 'react';
+import React, { useMemo } from 'react';
 
-import { DataFrame, SplitOpen, PanelData } from '@grafana/data';
+import { DataFrame, SplitOpen } from '@grafana/data';
 import { PanelChrome } from '@grafana/ui/src/components/PanelChrome/PanelChrome';
 import { StoreState, useSelector } from 'app/types';
 
 import { TraceView } from './TraceView';
-import { TopOfViewRefType } from './components/TraceTimelineViewer/VirtualizedTraceView';
 import { transformDataFrames } from './utils/transform';
 
 interface Props {
@@ -13,14 +12,12 @@ interface Props {
   splitOpenFn: SplitOpen;
   exploreId: string;
   scrollElement?: Element;
-  queryResponse: PanelData;
-  topOfViewRef: RefObject<HTMLDivElement>;
 }
 
 export function TraceViewContainer(props: Props) {
   // At this point we only show single trace
   const frame = props.dataFrames[0];
-  const { dataFrames, splitOpenFn, exploreId, scrollElement, topOfViewRef, queryResponse } = props;
+  const { dataFrames, splitOpenFn, exploreId, scrollElement } = props;
   const traceProp = useMemo(() => transformDataFrames(frame), [frame]);
   const datasource = useSelector(
     (state: StoreState) => state.explore.panes[props.exploreId]?.datasourceInstance ?? undefined
@@ -38,10 +35,7 @@ export function TraceViewContainer(props: Props) {
         splitOpenFn={splitOpenFn}
         scrollElement={scrollElement}
         traceProp={traceProp}
-        queryResponse={queryResponse}
         datasource={datasource}
-        topOfViewRef={topOfViewRef}
-        topOfViewRefType={TopOfViewRefType.Explore}
       />
     </PanelChrome>
   );
