@@ -23,6 +23,7 @@ import { Collapse, HorizontalGroup, Icon, InlineField, InlineFieldRow, Select, T
 import { IntervalInput } from 'app/core/components/IntervalInput/IntervalInput';
 
 import { defaultFilters, randomId, SearchProps, Tag } from '../../../useSearch';
+import SearchBarInput from '../../common/SearchBarInput';
 import { KIND, LIBRARY_NAME, LIBRARY_VERSION, STATUS, STATUS_MESSAGE, TRACE_STATE, ID } from '../../constants/span';
 import { Trace } from '../../types';
 import NextPrevResult from '../SearchBar/NextPrevResult';
@@ -37,6 +38,8 @@ export type SpanFilterProps = {
   showSpanFilterMatchesOnly: boolean;
   setShowSpanFilterMatchesOnly: (showMatchesOnly: boolean) => void;
   setFocusedSpanIdForSearch: React.Dispatch<React.SetStateAction<string>>;
+  showCriticalPathSpansOnly: boolean;
+  setShowCriticalPathSpansOnly: (showCriticalPathSpansOnly: boolean) => void;
   spanFilterMatches: Set<string> | undefined;
   datasourceType: string;
 };
@@ -50,6 +53,8 @@ export const SpanFilters = memo((props: SpanFilterProps) => {
     setShowSpanFilters,
     showSpanFilterMatchesOnly,
     setShowSpanFilterMatchesOnly,
+    showCriticalPathSpansOnly,
+    setShowCriticalPathSpansOnly,
     setFocusedSpanIdForSearch,
     spanFilterMatches,
     datasourceType,
@@ -69,7 +74,8 @@ export const SpanFilters = memo((props: SpanFilterProps) => {
     setTagKeys(undefined);
     setTagValues({});
     setSearch(defaultFilters);
-  }, [setSearch]);
+    setShowSpanFilterMatchesOnly(false);
+  }, [setSearch, setShowSpanFilterMatchesOnly]);
 
   useEffect(() => {
     clear();
@@ -293,7 +299,7 @@ export const SpanFilters = memo((props: SpanFilterProps) => {
   return (
     <div className={styles.container}>
       <Collapse label={collapseLabel} collapsible={true} isOpen={showSpanFilters} onToggle={setShowSpanFilters}>
-        <InlineFieldRow>
+        <InlineFieldRow className={styles.flexContainer}>
           <InlineField label="Service Name" labelWidth={16}>
             <HorizontalGroup spacing={'xs'}>
               <Select
@@ -313,6 +319,15 @@ export const SpanFilters = memo((props: SpanFilterProps) => {
               />
             </HorizontalGroup>
           </InlineField>
+          <SearchBarInput
+            onChange={(v) => {
+              setSpanFiltersSearch({ ...search, query: v });
+              if (v === '') {
+                setShowSpanFilterMatchesOnly(false);
+              }
+            }}
+            value={search.query || ''}
+          />
         </InlineFieldRow>
         <InlineFieldRow>
           <InlineField label="Span Name" labelWidth={16}>
@@ -455,6 +470,8 @@ export const SpanFilters = memo((props: SpanFilterProps) => {
           spanFilterMatches={spanFilterMatches}
           showSpanFilterMatchesOnly={showSpanFilterMatchesOnly}
           setShowSpanFilterMatchesOnly={setShowSpanFilterMatchesOnly}
+          showCriticalPathSpansOnly={showCriticalPathSpansOnly}
+          setShowCriticalPathSpansOnly={setShowCriticalPathSpansOnly}
           setFocusedSpanIdForSearch={setFocusedSpanIdForSearch}
           focusedSpanIndexForSearch={focusedSpanIndexForSearch}
           setFocusedSpanIndexForSearch={setFocusedSpanIndexForSearch}
@@ -472,6 +489,7 @@ SpanFilters.displayName = 'SpanFilters';
 const getStyles = (theme: GrafanaTheme2) => {
   return {
     container: css`
+      label: SpanFilters;
       margin: 0.5em 0 -${theme.spacing(1)} 0;
       z-index: 5;
 
@@ -486,6 +504,10 @@ const getStyles = (theme: GrafanaTheme2) => {
         margin: -2px 0 0 10px;
       }
     `,
+    flexContainer: css({
+      display: 'flex',
+      justifyContent: 'space-between',
+    }),
     addTag: css`
       margin: 0 0 0 10px;
     `,
