@@ -1,22 +1,24 @@
 import React from 'react';
 
-import { DataQueryRequest, serializeStateToUrlParam } from '@grafana/data';
+import { DataQueryRequest, EventBusSrv, serializeStateToUrlParam } from '@grafana/data';
 import { getTemplateSrv } from '@grafana/runtime';
 
 import { LokiQuery } from '../../../plugins/datasource/loki/types';
 
 import { makeLogsQueryResponse } from './helper/query';
-import { setupExplore, waitForExplore } from './helper/setup';
+import { setupExplore, tearDown, waitForExplore } from './helper/setup';
+
+const testEventBus = new EventBusSrv();
 
-const fetch = jest.fn();
 jest.mock('@grafana/runtime', () => ({
   ...jest.requireActual('@grafana/runtime'),
-  getBackendSrv: () => ({ fetch }),
+  getAppEvents: () => testEventBus,
 }));
 
 jest.mock('app/core/core', () => ({
   contextSrv: {
-    hasAccess: () => true,
+    hasPermission: () => true,
+    getValidIntervals: (defaultIntervals: string[]) => defaultIntervals,
   },
 }));
 
@@ -29,13 +31,11 @@ jest.mock('react-virtualized-auto-sizer', () => {
   };
 });
 
-jest.mock('../../correlations/utils', () => {
-  return {
-    getCorrelationsBySourceUIDs: jest.fn().mockReturnValue({ correlations: [] }),
-  };
-});
-
 describe('Explore: interpolation', () => {
+  afterEach(() => {
+    tearDown();
+  });
+
   // support-escalations/issues/1459
   it('Time is interpolated when explore is opened with a URL', async () => {
     const urlParams = {
