@@ -1,7 +1,6 @@
 import React from 'react';
-import { of } from 'rxjs';
 
-import { serializeStateToUrlParam } from '@grafana/data';
+import { DataQuery, EventBusSrv, serializeStateToUrlParam } from '@grafana/data';
 import { config } from '@grafana/runtime';
 
 import { silenceConsoleOutput } from '../../../../test/core/utils/silenceConsoleOutput';
@@ -11,15 +10,16 @@ import {
   assertLoadMoreQueryHistoryNotVisible,
   assertQueryHistory,
   assertQueryHistoryComment,
+  assertQueryHistoryContains,
   assertQueryHistoryElementsShown,
   assertQueryHistoryExists,
+  assertQueryHistoryIsEmpty,
   assertQueryHistoryIsStarred,
   assertQueryHistoryTabIsSelected,
-  assertQueryHistoryIsEmpty,
 } from './helper/assert';
 import {
-  commentQueryHistory,
   closeQueryHistory,
+  commentQueryHistory,
   deleteQueryHistory,
   inputQuery,
   loadMoreQueryHistory,
@@ -33,23 +33,26 @@ import {
 import { makeLogsQueryResponse } from './helper/query';
 import { setupExplore, tearDown, waitForExplore } from './helper/setup';
 
-const fetchMock = jest.fn();
-const postMock = jest.fn();
-const getMock = jest.fn();
 const reportInteractionMock = jest.fn();
+const testEventBus = new EventBusSrv();
+
+interface MockQuery extends DataQuery {
+  expr: string;
+}
+
 jest.mock('@grafana/runtime', () => ({
   ...jest.requireActual('@grafana/runtime'),
-  getBackendSrv: () => ({ fetch: fetchMock, post: postMock, get: getMock }),
   reportInteraction: (...args: object[]) => {
     reportInteractionMock(...args);
   },
+  getAppEvents: () => testEventBus,
 }));
 
 jest.mock('app/core/core', () => ({
   contextSrv: {
     hasPermission: () => true,
-    hasAccess: () => true,
     isSignedIn: true,
+    getValidIntervals: (defaultIntervals: string[]) => defaultIntervals,
   },
 }));
 
@@ -75,12 +78,6 @@ jest.mock('react-virtualized-auto-sizer', () => {
   };
 });
 
-jest.mock('../../correlations/utils', () => {
-  return {
-    getCorrelationsBySourceUIDs: jest.fn().mockReturnValue({ correlations: [] }),
-  };
-});
-
 describe('Explore: Query History', () => {
   const USER_INPUT = 'my query';
   const RAW_QUERY = `{"expr":"${USER_INPUT}"}`;
@@ -89,9 +86,6 @@ describe('Explore: Query History', () => {
 
   afterEach(() => {
     config.queryHistoryEnabled = false;
-    fetchMock.mockClear();
-    postMock.mockClear();
-    getMock.mockClear();
     reportInteractionMock.mockClear();
     tearDown();
   });
@@ -112,6 +106,8 @@ describe('Explore: Query History', () => {
 
     // when Explore is opened again
     unmount();
+
+    tearDown({ clearLocalStorage: false });
     setupExplore({ clearLocalStorage: false });
     await waitForExplore();
 
@@ -168,8 +164,10 @@ describe('Explore: Query History', () => {
     });
 
     it('initial state is in sync', async () => {
-      await assertQueryHistory(['{"expr":"query #2"}', '{"expr":"query #1"}'], 'left');
-      await assertQueryHistory(['{"expr":"query #2"}', '{"expr":"query #1"}'], 'right');
+      await assertQueryHistoryContains('{"expr":"query #1"}', 'left');
+      await assertQueryHistoryContains('{"expr":"query #2"}', 'left');
+      await assertQueryHistoryContains('{"expr":"query #1"}', 'right');
+      await assertQueryHistoryContains('{"expr":"query #2"}', 'right');
     });
 
     it('starred queries are synced', async () => {
@@ -207,7 +205,6 @@ describe('Explore: Query History', () => {
     await waitForExplore();
     await openQueryHistory();
     await assertQueryHistory(['{"expr":"query #1"}'], 'left');
-
     await commentQueryHistory(0, 'test comment');
     await assertQueryHistoryComment(['test comment'], 'left');
   });
@@ -261,13 +258,15 @@ describe('Explore: Query History', () => {
 
   it('pagination', async () => {
     config.queryHistoryEnabled = true;
-    const { datasources } = setupExplore();
+
+    const mockQuery: MockQuery = { refId: 'A', expr: 'query' };
+    const { datasources } = setupExplore({
+      queryHistory: {
+        queryHistory: [{ datasourceUid: 'loki', queries: [mockQuery] }],
+        totalCount: 2,
+      },
+    });
     jest.mocked(datasources.loki.query).mockReturnValueOnce(makeLogsQueryResponse());
-    fetchMock.mockReturnValue(
-      of({
-        data: { result: { queryHistory: [{ datasourceUid: 'loki', queries: [{ expr: 'query' }] }], totalCount: 2 } },
-      })
-    );
     await waitForExplore();
 
     await openQueryHistory();
