@@ -14,7 +14,7 @@ interface Props {
   wrapLogMessage: boolean;
   prettifyLogMessage: boolean;
   app?: CoreApp;
-  showContextToggle?: (row?: LogRowModel) => boolean;
+  showContextToggle?: (row: LogRowModel) => boolean;
   onOpenContext: (row: LogRowModel) => void;
   onPermalinkClick?: (row: LogRowModel) => Promise<void>;
   onPinLine?: (row: LogRowModel) => void;
@@ -22,6 +22,7 @@ interface Props {
   pinned?: boolean;
   styles: LogRowStyles;
   mouseIsOver: boolean;
+  onBlur: () => void;
 }
 
 interface LogMessageProps {
@@ -75,6 +76,7 @@ export const LogRowMessage = React.memo((props: Props) => {
     onPinLine,
     pinned,
     mouseIsOver,
+    onBlur,
   } = props;
   const { hasAnsi, raw } = row;
   const restructuredEntry = useMemo(() => restructureLog(raw, prettifyLogMessage), [raw, prettifyLogMessage]);
@@ -105,6 +107,7 @@ export const LogRowMessage = React.memo((props: Props) => {
             pinned={pinned}
             styles={styles}
             mouseIsOver={mouseIsOver}
+            onBlur={onBlur}
           />
         )}
       </td>
