@@ -30,13 +30,13 @@ export function getLogLevel(line: string): LogLevel {
   let level = LogLevel.unknown;
   let currentIndex: number | undefined = undefined;
 
-  for (const key of Object.keys(LogLevel)) {
+  for (const [key, value] of Object.entries(LogLevel)) {
     const regexp = new RegExp(`\\b${key}\\b`, 'i');
     const result = regexp.exec(line);
 
     if (result) {
       if (currentIndex === undefined || result.index < currentIndex) {
-        level = (LogLevel as any)[key];
+        level = value;
         currentIndex = result.index;
       }
     }
@@ -45,7 +45,7 @@ export function getLogLevel(line: string): LogLevel {
 }
 
 export function getLogLevelFromKey(key: string | number): LogLevel {
-  const level = (LogLevel as any)[key.toString().toLowerCase()];
+  const level = LogLevel[key.toString().toLowerCase() as keyof typeof LogLevel];
   if (level) {
     return level;
   }
@@ -59,7 +59,7 @@ export function calculateLogsLabelStats(rows: LogRowModel[], label: string): Log
   const rowCount = rowsWithLabel.length;
 
   // Get label value counts for eligible rows
-  const countsByValue = countBy(rowsWithLabel, (row) => (row as LogRowModel).labels[label]);
+  const countsByValue = countBy(rowsWithLabel, (row) => row.labels[label]);
   return getSortedCounts(countsByValue, rowCount);
 }
 
@@ -243,13 +243,14 @@ export const mergeLogsVolumeDataFrames = (dataFrames: DataFrame[]): { dataFrames
     levelDataFrame.addField({ name: 'Time', type: FieldType.time, config: timeFieldConfig });
     levelDataFrame.addField({ name: 'Value', type: FieldType.number, config: valueFieldConfig });
 
-    for (const time in aggregated[level]) {
-      const value = aggregated[level][time];
-      levelDataFrame.add({
-        Time: Number(time),
-        Value: value,
+    Object.entries(aggregated[level])
+      .sort((a, b) => Number(a[0]) - Number(b[0]))
+      .forEach(([time, value]) => {
+        levelDataFrame.add({
+          Time: Number(time),
+          Value: value,
+        });
       });
-    }
 
     results.push(levelDataFrame);
   });
@@ -272,3 +273,27 @@ export const getLogsVolumeDataSourceInfo = (dataFrames: DataFrame[]): { name: st
 export const isLogsVolumeLimited = (dataFrames: DataFrame[]) => {
   return dataFrames[0]?.meta?.custom?.logsVolumeType === LogsVolumeType.Limited;
 };
+
+export const copyText = async (text: string, buttonRef: React.MutableRefObject<Element | null>) => {
+  if (navigator.clipboard && window.isSecureContext) {
+    return navigator.clipboard.writeText(text);
+  } else {
+    // Use a fallback method for browsers/contexts that don't support the Clipboard API.
+    // See https://web.dev/async-clipboard/#feature-detection.
+    // Use textarea so the user can copy multi-line content.
+    const textarea = document.createElement('textarea');
+    // Normally we'd append this to the body. However if we're inside a focus manager
+    // from react-aria, we can't focus anything outside of the managed area.
+    // Instead, let's append it to the button. Then we're guaranteed to be able to focus + copy.
+    buttonRef.current?.appendChild(textarea);
+    textarea.value = text;
+    textarea.focus();
+    textarea.select();
+    document.execCommand('copy');
+    textarea.remove();
+  }
+};
+
+export function targetIsElement(target: EventTarget | null): target is Element {
+  return target instanceof Element;
+}
