@@ -1,16 +1,6 @@
-export interface Snapshot {
-  created: string;
-  expires: string;
-  external: boolean;
-  externalUrl: string;
-  id: number;
-  key: string;
-  name: string;
-  orgId: number;
-  updated: string;
-  url?: string;
-  userId: number;
-}
+import { Dashboard } from '@grafana/schema/src/veneer/dashboard.types';
+
+import { ExternalDashboard } from '../dashboard/components/DashExportModal/DashboardExporter';
 
 export type DeleteDashboardResponse = {
   id: number;
@@ -36,3 +26,5 @@ export interface PublicDashboardListResponse {
 export interface PublicDashboardListWithPagination extends PublicDashboardListWithPaginationResponse {
   totalPages: number;
 }
+
+export type DashboardJson = ExternalDashboard & Omit<Dashboard, 'panels'>;
