@@ -1,5 +1,6 @@
 import { css, cx } from '@emotion/css';
 import React, { MouseEventHandler } from 'react';
+import Skeleton from 'react-loading-skeleton';
 
 import { GrafanaTheme2, isUnsignedPluginSignature, PanelPluginMeta, PluginState } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
@@ -17,6 +18,8 @@ interface Props {
   description?: string;
 }
 
+const IMAGE_SIZE = 38;
+
 export const PanelTypeCard = ({
   isCurrent,
   title,
@@ -74,86 +77,122 @@ export const PanelTypeCard = ({
   );
 };
 
+interface SkeletonProps {
+  hasDescription?: boolean;
+  hasDelete?: boolean;
+}
+
+const PanelTypeCardSkeleton = ({ children, hasDescription, hasDelete }: React.PropsWithChildren<SkeletonProps>) => {
+  const styles = useStyles2(getStyles);
+  const skeletonStyles = useStyles2(getSkeletonStyles);
+  return (
+    <div className={styles.item}>
+      <Skeleton className={cx(styles.img, skeletonStyles.image)} width={IMAGE_SIZE} height={IMAGE_SIZE} />
+
+      <div className={styles.itemContent}>
+        <div className={styles.name}>
+          <Skeleton width={160} />
+        </div>
+        {hasDescription ? <Skeleton containerClassName={styles.description} width={80} /> : null}
+        {children}
+      </div>
+      {hasDelete && (
+        <Skeleton containerClassName={cx(styles.deleteButton, skeletonStyles.deleteButton)} width={16} height={16} />
+      )}
+    </div>
+  );
+};
+
 PanelTypeCard.displayName = 'PanelTypeCard';
+PanelTypeCard.Skeleton = PanelTypeCardSkeleton;
+
+const getSkeletonStyles = () => {
+  return {
+    deleteButton: css({
+      lineHeight: 1,
+    }),
+    image: css({
+      lineHeight: 1,
+    }),
+  };
+};
 
 const getStyles = (theme: GrafanaTheme2) => {
   return {
-    item: css`
-      position: relative;
-      display: flex;
-      flex-shrink: 0;
-      cursor: pointer;
-      background: ${theme.colors.background.secondary};
-      border-radius: ${theme.shape.borderRadius()};
-      box-shadow: ${theme.shadows.z1};
-      border: 1px solid ${theme.colors.background.secondary};
-      align-items: center;
-      padding: 8px;
-      width: 100%;
-      position: relative;
-      overflow: hidden;
-      transition: ${theme.transitions.create(['background'], {
+    item: css({
+      position: 'relative',
+      display: 'flex',
+      flexShrink: 0,
+      cursor: 'pointer',
+      background: theme.colors.background.secondary,
+      borderRadius: theme.shape.radius.default,
+      boxShadow: theme.shadows.z1,
+      border: `1px solid ${theme.colors.background.secondary}`,
+      alignItems: 'center',
+      padding: theme.spacing(1),
+      width: '100%',
+      overflow: 'hidden',
+      transition: theme.transitions.create(['background'], {
         duration: theme.transitions.duration.short,
-      })};
+      }),
 
-      &:hover {
-        background: ${theme.colors.emphasize(theme.colors.background.secondary, 0.03)};
-      }
-    `,
-    itemContent: css`
-      overflow: hidden;
-      position: relative;
-      padding: ${theme.spacing(0, 1)};
-    `,
-    itemDisabled: css`
-      cursor: default;
+      '&:hover': {
+        background: theme.colors.emphasize(theme.colors.background.secondary, 0.03),
+      },
+    }),
+    itemContent: css({
+      overflow: 'hidden',
+      position: 'relative',
+      padding: theme.spacing(0, 1),
+    }),
+    itemDisabled: css({
+      cursor: 'default',
 
-      &,
-      &:hover {
-        background: ${theme.colors.action.disabledBackground};
-      }
-    `,
-    current: css`
-      label: currentVisualizationItem;
-      border: 1px solid ${theme.colors.primary.border};
-      background: ${theme.colors.action.selected};
-    `,
-    disabled: css`
-      opacity: 0.6;
-      filter: grayscale(1);
-      cursor: default;
-      pointer-events: none;
-    `,
-    name: css`
-      text-overflow: ellipsis;
-      overflow: hidden;
-      font-size: ${theme.typography.size.sm};
-      font-weight: ${theme.typography.fontWeightMedium};
-      width: 100%;
-    `,
-    description: css`
-      display: block;
-      text-overflow: ellipsis;
-      overflow: hidden;
-      color: ${theme.colors.text.secondary};
-      font-size: ${theme.typography.bodySmall.fontSize};
-      font-weight: ${theme.typography.fontWeightLight};
-      width: 100%;
-      max-height: 4.5em;
-    `,
-    img: css`
-      max-height: 38px;
-      width: 38px;
-      display: flex;
-      align-items: center;
-    `,
-    badge: css`
-      background: ${theme.colors.background.primary};
-    `,
-    deleteButton: css`
-      cursor: pointer;
-      margin-left: auto;
-    `,
+      '&, &:hover': {
+        background: theme.colors.action.disabledBackground,
+      },
+    }),
+    current: css({
+      label: 'currentVisualizationItem',
+      border: `1px solid ${theme.colors.primary.border}`,
+      background: theme.colors.action.selected,
+    }),
+    disabled: css({
+      opacity: 0.6,
+      filter: 'grayscale(1)',
+      cursor: 'default',
+      pointerEvents: 'none',
+    }),
+    name: css({
+      textOverflow: 'ellipsis',
+      overflow: 'hidden',
+      fontSize: theme.typography.size.sm,
+      fontWeight: theme.typography.fontWeightMedium,
+      width: '100%',
+    }),
+    description: css({
+      display: 'block',
+      textOverflow: 'ellipsis',
+      overflow: 'hidden',
+      color: theme.colors.text.secondary,
+      fontSize: theme.typography.bodySmall.fontSize,
+      fontWeight: theme.typography.fontWeightLight,
+      width: '100%',
+      maxHeight: '4.5em',
+    }),
+    img: css({
+      maxHeight: IMAGE_SIZE,
+      width: IMAGE_SIZE,
+      display: 'flex',
+      alignItems: 'center',
+    }),
+    badge: css({
+      background: theme.colors.background.primary,
+    }),
+    deleteButton: css({
+      cursor: 'pointer',
+      marginLeft: 'auto',
+    }),
   };
 };
 
