@@ -22,13 +22,13 @@ const mixedPlugin = async () =>
 const mysqlPlugin = async () =>
   await import(/* webpackChunkName: "mysqlPlugin" */ 'app/plugins/datasource/mysql/module');
 const postgresPlugin = async () =>
-  await import(/* webpackChunkName: "postgresPlugin" */ 'app/plugins/datasource/postgres/module');
+  await import(/* webpackChunkName: "postgresPlugin" */ 'app/plugins/datasource/grafana-postgresql-datasource/module');
 const prometheusPlugin = async () =>
   await import(/* webpackChunkName: "prometheusPlugin" */ 'app/plugins/datasource/prometheus/module');
 const mssqlPlugin = async () =>
   await import(/* webpackChunkName: "mssqlPlugin" */ 'app/plugins/datasource/mssql/module');
 const testDataDSPlugin = async () =>
-  await import(/* webpackChunkName: "testDataDSPlugin" */ 'app/plugins/datasource/testdata/module');
+  await import(/* webpackChunkName: "testDataDSPlugin" */ '@grafana-plugins/grafana-testdata-datasource/module');
 const cloudMonitoringPlugin = async () =>
   await import(/* webpackChunkName: "cloudMonitoringPlugin" */ 'app/plugins/datasource/cloud-monitoring/module');
 const azureMonitorPlugin = async () =>
@@ -77,67 +77,67 @@ const canvasPanel = async () => await import(/* webpackChunkName: "canvasPanel"
 const graphPanel = async () => await import(/* webpackChunkName: "graphPlugin" */ 'app/plugins/panel/graph/module');
 const heatmapPanel = async () =>
   await import(/* webpackChunkName: "heatmapPanel" */ 'app/plugins/panel/heatmap/module');
-
 const tableOldPanel = async () =>
   await import(/* webpackChunkName: "tableOldPlugin" */ 'app/plugins/panel/table-old/module');
 
-const builtInPlugins: any = {
-  'app/plugins/datasource/graphite/module': graphitePlugin,
-  'app/plugins/datasource/cloudwatch/module': cloudwatchPlugin,
-  'app/plugins/datasource/dashboard/module': dashboardDSPlugin,
-  'app/plugins/datasource/elasticsearch/module': elasticsearchPlugin,
-  'app/plugins/datasource/opentsdb/module': opentsdbPlugin,
-  'app/plugins/datasource/grafana/module': grafanaPlugin,
-  'app/plugins/datasource/influxdb/module': influxdbPlugin,
-  'app/plugins/datasource/loki/module': lokiPlugin,
-  'app/plugins/datasource/jaeger/module': jaegerPlugin,
-  'app/plugins/datasource/zipkin/module': zipkinPlugin,
-  'app/plugins/datasource/mixed/module': mixedPlugin,
-  'app/plugins/datasource/mysql/module': mysqlPlugin,
-  'app/plugins/datasource/postgres/module': postgresPlugin,
-  'app/plugins/datasource/mssql/module': mssqlPlugin,
-  'app/plugins/datasource/prometheus/module': prometheusPlugin,
-  'app/plugins/datasource/testdata/module': testDataDSPlugin,
-  'app/plugins/datasource/cloud-monitoring/module': cloudMonitoringPlugin,
-  'app/plugins/datasource/azuremonitor/module': azureMonitorPlugin,
-  'app/plugins/datasource/tempo/module': tempoPlugin,
-  'app/plugins/datasource/alertmanager/module': alertmanagerPlugin,
-  'app/plugins/datasource/grafana-pyroscope-datasource/module': pyroscopePlugin,
-  'app/plugins/datasource/parca/module': parcaPlugin,
-
-  'app/plugins/panel/text/module': textPanel,
-  'app/plugins/panel/timeseries/module': timeseriesPanel,
-  'app/plugins/panel/trend/module': trendPanel,
-  'app/plugins/panel/state-timeline/module': stateTimelinePanel,
-  'app/plugins/panel/status-history/module': statusHistoryPanel,
-  'app/plugins/panel/candlestick/module': candlestickPanel,
-  'app/plugins/panel/graph/module': graphPanel,
-  'app/plugins/panel/xychart/module': xyChartPanel,
-  'app/plugins/panel/geomap/module': geomapPanel,
-  'app/plugins/panel/canvas/module': canvasPanel,
-  'app/plugins/panel/dashlist/module': dashListPanel,
-  'app/plugins/panel/alertlist/module': alertListPanel,
-  'app/plugins/panel/annolist/module': annoListPanel,
-  'app/plugins/panel/heatmap/module': heatmapPanel,
-  'app/plugins/panel/table/module': tablePanel,
-  'app/plugins/panel/table-old/module': tableOldPanel,
-  'app/plugins/panel/news/module': newsPanel,
-  'app/plugins/panel/live/module': livePanel,
-  'app/plugins/panel/stat/module': statPanel,
-  'app/plugins/panel/datagrid/module': dataGridPanel,
-  'app/plugins/panel/debug/module': debugPanel,
-  'app/plugins/panel/flamegraph/module': flamegraphPanel,
-  'app/plugins/panel/gettingstarted/module': gettingStartedPanel,
-  'app/plugins/panel/gauge/module': gaugePanel,
-  'app/plugins/panel/piechart/module': pieChartPanel,
-  'app/plugins/panel/bargauge/module': barGaugePanel,
-  'app/plugins/panel/barchart/module': barChartPanel,
-  'app/plugins/panel/logs/module': logsPanel,
-  'app/plugins/panel/traces/module': tracesPanel,
-  'app/plugins/panel/welcome/module': welcomeBanner,
-  'app/plugins/panel/nodeGraph/module': nodeGraph,
-  'app/plugins/panel/histogram/module': histogramPanel,
-  'app/plugins/panel/alertGroups/module': alertGroupsPanel,
+const builtInPlugins: Record<string, System.Module | (() => Promise<System.Module>)> = {
+  // datasources
+  'core:plugin/graphite': graphitePlugin,
+  'core:plugin/cloudwatch': cloudwatchPlugin,
+  'core:plugin/dashboard': dashboardDSPlugin,
+  'core:plugin/elasticsearch': elasticsearchPlugin,
+  'core:plugin/opentsdb': opentsdbPlugin,
+  'core:plugin/grafana': grafanaPlugin,
+  'core:plugin/influxdb': influxdbPlugin,
+  'core:plugin/loki': lokiPlugin,
+  'core:plugin/jaeger': jaegerPlugin,
+  'core:plugin/zipkin': zipkinPlugin,
+  'core:plugin/mixed': mixedPlugin,
+  'core:plugin/mysql': mysqlPlugin,
+  'core:plugin/grafana-postgresql-datasource': postgresPlugin,
+  'core:plugin/mssql': mssqlPlugin,
+  'core:plugin/prometheus': prometheusPlugin,
+  'core:plugin/grafana-testdata-datasource': testDataDSPlugin,
+  'core:plugin/cloud-monitoring': cloudMonitoringPlugin,
+  'core:plugin/azuremonitor': azureMonitorPlugin,
+  'core:plugin/tempo': tempoPlugin,
+  'core:plugin/alertmanager': alertmanagerPlugin,
+  'core:plugin/grafana-pyroscope-datasource': pyroscopePlugin,
+  'core:plugin/parca': parcaPlugin,
+  // panels
+  'core:plugin/text': textPanel,
+  'core:plugin/timeseries': timeseriesPanel,
+  'core:plugin/trend': trendPanel,
+  'core:plugin/state-timeline': stateTimelinePanel,
+  'core:plugin/status-history': statusHistoryPanel,
+  'core:plugin/candlestick': candlestickPanel,
+  'core:plugin/graph': graphPanel,
+  'core:plugin/xychart': xyChartPanel,
+  'core:plugin/geomap': geomapPanel,
+  'core:plugin/canvas': canvasPanel,
+  'core:plugin/dashlist': dashListPanel,
+  'core:plugin/alertlist': alertListPanel,
+  'core:plugin/annolist': annoListPanel,
+  'core:plugin/heatmap': heatmapPanel,
+  'core:plugin/table': tablePanel,
+  'core:plugin/table-old': tableOldPanel,
+  'core:plugin/news': newsPanel,
+  'core:plugin/live': livePanel,
+  'core:plugin/stat': statPanel,
+  'core:plugin/datagrid': dataGridPanel,
+  'core:plugin/debug': debugPanel,
+  'core:plugin/flamegraph': flamegraphPanel,
+  'core:plugin/gettingstarted': gettingStartedPanel,
+  'core:plugin/gauge': gaugePanel,
+  'core:plugin/piechart': pieChartPanel,
+  'core:plugin/bargauge': barGaugePanel,
+  'core:plugin/barchart': barChartPanel,
+  'core:plugin/logs': logsPanel,
+  'core:plugin/traces': tracesPanel,
+  'core:plugin/welcome': welcomeBanner,
+  'core:plugin/nodeGraph': nodeGraph,
+  'core:plugin/histogram': histogramPanel,
+  'core:plugin/alertGroups': alertGroupsPanel,
 };
 
 export default builtInPlugins;
