@@ -1,7 +1,8 @@
 import React from 'react';
 import useAsync from 'react-use/lib/useAsync';
 
-import { SelectableValue } from '@grafana/data';
+import { SelectableValue, VariableWithMultiSupport } from '@grafana/data';
+import { getTemplateSrv } from '@grafana/runtime';
 
 import { QueryWithDefaults } from '../../defaults';
 import { DB, SQLExpression, SQLQuery, SQLSelectableValue } from '../../types';
@@ -31,6 +32,9 @@ export function SQLWhereRow({ query, fields, onQueryChange, db }: WhereRowProps)
       config={{ fields: state.value || {} }}
       sql={query.sql!}
       onSqlChange={(val: SQLExpression) => {
+        const templateVars = getTemplateSrv().getVariables() as VariableWithMultiSupport[];
+        removeQuotesForMultiVariables(val, templateVars);
+
         onSqlChange(val);
       }}
     />
@@ -49,3 +53,13 @@ function mapFieldsToTypes(columns: SQLSelectableValue[]) {
   }
   return fields;
 }
+
+export function removeQuotesForMultiVariables(val: SQLExpression, templateVars: VariableWithMultiSupport[]) {
+  const multiVariableInWhereString = (tv: VariableWithMultiSupport) =>
+    tv.multi && (val.whereString?.includes(`\${${tv.name}}`) || val.whereString?.includes(`$${tv.name}`));
+
+  if (templateVars.some((tv) => multiVariableInWhereString(tv))) {
+    val.whereString = val.whereString?.replaceAll("')", ')');
+    val.whereString = val.whereString?.replaceAll("('", '(');
+  }
+}
