@@ -1,6 +1,5 @@
-import { PanelData, LoadingState, DataSourceApi, CoreApp, urlUtil } from '@grafana/data';
+import { PanelData, LoadingState, DataSourceApi, urlUtil, CoreApp } from '@grafana/data';
 import { reportMetaAnalytics, MetaAnalyticsEventName, DataRequestEventPayload } from '@grafana/runtime';
-import { getConfig } from 'app/core/config';
 
 import { getDashboardSrv } from '../../dashboard/services/DashboardSrv';
 
@@ -8,7 +7,7 @@ export function emitDataRequestEvent(datasource: DataSourceApi) {
   let done = false;
 
   return (data: PanelData) => {
-    if (!data.request || done || data.request.app === CoreApp.Explore) {
+    if (!data.request || done) {
       return;
     }
 
@@ -21,41 +20,21 @@ export function emitDataRequestEvent(datasource: DataSourceApi) {
       return;
     }
 
-    const queryCacheStatus: { [key: string]: boolean } = {};
-    for (let i = 0; i < data.series.length; i++) {
-      const refId = data.series[i].refId;
-      if (refId && !queryCacheStatus[refId]) {
-        queryCacheStatus[refId] = data.series[i].meta?.isCachedResponse ?? false;
-      }
-    }
-    const totalQueries = Object.keys(queryCacheStatus).length;
-    const cachedQueries = Object.values(queryCacheStatus).filter((val) => val === true).length;
-
     const eventData: DataRequestEventPayload = {
       eventName: MetaAnalyticsEventName.DataRequest,
+      source: data.request.app,
       datasourceName: datasource.name,
       datasourceId: datasource.id,
       datasourceUid: datasource.uid,
       datasourceType: datasource.type,
-      panelId: data.request.panelId,
-      dashboardId: data.request.dashboardId,
       dataSize: 0,
       duration: data.request.endTime! - data.request.startTime,
-      totalQueries,
-      cachedQueries,
     };
 
-    // enrich with dashboard info
-    const dashboard = getDashboardSrv().getCurrent();
-    if (dashboard) {
-      eventData.dashboardId = dashboard.id;
-      eventData.dashboardName = dashboard.title;
-      eventData.dashboardUid = dashboard.uid;
-      eventData.folderName = dashboard.meta.folderTitle;
+    enrichWithInfo(eventData, data);
 
-      if (getConfig().isPublicDashboardView) {
-        eventData.publicDashboardUid = dashboard.meta.publicDashboardUid;
-      }
+    if (data.request.app !== CoreApp.Explore && data.request.app !== CoreApp.Correlations) {
+      enrichWithErrorData(eventData, data);
     }
 
     if (data.series && data.series.length > 0) {
@@ -63,14 +42,40 @@ export function emitDataRequestEvent(datasource: DataSourceApi) {
       eventData.dataSize = data.series.length;
     }
 
-    if (data.error) {
-      eventData.error = data.error.message;
-    }
-
     reportMetaAnalytics(eventData);
 
     // this done check is to make sure we do not double emit events in case
     // there are multiple responses with done state
     done = true;
   };
+
+  function enrichWithInfo(eventData: DataRequestEventPayload, data: PanelData) {
+    const queryCacheStatus: { [key: string]: boolean } = {};
+    for (let i = 0; i < data.series.length; i++) {
+      const refId = data.series[i].refId;
+      if (refId && !queryCacheStatus[refId]) {
+        queryCacheStatus[refId] = data.series[i].meta?.isCachedResponse ?? false;
+      }
+    }
+
+    eventData.totalQueries = Object.keys(queryCacheStatus).length;
+    eventData.cachedQueries = Object.values(queryCacheStatus).filter((val) => val === true).length;
+    eventData.panelId = data.request!.panelId;
+
+    const dashboard = getDashboardSrv().getCurrent();
+    if (dashboard) {
+      eventData.dashboardId = dashboard.id;
+      eventData.dashboardName = dashboard.title;
+      eventData.dashboardUid = dashboard.uid;
+      eventData.folderName = dashboard.meta.folderTitle;
+    }
+  }
+}
+
+function enrichWithErrorData(eventData: DataRequestEventPayload, data: PanelData) {
+  if (data.errors?.length) {
+    eventData.error = data.errors.join(', ');
+  } else if (data.error) {
+    eventData.error = data.error.message;
+  }
 }
