@@ -12,6 +12,7 @@ import {
 } from '@grafana/data';
 import { InlineField, InlineFieldRow, Select } from '@grafana/ui';
 
+import { getTransformationContent } from '../docs/getTransformationContent';
 import { useAllFieldNamesFromDataFrames } from '../utils';
 
 export const GroupingToMatrixTransformerEditor = ({
@@ -92,7 +93,8 @@ export const groupingToMatrixTransformRegistryItem: TransformerRegistryItem<Grou
   id: DataTransformerID.groupingToMatrix,
   editor: GroupingToMatrixTransformerEditor,
   transformation: standardTransformers.groupingToMatrixTransformer,
-  name: 'Grouping to matrix',
+  name: standardTransformers.groupingToMatrixTransformer.name,
   description: 'Takes a three fields combination and produces a Matrix.',
   categories: new Set([TransformerCategory.Combine, TransformerCategory.Reformat]),
+  help: getTransformationContent(DataTransformerID.groupingToMatrix).helperDocs,
 };
