@@ -1,14 +1,16 @@
-import React, { FC, useMemo } from 'react';
+import React, { useMemo } from 'react';
+
 import { IconButton } from '@grafana/ui';
-import { UsagesToNetwork } from './utils';
+
 import { NetworkGraphModal } from './NetworkGraphModal';
+import { UsagesToNetwork } from './utils';
 
 interface Props {
   id: string;
   usages: UsagesToNetwork[];
 }
 
-export const VariablesUnknownButton: FC<Props> = ({ id, usages }) => {
+export const VariablesUnknownButton = ({ id, usages }: Props) => {
   const network = useMemo(() => usages.find((n) => n.variable.id === id), [id, usages]);
 
   if (!network) {
@@ -25,7 +27,14 @@ export const VariablesUnknownButton: FC<Props> = ({ id, usages }) => {
   return (
     <NetworkGraphModal show={false} title={`Showing usages for: $${id}`} nodes={nodes} edges={network.edges}>
       {({ showModal }) => {
-        return <IconButton onClick={() => showModal()} name="code-branch" title="Show usages" />;
+        return (
+          <IconButton
+            onClick={() => showModal()}
+            name="code-branch"
+            tooltip="Show usages"
+            data-testid="VariablesUnknownButton"
+          />
+        );
       }}
     </NetworkGraphModal>
   );
