@@ -118,58 +118,52 @@ const validVariableNames: Record<string, RegExp[]> = {
 };
 
 export const getPropsWithVariable = (variableId: string, parent: { key: string; value: any }, result: any) => {
-  const stringValues = Object.keys(parent.value).reduce(
-    (all, key) => {
-      const value = parent.value[key];
-      if (!value || typeof value !== 'string') {
-        return all;
+  const stringValues = Object.keys(parent.value).reduce<Record<string, any>>((all, key) => {
+    const value = parent.value[key];
+    if (!value || typeof value !== 'string') {
+      return all;
+    }
+
+    const isValidName = validVariableNames[key]
+      ? validVariableNames[key].find((regex: RegExp) => regex.test(variableId))
+      : undefined;
+
+    let hasVariable = containsVariable(value, variableId);
+    if (key === 'repeat' && value === variableId) {
+      // repeat stores value without variable format
+      hasVariable = true;
+    }
+
+    if (!isValidName && hasVariable) {
+      all = {
+        ...all,
+        [key]: value,
+      };
+    }
+
+    return all;
+  }, {});
+
+  const objectValues = Object.keys(parent.value).reduce<Record<string, any>>((all, key) => {
+    const value = parent.value[key];
+    if (value && typeof value === 'object' && Object.keys(value).length) {
+      let id = value.title || value.name || value.id || key;
+      if (Array.isArray(parent.value) && parent.key === 'panels') {
+        id = `${id}[${value.id}]`;
       }
 
-      const isValidName = validVariableNames[key]
-        ? validVariableNames[key].find((regex: RegExp) => regex.test(variableId))
-        : undefined;
+      const newResult = getPropsWithVariable(variableId, { key, value }, {});
 
-      let hasVariable = containsVariable(value, variableId);
-      if (key === 'repeat' && value === variableId) {
-        // repeat stores value without variable format
-        hasVariable = true;
-      }
-
-      if (!isValidName && hasVariable) {
+      if (Object.keys(newResult).length) {
         all = {
           ...all,
-          [key]: value,
+          [id]: newResult,
         };
       }
+    }
 
-      return all;
-    },
-    {} as Record<string, any>
-  );
-
-  const objectValues = Object.keys(parent.value).reduce(
-    (all, key) => {
-      const value = parent.value[key];
-      if (value && typeof value === 'object' && Object.keys(value).length) {
-        let id = value.title || value.name || value.id || key;
-        if (Array.isArray(parent.value) && parent.key === 'panels') {
-          id = `${id}[${value.id}]`;
-        }
-
-        const newResult = getPropsWithVariable(variableId, { key, value }, {});
-
-        if (Object.keys(newResult).length) {
-          all = {
-            ...all,
-            [id]: newResult,
-          };
-        }
-      }
-
-      return all;
-    },
-    {} as Record<string, any>
-  );
+    return all;
+  }, {});
 
   if (Object.keys(stringValues).length || Object.keys(objectValues).length) {
     result = {
@@ -199,7 +193,7 @@ export const createUsagesNetwork = (variables: VariableModel[], dashboard: Dashb
 
   const unUsed: VariableModel[] = [];
   let usages: VariableUsageTree[] = [];
-  const model = dashboard.getSaveModelClone();
+  const model = dashboard.getSaveModelCloneOld();
 
   for (const variable of variables) {
     const variableId = variable.id;
@@ -239,7 +233,7 @@ function createUnknownsNetwork(variables: VariableModel[], dashboard: DashboardM
   }
 
   let unknown: VariableUsageTree[] = [];
-  const model = dashboard.getSaveModelClone();
+  const model = dashboard.getSaveModelCloneOld();
 
   const unknownVariables = getUnknownVariableStrings(variables, model);
   for (const unknownVariable of unknownVariables) {
@@ -341,7 +335,7 @@ export const transformUsagesToNetwork = (usages: VariableUsageTree[]): UsagesToN
   return results;
 };
 
-const countLeaves = (object: any): number => {
+const countLeaves = (object: object): number => {
   const total = Object.values(object).reduce((count: number, value: any) => {
     if (typeof value === 'object') {
       return count + countLeaves(value);
@@ -350,7 +344,7 @@ const countLeaves = (object: any): number => {
     return count + 1;
   }, 0);
 
-  return total as unknown as number;
+  return total;
 };
 
 export const getVariableUsages = (variableId: string, usages: VariableUsageTree[]): number => {
