@@ -1,7 +1,8 @@
-import React, { PropsWithChildren, useMemo } from 'react';
+import React, { PropsWithChildren, useMemo, useState } from 'react';
 
 import { VariableRefresh } from '@grafana/data';
-import { Field, RadioButtonGroup } from '@grafana/ui';
+import { Field, RadioButtonGroup, useTheme2 } from '@grafana/ui';
+import { useMediaQueryChange } from 'app/core/hooks/useMediaQueryChange';
 
 interface Props {
   onChange: (option: VariableRefresh) => void;
@@ -14,6 +15,16 @@ const REFRESH_OPTIONS = [
 ];
 
 export function QueryVariableRefreshSelect({ onChange, refresh }: PropsWithChildren<Props>) {
+  const theme = useTheme2();
+
+  const [isSmallScreen, setIsSmallScreen] = useState(false);
+  useMediaQueryChange({
+    breakpoint: theme.breakpoints.values.sm,
+    onChange: (e) => {
+      setIsSmallScreen(!e.matches);
+    },
+  });
+
   const value = useMemo(
     () => REFRESH_OPTIONS.find((o) => o.value === refresh)?.value ?? REFRESH_OPTIONS[0].value,
     [refresh]
@@ -21,7 +32,12 @@ export function QueryVariableRefreshSelect({ onChange, refresh }: PropsWithChild
 
   return (
     <Field label="Refresh" description="When to update the values of this variable">
-      <RadioButtonGroup options={REFRESH_OPTIONS} onChange={onChange} value={value} />
+      <RadioButtonGroup
+        options={REFRESH_OPTIONS}
+        onChange={onChange}
+        value={value}
+        size={isSmallScreen ? 'sm' : 'md'}
+      />
     </Field>
   );
 }
