@@ -18,87 +18,86 @@ import { getTemplatedRegex, toKeyedVariableIdentifier, toVariablePayload } from
 
 import { updateVariableOptions } from './reducer';
 
-export function toMetricFindValues(): OperatorFunction<PanelData, MetricFindValue[]> {
-  return (source) =>
-    source.pipe(
-      map((panelData) => {
-        const frames = panelData.series;
-        if (!frames || !frames.length) {
-          return [];
-        }
+export function toMetricFindValuesOperator(): OperatorFunction<PanelData, MetricFindValue[]> {
+  return (source) => source.pipe(map(toMetricFindValues));
+}
 
-        if (areMetricFindValues(frames)) {
-          return frames;
-        }
+export function toMetricFindValues(panelData: PanelData): MetricFindValue[] {
+  const frames = panelData.series;
+  if (!frames || !frames.length) {
+    return [];
+  }
 
-        const processedDataFrames = getProcessedDataFrames(frames);
-        const metrics: MetricFindValue[] = [];
+  if (areMetricFindValues(frames)) {
+    return frames;
+  }
 
-        let valueIndex = -1;
-        let textIndex = -1;
-        let stringIndex = -1;
-        let expandableIndex = -1;
+  const processedDataFrames = getProcessedDataFrames(frames);
+  const metrics: MetricFindValue[] = [];
 
-        for (const frame of processedDataFrames) {
-          for (let index = 0; index < frame.fields.length; index++) {
-            const field = frame.fields[index];
-            const fieldName = getFieldDisplayName(field, frame, frames).toLowerCase();
+  let valueIndex = -1;
+  let textIndex = -1;
+  let stringIndex = -1;
+  let expandableIndex = -1;
 
-            if (field.type === FieldType.string && stringIndex === -1) {
-              stringIndex = index;
-            }
+  for (const frame of processedDataFrames) {
+    for (let index = 0; index < frame.fields.length; index++) {
+      const field = frame.fields[index];
+      const fieldName = getFieldDisplayName(field, frame, frames).toLowerCase();
 
-            if (fieldName === 'text' && field.type === FieldType.string && textIndex === -1) {
-              textIndex = index;
-            }
+      if (field.type === FieldType.string && stringIndex === -1) {
+        stringIndex = index;
+      }
 
-            if (fieldName === 'value' && field.type === FieldType.string && valueIndex === -1) {
-              valueIndex = index;
-            }
+      if (fieldName === 'text' && field.type === FieldType.string && textIndex === -1) {
+        textIndex = index;
+      }
 
-            if (
-              fieldName === 'expandable' &&
-              (field.type === FieldType.boolean || field.type === FieldType.number) &&
-              expandableIndex === -1
-            ) {
-              expandableIndex = index;
-            }
-          }
-        }
+      if (fieldName === 'value' && field.type === FieldType.string && valueIndex === -1) {
+        valueIndex = index;
+      }
 
-        if (stringIndex === -1) {
-          throw new Error("Couldn't find any field of type string in the results.");
-        }
+      if (
+        fieldName === 'expandable' &&
+        (field.type === FieldType.boolean || field.type === FieldType.number) &&
+        expandableIndex === -1
+      ) {
+        expandableIndex = index;
+      }
+    }
+  }
 
-        for (const frame of frames) {
-          for (let index = 0; index < frame.length; index++) {
-            const expandable = expandableIndex !== -1 ? frame.fields[expandableIndex].values[index] : undefined;
-            const string = frame.fields[stringIndex].values[index];
-            const text = textIndex !== -1 ? frame.fields[textIndex].values[index] : null;
-            const value = valueIndex !== -1 ? frame.fields[valueIndex].values[index] : null;
+  if (stringIndex === -1) {
+    throw new Error("Couldn't find any field of type string in the results.");
+  }
 
-            if (valueIndex === -1 && textIndex === -1) {
-              metrics.push({ text: string, value: string, expandable });
-              continue;
-            }
+  for (const frame of processedDataFrames) {
+    for (let index = 0; index < frame.length; index++) {
+      const expandable = expandableIndex !== -1 ? frame.fields[expandableIndex].values[index] : undefined;
+      const string = frame.fields[stringIndex].values[index];
+      const text = textIndex !== -1 ? frame.fields[textIndex].values[index] : null;
+      const value = valueIndex !== -1 ? frame.fields[valueIndex].values[index] : null;
 
-            if (valueIndex === -1 && textIndex !== -1) {
-              metrics.push({ text, value: text, expandable });
-              continue;
-            }
+      if (valueIndex === -1 && textIndex === -1) {
+        metrics.push({ text: string, value: string, expandable });
+        continue;
+      }
 
-            if (valueIndex !== -1 && textIndex === -1) {
-              metrics.push({ text: value, value, expandable });
-              continue;
-            }
+      if (valueIndex === -1 && textIndex !== -1) {
+        metrics.push({ text, value: text, expandable });
+        continue;
+      }
 
-            metrics.push({ text, value, expandable });
-          }
-        }
+      if (valueIndex !== -1 && textIndex === -1) {
+        metrics.push({ text: value, value, expandable });
+        continue;
+      }
 
-        return metrics;
-      })
-    );
+      metrics.push({ text, value, expandable });
+    }
+  }
+
+  return metrics;
 }
 
 export function updateOptionsState(args: {
