@@ -2,6 +2,9 @@ import { AnyAction } from 'redux';
 
 import { LoadingState } from '@grafana/data';
 import * as runtime from '@grafana/runtime';
+import { DataSourceSrv, LocationService } from '@grafana/runtime';
+import { BackendSrv } from 'app/core/services/backend_srv';
+import { DashboardModel } from 'app/features/dashboard/state';
 
 import { reduxTester } from '../../../../test/core/redux/reduxTester';
 import { toAsyncOfResult } from '../../query/state/DashboardQueryRunner/testHelpers';
@@ -9,6 +12,7 @@ import { variableAdapters } from '../adapters';
 import { createConstantVariableAdapter } from '../constant/adapter';
 import { ALL_VARIABLE_TEXT, ALL_VARIABLE_VALUE, NEW_VARIABLE_ID } from '../constants';
 import { createCustomVariableAdapter } from '../custom/adapter';
+import { createCustomOptionsFromQuery } from '../custom/reducer';
 import { changeVariableName } from '../editor/actions';
 import { changeVariableNameFailed, changeVariableNameSucceeded, cleanEditorState } from '../editor/reducer';
 import { cleanPickerState } from '../pickers/OptionsPicker/reducer';
@@ -73,7 +77,7 @@ jest.mock('app/features/dashboard/services/TimeSrv', () => ({
 runtime.setDataSourceSrv({
   get: getDatasource,
   getList: getMetricSources,
-} as any);
+} as unknown as DataSourceSrv);
 
 describe('shared actions', () => {
   describe('when initDashboardTemplating is dispatched', () => {
@@ -85,7 +89,7 @@ describe('shared actions', () => {
       const custom = customBuilder().build();
       const textbox = textboxBuilder().build();
       const list = [query, constant, datasource, custom, textbox];
-      const dashboard: any = { templating: { list } };
+      const dashboard = { templating: { list } } as DashboardModel;
 
       reduxTester<TemplatingReducerType>()
         .givenRootReducer(getTemplatingRootReducer())
@@ -150,7 +154,7 @@ describe('shared actions', () => {
       const key = 'key';
       const var1 = queryBuilder().withName('var1').withQuery('$var2').build();
       const var2 = queryBuilder().withName('var2').withQuery('$var1').build();
-      const dashboard: any = { templating: { list: [var1, var2] } };
+      const dashboard = { templating: { list: [var1, var2] } } as DashboardModel;
       const preloadedState = getPreloadedState(key, {});
 
       await expect(async () => {
@@ -170,16 +174,16 @@ describe('shared actions', () => {
       const custom = customBuilder().build();
       const textbox = textboxBuilder().build();
       const list = [query, constant, datasource, custom, textbox];
-      const dashboard: any = { templating: { list } };
+      const dashboard = { templating: { list } } as DashboardModel;
       const preloadedState = getPreloadedState(key, {});
-      const locationService: any = { getSearchObject: () => ({}) };
+      const locationService = { getSearchObject: () => ({}) } as LocationService;
       runtime.setLocationService(locationService);
-      const variableQueryRunner: any = {
+      const variableQueryRunner = {
         cancelRequest: jest.fn(),
         queueRequest: jest.fn(),
         getResponse: () => toAsyncOfResult({ state: LoadingState.Done, identifier: toKeyedVariableIdentifier(query) }),
         destroy: jest.fn(),
-      };
+      } as unknown as VariableQueryRunner;
       setVariableQueryRunner(variableQueryRunner);
 
       const tester = await reduxTester<TemplatingReducerType>({ preloadedState })
@@ -189,7 +193,7 @@ describe('shared actions', () => {
         .whenAsyncActionIsDispatched(processVariables(key), true);
 
       await tester.thenDispatchedActionsPredicateShouldEqual((dispatchedActions) => {
-        expect(dispatchedActions.length).toEqual(5);
+        expect(dispatchedActions.length).toEqual(7);
 
         expect(dispatchedActions[0]).toEqual(
           toKeyedAction(
@@ -210,7 +214,7 @@ describe('shared actions', () => {
         expect(dispatchedActions[2]).toEqual(
           toKeyedAction(
             key,
-            variableStateCompleted(toVariablePayload({ ...custom, id: dispatchedActions[2].payload.action.payload.id }))
+            variableStateFetching(toVariablePayload({ ...custom, id: dispatchedActions[2].payload.action.payload.id }))
           )
         );
 
@@ -226,7 +230,23 @@ describe('shared actions', () => {
         expect(dispatchedActions[4]).toEqual(
           toKeyedAction(
             key,
-            variableStateCompleted(toVariablePayload({ ...query, id: dispatchedActions[4].payload.action.payload.id }))
+            createCustomOptionsFromQuery(
+              toVariablePayload({ ...custom, id: dispatchedActions[4].payload.action.payload.id })
+            )
+          )
+        );
+
+        expect(dispatchedActions[5]).toEqual(
+          toKeyedAction(
+            key,
+            variableStateCompleted(toVariablePayload({ ...custom, id: dispatchedActions[5].payload.action.payload.id }))
+          )
+        );
+
+        expect(dispatchedActions[6]).toEqual(
+          toKeyedAction(
+            key,
+            variableStateCompleted(toVariablePayload({ ...query, id: dispatchedActions[6].payload.action.payload.id }))
           )
         );
 
@@ -261,9 +281,9 @@ describe('shared actions', () => {
         .build();
 
       const list = [stats, substats];
-      const dashboard: any = { templating: { list } };
+      const dashboard = { templating: { list } } as DashboardModel;
       const query = { orgId: '1', 'var-stats': 'response', 'var-substats': ALL_VARIABLE_TEXT };
-      const locationService: any = { getSearchObject: () => query };
+      const locationService = { getSearchObject: () => query } as unknown as LocationService;
       runtime.setLocationService(locationService);
       const preloadedState = getPreloadedState(key, {});
 
@@ -378,6 +398,74 @@ describe('shared actions', () => {
       });
     });
 
+    describe('and not multivalue, but with currentValue specified', () => {
+      const A = { text: 'A', value: 'a-uid' };
+      const B = { text: 'B', value: 'b-uid' };
+      const C = { text: 'C', value: 'c-uid' };
+
+      it.each`
+        withOptions  | currentText  | currentValue | defaultValue | expected
+        ${[A, B, C]} | ${undefined} | ${undefined} | ${undefined} | ${A}
+        ${[A, B, C]} | ${'B'}       | ${'b-uid'}   | ${undefined} | ${B}
+        ${[A, B, C]} | ${'B'}       | ${undefined} | ${undefined} | ${B}
+        ${[A, B, C]} | ${undefined} | ${'b-uid'}   | ${undefined} | ${B}
+        ${[A, B, C]} | ${'Old B'}   | ${'b-uid'}   | ${undefined} | ${B}
+        ${[A, B, C]} | ${undefined} | ${'x-uid'}   | ${'b-uid'}   | ${B}
+        ${[A, B, C]} | ${undefined} | ${'b-uid'}   | ${'c-uid'}   | ${B}
+        ${[A, B, C]} | ${undefined} | ${'x-uid'}   | ${undefined} | ${A}
+        ${undefined} | ${undefined} | ${'b-uid'}   | ${undefined} | ${'should not dispatch setCurrentVariableValue'}
+      `(
+        'then correct actions are dispatched',
+        async ({ withOptions, currentText, currentValue, defaultValue, expected }) => {
+          let custom;
+          const key = 'key';
+          if (!withOptions) {
+            custom = customBuilder()
+              .withId('0')
+              .withRootStateKey(key)
+              .withCurrent(currentText, currentValue)
+              .withoutOptions()
+              .build();
+          } else {
+            custom = customBuilder()
+              .withId('0')
+              .withRootStateKey(key)
+              .withOptions(...withOptions)
+              .withCurrent(currentText, currentValue)
+              .build();
+          }
+
+          const tester = await reduxTester<TemplatingReducerType>()
+            .givenRootReducer(getTemplatingRootReducer())
+            .whenActionIsDispatched(
+              toKeyedAction(key, addVariable(toVariablePayload(custom, { global: false, index: 0, model: custom })))
+            )
+            .whenAsyncActionIsDispatched(
+              validateVariableSelectionState(toKeyedVariableIdentifier(custom), defaultValue),
+              true
+            );
+
+          await tester.thenDispatchedActionsPredicateShouldEqual((dispatchedActions) => {
+            const expectedActions: AnyAction[] = withOptions
+              ? [
+                  toKeyedAction(
+                    key,
+                    setCurrentVariableValue(
+                      toVariablePayload(
+                        { type: 'custom', id: '0' },
+                        { option: { text: expected.text, value: expected.value, selected: false } }
+                      )
+                    )
+                  ),
+                ]
+              : [];
+            expect(dispatchedActions).toEqual(expectedActions);
+            return true;
+          });
+        }
+      );
+    });
+
     describe('and multivalue', () => {
       it.each`
         withOptions        | withCurrent   | defaultValue | expectedText  | expectedSelected
@@ -603,7 +691,7 @@ describe('shared actions', () => {
               key,
               changeVariableNameFailed({
                 newName: '#constant!',
-                errorText: 'Only word and digit characters are allowed in variable names',
+                errorText: 'Only word characters are allowed in variable names',
               })
             )
           );
@@ -745,9 +833,9 @@ describe('shared actions', () => {
 
   describe('cancelVariables', () => {
     const cancelAllInFlightRequestsMock = jest.fn();
-    const backendSrvMock: any = {
+    const backendSrvMock = {
       cancelAllInFlightRequests: cancelAllInFlightRequestsMock,
-    };
+    } as unknown as BackendSrv;
 
     describe('when called', () => {
       it('then cancelAllInFlightRequests should be called and correct actions are dispatched', async () => {
