@@ -5,10 +5,20 @@ import {
   getDataSourceRef,
   isDataSourceRef,
   isEmptyObject,
+  isObject,
   LoadingState,
   TimeRange,
+  TypedVariableModel,
   UrlQueryMap,
   UrlQueryValue,
+  OrgVariableModel,
+  QueryVariableModel,
+  DashboardVariableModel,
+  UserVariableModel,
+  VariableHide,
+  VariableOption,
+  VariableRefresh,
+  VariableWithOptions,
 } from '@grafana/data';
 import { config, locationService } from '@grafana/runtime';
 import { notifyApp } from 'app/core/actions';
@@ -27,35 +37,17 @@ import { getTemplateSrv, TemplateSrv } from '../../templating/template_srv';
 import { variableAdapters } from '../adapters';
 import { ALL_VARIABLE_TEXT, ALL_VARIABLE_VALUE, VARIABLE_PREFIX } from '../constants';
 import { cleanEditorState } from '../editor/reducer';
-import {
-  hasCurrent,
-  hasLegacyVariableSupport,
-  hasOptions,
-  hasStandardVariableSupport,
-  isAdHoc,
-  isConstant,
-  isMulti,
-  isQuery,
-} from '../guard';
+import { hasCurrent, hasLegacyVariableSupport, hasOptions, hasStandardVariableSupport, isMulti } from '../guard';
 import { getAllAffectedPanelIdsForVariableChange, getPanelVars } from '../inspect/utils';
 import { cleanPickerState } from '../pickers/OptionsPicker/reducer';
 import { alignCurrentWithMulti } from '../shared/multiOptions';
 import {
-  DashboardVariableModel,
   initialVariableModelState,
-  OrgVariableModel,
-  QueryVariableModel,
   TransactionStatus,
-  UserVariableModel,
-  VariableHide,
-  VariableModel,
-  VariableOption,
-  VariableRefresh,
   VariablesChanged,
   VariablesChangedEvent,
   VariablesChangedInUrl,
   VariablesTimeRangeProcessDone,
-  VariableWithOptions,
 } from '../types';
 import {
   ensureStringValues,
@@ -69,6 +61,7 @@ import {
   toVariablePayload,
 } from '../utils';
 
+import { findVariableNodeInList, isVariableOnTimeRangeConfigured } from './helpers';
 import { toKeyedAction } from './keyedVariablesReducer';
 import { getIfExistsLastKey, getVariable, getVariablesByKey, getVariablesState } from './selectors';
 import {
@@ -143,7 +136,7 @@ export const initDashboardTemplating = (key: string, dashboard: DashboardModel):
   };
 };
 
-export function fixSelectedInconsistency(model: VariableModel): VariableModel | VariableWithOptions {
+export function fixSelectedInconsistency(model: TypedVariableModel): TypedVariableModel | VariableWithOptions {
   if (!hasOptions(model)) {
     return model;
   }
@@ -273,7 +266,7 @@ export const changeVariableMultiValue = (identifier: KeyedVariableIdentifier, mu
   };
 };
 
-export const processVariableDependencies = async (variable: VariableModel, state: StoreState) => {
+export const processVariableDependencies = async (variable: TypedVariableModel, state: StoreState) => {
   if (!variable.rootStateKey) {
     throw new Error(`rootStateKey not found for variable with id:${variable.id}`);
   }
@@ -303,7 +296,7 @@ export const processVariableDependencies = async (variable: VariableModel, state
 };
 
 const isDependencyGraphCircular = (
-  variable: VariableModel,
+  variable: TypedVariableModel,
   state: StoreState,
   encounteredDependencyIds: Set<string> = new Set()
 ): boolean => {
@@ -318,12 +311,12 @@ const isDependencyGraphCircular = (
   });
 };
 
-const getDirectDependencies = (variable: VariableModel, state: StoreState) => {
+const getDirectDependencies = (variable: TypedVariableModel, state: StoreState) => {
   if (!variable.rootStateKey) {
     return [];
   }
 
-  const directDependencies: VariableModel[] = [];
+  const directDependencies: TypedVariableModel[] = [];
 
   for (const otherVariable of getVariablesByKey(variable.rootStateKey, state)) {
     if (variable === otherVariable) {
@@ -340,7 +333,7 @@ const getDirectDependencies = (variable: VariableModel, state: StoreState) => {
   return directDependencies;
 };
 
-const isWaitingForDependencies = (key: string, dependencies: VariableModel[], state: StoreState): boolean => {
+const isWaitingForDependencies = (key: string, dependencies: TypedVariableModel[], state: StoreState): boolean => {
   if (dependencies.length === 0) {
     return false;
   }
@@ -379,6 +372,11 @@ export const processVariable = (
       }
     }
 
+    if (variable.type === 'custom') {
+      await dispatch(updateOptions(toKeyedVariableIdentifier(variable)));
+      return;
+    }
+
     // for variables that aren't updated via URL or refresh, let's simulate the same state changes
     dispatch(completeVariableLoading(identifier));
   };
@@ -388,8 +386,7 @@ export const processVariables = (key: string): ThunkResult<Promise<void>> => {
   return async (dispatch, getState) => {
     const queryParams = locationService.getSearchObject();
     const promises = getVariablesByKey(key, getState()).map(
-      async (variable: VariableModel) =>
-        await dispatch(processVariable(toKeyedVariableIdentifier(variable), queryParams))
+      async (variable) => await dispatch(processVariable(toKeyedVariableIdentifier(variable), queryParams))
     );
 
     await Promise.all(promises);
@@ -564,7 +561,7 @@ export const setOptionAsCurrent = (
   };
 };
 
-export const createGraph = (variables: VariableModel[]) => {
+export const createGraph = (variables: TypedVariableModel[]) => {
   const g = new Graph();
 
   variables.forEach((v) => {
@@ -611,15 +608,17 @@ export const variableUpdated = (
     const panels = state.dashboard?.getModel()?.panels ?? [];
     const panelVars = getPanelVars(panels);
 
-    const event: VariablesChangedEvent = isAdHoc(variableInState)
-      ? { refreshAll: true, panelIds: [] } // for adhoc variables we don't know which panels that will be impacted
-      : {
-          refreshAll: false,
-          panelIds: Array.from(getAllAffectedPanelIdsForVariableChange([variableInState.id], g, panelVars)),
-        };
+    const event: VariablesChangedEvent =
+      variableInState.type === 'adhoc'
+        ? { refreshAll: true, panelIds: [] } // for adhoc variables we don't know which panels that will be impacted
+        : {
+            refreshAll: false,
+            panelIds: Array.from(getAllAffectedPanelIdsForVariableChange([variableInState.id], g, panelVars)),
+            variable: getVariable(identifier, state),
+          };
 
     const node = g.getNode(variableInState.name);
-    let promises: Array<Promise<any>> = [];
+    let promises: Array<Promise<void>> = [];
     if (node) {
       promises = node.getOptimizedInputEdges().map((e) => {
         const variable = variables.find((v) => v.name === e.inputNode?.name);
@@ -645,7 +644,12 @@ export interface OnTimeRangeUpdatedDependencies {
   events: typeof appEvents;
 }
 
-const dfs = (node: Node, visited: string[], variables: VariableModel[], variablesRefreshTimeRange: VariableModel[]) => {
+const dfs = (
+  node: Node,
+  visited: string[],
+  variables: TypedVariableModel[],
+  variablesRefreshTimeRange: TypedVariableModel[]
+) => {
   if (!visited.includes(node.name)) {
     visited.push(node.name);
   }
@@ -669,6 +673,20 @@ const dfs = (node: Node, visited: string[], variables: VariableModel[], variable
   return variablesRefreshTimeRange;
 };
 
+// verify if the output edges of a node are not time range dependent
+const areOuputEdgesNotTimeRange = (node: Node, variables: TypedVariableModel[]) => {
+  return node.outputEdges.every((e) => {
+    const childNode = e.outputNode;
+    if (childNode) {
+      const childVariable = findVariableNodeInList(variables, childNode.name);
+      if (childVariable && childVariable.type === 'query') {
+        return childVariable.refresh !== VariableRefresh.onTimeRangeChanged;
+      }
+    }
+    return true;
+  });
+};
+
 /**
  * This function returns a list of variables that need to be refreshed when the time range changes
  * It follows this logic
@@ -684,24 +702,26 @@ const dfs = (node: Node, visited: string[], variables: VariableModel[], variable
  *       Here, we should traverse the tree using DFS (Depth First Search), as the dependent nodes will be updated in cascade when the parent variable is updated.
  */
 
-export const getVariablesThatNeedRefreshNew = (key: string, state: StoreState): VariableWithOptions[] => {
+export const getVariablesThatNeedRefreshNew = (key: string, state: StoreState): TypedVariableModel[] => {
   const allVariables = getVariablesByKey(key, state);
 
   //create dependency graph
   const g = createGraph(allVariables);
   // create a list of nodes that were visited
   const visitedDfs: string[] = [];
-  const variablesRefreshTimeRange: VariableWithOptions[] = [];
+  const variablesRefreshTimeRange: TypedVariableModel[] = [];
   allVariables.forEach((v) => {
     const node = g.getNode(v.name);
     if (visitedDfs.includes(v.name)) {
       return;
     }
     if (node) {
-      const parentVariableNode = allVariables.find((v) => v.name === node.name) as QueryVariableModel;
-      const isVariableTimeRange =
-        parentVariableNode && parentVariableNode.refresh === VariableRefresh.onTimeRangeChanged;
-      //
+      const parentVariableNode = findVariableNodeInList(allVariables, node.name);
+      if (!parentVariableNode) {
+        return;
+      }
+      const isVariableTimeRange = isVariableOnTimeRangeConfigured(parentVariableNode);
+      // if variable is time range and has no output edges add it to the list of variables that need refresh
       if (isVariableTimeRange && node.outputEdges.length === 0) {
         variablesRefreshTimeRange.push(parentVariableNode);
       }
@@ -716,12 +736,16 @@ export const getVariablesThatNeedRefreshNew = (key: string, state: StoreState):
         dfs(node, visitedDfs, allVariables, variablesRefreshTimeRange);
       }
 
+      // If is variable time range, has outputEdges, but the output edges are not time range configured, it means this
+      // is the top variable that need to be refreshed
+      if (isVariableTimeRange && node.outputEdges.length > 0 && areOuputEdgesNotTimeRange(node, allVariables)) {
+        if (!variablesRefreshTimeRange.includes(parentVariableNode)) {
+          variablesRefreshTimeRange.push(parentVariableNode);
+        }
+      }
+
       // if variable is not time range but has dependents (output edges) visit its dependants and repeat the process
-      if (
-        parentVariableNode &&
-        parentVariableNode.refresh &&
-        parentVariableNode.refresh !== VariableRefresh.onTimeRangeChanged
-      ) {
+      if (!isVariableTimeRange && node.outputEdges.length > 0) {
         dfs(node, visitedDfs, allVariables, variablesRefreshTimeRange);
       }
     }
@@ -735,8 +759,8 @@ const getVariablesThatNeedRefreshOld = (key: string, state: StoreState): Variabl
   const allVariables = getVariablesByKey(key, state);
 
   const variablesThatNeedRefresh = allVariables.filter((variable) => {
-    if (variable.hasOwnProperty('refresh') && variable.hasOwnProperty('options')) {
-      const variableWithRefresh = variable as unknown as QueryVariableModel;
+    if ('refresh' in variable && 'options' in variable) {
+      const variableWithRefresh = variable;
       return variableWithRefresh.refresh === VariableRefresh.onTimeRangeChanged;
     }
     return false;
@@ -755,7 +779,8 @@ export const onTimeRangeUpdated =
     dependencies.templateSrv.updateTimeRange(timeRange);
 
     // approach # 2, get variables that need refresh but use the dependency graph to only update the ones that are affected
-    let variablesThatNeedRefresh: VariableWithOptions[] = [];
+    // TODO: remove the VariableWithOptions type once the feature flag is on GA
+    let variablesThatNeedRefresh: VariableWithOptions[] | TypedVariableModel[] = [];
     if (config.featureToggles.refactorVariablesTimeRange) {
       variablesThatNeedRefresh = getVariablesThatNeedRefreshNew(key, getState());
     } else {
@@ -804,7 +829,7 @@ export const timeRangeUpdated =
 export const templateVarsChangedInUrl =
   (key: string, vars: ExtendedUrlQueryMap, events: typeof appEvents = appEvents): ThunkResult<void> =>
   async (dispatch, getState) => {
-    const update: Array<Promise<any>> = [];
+    const update: Array<Promise<void>> = [];
     const dashboard = getState().dashboard.getModel();
     const variables = getVariablesByKey(key, getState());
 
@@ -829,7 +854,7 @@ export const templateVarsChangedInUrl =
           value = variableInModel.current.value; // revert value to the value stored in dashboard json
         }
 
-        if (variableInModel && isConstant(variableInModel)) {
+        if (variableInModel && variableInModel.type === 'constant') {
           value = variableInModel.query; // revert value to the value stored in dashboard json, constants don't store current values in dashboard json
         }
       }
@@ -840,7 +865,9 @@ export const templateVarsChangedInUrl =
 
     const filteredVars = variables.filter((v) => {
       const key = VARIABLE_PREFIX + v.name;
-      return vars.hasOwnProperty(key) && isVariableUrlValueDifferentFromCurrent(v, vars[key].value) && !isAdHoc(v);
+      return (
+        vars.hasOwnProperty(key) && isVariableUrlValueDifferentFromCurrent(v, vars[key].value) && v.type !== 'adhoc'
+      );
     });
     const varGraph = createGraph(variables);
     const panelVars = getPanelVars(dashboard?.panels ?? []);
@@ -862,7 +889,7 @@ export const templateVarsChangedInUrl =
     }
   };
 
-export function isVariableUrlValueDifferentFromCurrent(variable: VariableModel, urlValue: any): boolean {
+export function isVariableUrlValueDifferentFromCurrent(variable: TypedVariableModel, urlValue: unknown): boolean {
   const variableValue = variableAdapters.get(variable.type).getValueForUrl(variable);
   let stringUrlValue = ensureStringValues(urlValue);
   if (Array.isArray(variableValue) && !Array.isArray(stringUrlValue)) {
@@ -877,10 +904,10 @@ const getQueryWithVariables = (key: string, getState: () => StoreState): UrlQuer
 
   const queryParamsNew = Object.keys(queryParams)
     .filter((key) => key.indexOf(VARIABLE_PREFIX) === -1)
-    .reduce((obj, key) => {
+    .reduce<UrlQueryMap>((obj, key) => {
       obj[key] = queryParams[key];
       return obj;
-    }, {} as UrlQueryMap);
+    }, {});
 
   for (const variable of getVariablesByKey(key, getState())) {
     if (variable.skipUrlSync) {
@@ -934,7 +961,7 @@ export function migrateVariablesDatasourceNameToRef(
   return (dispatch, getState) => {
     const variables = getVariablesByKey(key, getState());
     for (const variable of variables) {
-      if (!isAdHoc(variable) && !isQuery(variable)) {
+      if (variable.type !== 'adhoc' && variable.type !== 'query') {
         continue;
       }
 
@@ -1006,12 +1033,12 @@ export const updateOptions =
 
 export const createVariableErrorNotification = (
   message: string,
-  error: any,
+  error: unknown,
   identifier?: KeyedVariableIdentifier
 ): AppNotification =>
   createErrorNotification(
     `${identifier ? `Templating [${identifier.id}]` : 'Templating'}`,
-    `${message} ${error.message}`
+    error instanceof Error ? `${message} ${error.message}` : `${message}`
   );
 
 export const completeVariableLoading =
@@ -1079,10 +1106,6 @@ export function upgradeLegacyQueries(
   };
 }
 
-function isDataQueryType(query: any): query is DataQuery {
-  if (!query) {
-    return false;
-  }
-
-  return query.hasOwnProperty('refId') && typeof query.refId === 'string';
+function isDataQueryType(query: unknown): query is DataQuery {
+  return isObject(query) && 'refId' in query && typeof query.refId === 'string';
 }
