@@ -12,30 +12,30 @@ export type AlertManagerCortexConfig = {
 };
 
 export type TLSConfig = {
-  ca_file: string;
-  cert_file: string;
-  key_file: string;
+  ca_file?: string;
+  cert_file?: string;
+  key_file?: string;
   server_name?: string;
   insecure_skip_verify?: boolean;
 };
 
 export type HTTPConfigCommon = {
-  proxy_url?: string;
+  proxy_url?: string | null;
   tls_config?: TLSConfig;
 };
 
 export type HTTPConfigBasicAuth = {
-  basic_auth: {
+  basic_auth?: {
     username: string;
-  } & ({ password: string } | { password_file: string });
+  } & ({ password?: string } | { password_file?: string });
 };
 
 export type HTTPConfigBearerToken = {
-  bearer_token: string;
+  bearer_token?: string;
 };
 
 export type HTTPConfigBearerTokenFile = {
-  bearer_token_file: string;
+  bearer_token_file?: string;
 };
 
 export type HTTPConfig = HTTPConfigCommon & (HTTPConfigBasicAuth | HTTPConfigBearerToken | HTTPConfigBearerTokenFile);
@@ -79,20 +79,22 @@ export type GrafanaManagedReceiverConfig = {
   provenance?: string;
 };
 
-export type Receiver = {
+export interface GrafanaManagedContactPoint {
+  name: string;
+  grafana_managed_receiver_configs?: GrafanaManagedReceiverConfig[];
+}
+
+export interface AlertmanagerReceiver {
   name: string;
 
   email_configs?: EmailConfig[];
-  pagerduty_configs?: any[];
-  pushover_configs?: any[];
-  slack_configs?: any[];
-  opsgenie_configs?: any[];
   webhook_configs?: WebhookConfig[];
-  victorops_configs?: any[];
-  wechat_configs?: any[];
-  grafana_managed_receiver_configs?: GrafanaManagedReceiverConfig[];
-  [key: string]: any;
-};
+
+  // this is supposedly to support any *_configs
+  [key: `${string}_configs`]: any[] | undefined;
+}
+
+export type Receiver = GrafanaManagedContactPoint | AlertmanagerReceiver;
 
 export type ObjectMatcher = [name: string, operator: MatcherOperator, value: string];
 
@@ -121,10 +123,10 @@ export interface RouteWithID extends Route {
 }
 
 export type InhibitRule = {
-  target_match: Record<string, string>;
-  target_match_re: Record<string, string>;
-  source_match: Record<string, string>;
-  source_match_re: Record<string, string>;
+  target_match?: Record<string, string>;
+  target_match_re?: Record<string, string>;
+  source_match?: Record<string, string>;
+  source_match_re?: Record<string, string>;
   equal?: string[];
 };
 
