@@ -1,12 +1,13 @@
 import React, { useCallback, useEffect } from 'react';
 
 import { SelectableValue } from '@grafana/data';
-import { EditorRows } from '@grafana/experimental';
+import { EditorRows, Stack } from '@grafana/experimental';
 
 import CloudMonitoringDatasource from '../datasource';
 import { AlignmentTypes, CloudMonitoringQuery, QueryType, TimeSeriesList, TimeSeriesQuery } from '../types/query';
 import { CustomMetaData } from '../types/types';
 
+import { AliasBy } from './AliasBy';
 import { GraphPeriod } from './GraphPeriod';
 import { MQLQueryEditor } from './MQLQueryEditor';
 import { Project } from './Project';
@@ -68,6 +69,7 @@ function Editor({
         datasource: query.datasource,
         queryType: QueryType.TIME_SERIES_LIST,
         timeSeriesList: defaultTimeSeriesList(datasource),
+        aliasBy: query.aliasBy,
       });
     }
     if (query.queryType === QueryType.TIME_SERIES_QUERY && !query.timeSeriesQuery) {
@@ -76,6 +78,7 @@ function Editor({
         datasource: query.datasource,
         queryType: QueryType.TIME_SERIES_QUERY,
         timeSeriesQuery: defaultTimeSeriesQuery(datasource),
+        aliasBy: query.aliasBy,
       });
     }
   }, [onQueryChange, query, datasource]);
@@ -98,13 +101,22 @@ function Editor({
 
       {query.queryType === QueryType.TIME_SERIES_QUERY && query.timeSeriesQuery && (
         <>
-          <Project
-            refId={refId}
-            datasource={datasource}
-            onChange={(projectName) => onChangeTimeSeriesQuery({ ...query.timeSeriesQuery!, projectName: projectName })}
-            templateVariableOptions={variableOptionGroup.options}
-            projectName={query.timeSeriesQuery.projectName!}
-          />
+          <Stack gap={1} direction="row">
+            <Project
+              refId={refId}
+              datasource={datasource}
+              onChange={(projectName) =>
+                onChangeTimeSeriesQuery({ ...query.timeSeriesQuery!, projectName: projectName })
+              }
+              templateVariableOptions={variableOptionGroup.options}
+              projectName={query.timeSeriesQuery.projectName!}
+            />
+            <AliasBy
+              refId={refId}
+              value={query.aliasBy}
+              onChange={(aliasBy: string) => onQueryChange({ ...query, aliasBy })}
+            />
+          </Stack>
           <MQLQueryEditor
             onChange={(q: string) => onChangeTimeSeriesQuery({ ...query.timeSeriesQuery!, query: q })}
             onRunQuery={onRunQuery}
