@@ -1,5 +1,4 @@
 import { getBackendSrv, setBackendSrv } from '@grafana/runtime';
-import { getTimeSrv } from 'app/features/dashboard/services/TimeSrv';
 import { TemplateSrv } from 'app/features/templating/template_srv';
 import { CustomVariableModel } from 'app/features/variables/types';
 
@@ -13,13 +12,12 @@ export function setupMockedResourcesAPI({
   getMock,
 }: {
   getMock?: jest.Mock;
-  response?: Array<{ text: string; label: string; value: string }>;
+  response?: unknown;
   variables?: CustomVariableModel[];
   mockGetVariableName?: boolean;
 } = {}) {
   let templateService = variables ? setupMockedTemplateService(variables) : new TemplateSrv();
 
-  const timeSrv = getTimeSrv();
   const api = new ResourcesAPI(CloudWatchSettings, templateService);
   let resourceRequestMock = getMock ? getMock : jest.fn().mockReturnValue(response);
   setBackendSrv({
@@ -27,5 +25,5 @@ export function setupMockedResourcesAPI({
     get: resourceRequestMock,
   });
 
-  return { api, resourceRequestMock, templateService, timeSrv };
+  return { api, resourceRequestMock, templateService };
 }
