@@ -3,7 +3,7 @@ import React, { useState } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { AccessoryButton, InputGroup } from '@grafana/experimental';
-import { Input, stylesFactory, useTheme2 } from '@grafana/ui';
+import { Input, useStyles2 } from '@grafana/ui';
 
 import { MultiFilterCondition } from './MultiFilter';
 
@@ -17,8 +17,7 @@ export interface Props {
 export const MultiFilterItem = ({ filter, onChange, onDelete, keyPlaceholder }: Props) => {
   const [localKey, setLocalKey] = useState(filter.key || '');
   const [localValue, setLocalValue] = useState(filter.value?.join(', ') || '');
-  const theme = useTheme2();
-  const styles = getOperatorStyles(theme);
+  const styles = useStyles2(getOperatorStyles);
 
   return (
     <div data-testid="cloudwatch-multifilter-item">
@@ -59,9 +58,9 @@ export const MultiFilterItem = ({ filter, onChange, onDelete, keyPlaceholder }:
   );
 };
 
-const getOperatorStyles = stylesFactory((theme: GrafanaTheme2) => ({
+const getOperatorStyles = (theme: GrafanaTheme2) => ({
   root: css({
     padding: theme.spacing(0, 1),
     alignSelf: 'center',
   }),
-}));
+});
