@@ -1,7 +1,6 @@
-import { map, Observable } from 'rxjs';
+import { Observable } from 'rxjs';
 
 import { DataQueryRequest, DataQueryResponse, DataSourceInstanceSettings } from '@grafana/data';
-import { toDataQueryResponse } from '@grafana/runtime';
 import { TemplateSrv } from 'app/features/templating/template_srv';
 
 import { CloudWatchAnnotationQuery, CloudWatchJsonData, CloudWatchQuery } from '../types';
@@ -10,18 +9,21 @@ import { CloudWatchRequest } from './CloudWatchRequest';
 
 // This class handles execution of CloudWatch annotation queries
 export class CloudWatchAnnotationQueryRunner extends CloudWatchRequest {
-  constructor(instanceSettings: DataSourceInstanceSettings<CloudWatchJsonData>, templateSrv: TemplateSrv) {
-    super(instanceSettings, templateSrv);
+  constructor(
+    instanceSettings: DataSourceInstanceSettings<CloudWatchJsonData>,
+    templateSrv: TemplateSrv,
+    queryFn: (request: DataQueryRequest<CloudWatchQuery>) => Observable<DataQueryResponse>
+  ) {
+    super(instanceSettings, templateSrv, queryFn);
   }
 
   handleAnnotationQuery(
     queries: CloudWatchAnnotationQuery[],
     options: DataQueryRequest<CloudWatchQuery>
   ): Observable<DataQueryResponse> {
-    return this.awsRequest(this.dsQueryEndpoint, {
-      from: options.range.from.valueOf().toString(),
-      to: options.range.to.valueOf().toString(),
-      queries: queries.map((query) => ({
+    return this.query({
+      ...options,
+      targets: queries.map((query) => ({
         ...query,
         statistic: this.templateSrv.replace(query.statistic),
         region: this.templateSrv.replace(this.getActualRegion(query.region)),
@@ -34,11 +36,6 @@ export class CloudWatchAnnotationQueryRunner extends CloudWatchRequest {
         type: 'annotationQuery',
         datasource: this.ref,
       })),
-    }).pipe(
-      map((r) => {
-        const frames = toDataQueryResponse(r).data;
-        return { data: frames };
-      })
-    );
+    });
   }
 }
