@@ -6,7 +6,7 @@ import {
   TraceLog,
   TraceSpanRow,
 } from '@grafana/data';
-import { transformTraceData } from '@jaegertracing/jaeger-ui-components';
+import { transformTraceData } from 'app/features/explore/TraceView/components';
 
 import { JaegerResponse, Span, TraceProcess, TraceResponse } from './types';
 
