@@ -1,23 +1,28 @@
 import { render, screen } from '@testing-library/react';
 import React from 'react';
 
-import LokiLanguageProvider from '../../LanguageProvider';
 import { createLokiDatasource } from '../../mocks';
 
 import MonacoQueryField from './MonacoQueryField';
 import { Props } from './MonacoQueryFieldProps';
 
-function renderComponent({ initialValue = '', onRunQuery = jest.fn(), onBlur = jest.fn() }: Partial<Props> = {}) {
+function renderComponent({
+  initialValue = '',
+  onRunQuery = jest.fn(),
+  onBlur = jest.fn(),
+  onChange = jest.fn(),
+}: Partial<Props> = {}) {
   const datasource = createLokiDatasource();
-  const languageProvider = new LokiLanguageProvider(datasource);
 
   render(
     <MonacoQueryField
-      languageProvider={languageProvider}
+      datasource={datasource}
       initialValue={initialValue}
       history={[]}
       onRunQuery={onRunQuery}
       onBlur={onBlur}
+      onChange={onChange}
+      placeholder="Enter a Loki query (run with Shift+Enter)"
     />
   );
 }
