@@ -3,7 +3,6 @@ import { sortBy } from 'lodash';
 
 import {
   Identifier,
-  JsonExpressionParser,
   LabelFilter,
   LabelParser,
   LineComment,
@@ -17,13 +16,19 @@ import {
   UnwrapExpr,
   String,
   PipelineStage,
+  LogfmtParser,
+  JsonExpressionParser,
+  LogfmtExpressionParser,
+  Expr,
 } from '@grafana/lezer-logql';
 
 import { QueryBuilderLabelFilter } from '../prometheus/querybuilder/shared/types';
 
 import { unescapeLabelValue } from './languageUtils';
+import { getNodePositionsFromQuery } from './queryUtils';
 import { lokiQueryModeller as modeller } from './querybuilder/LokiQueryModeller';
 import { buildVisualQueryFromString, handleQuotes } from './querybuilder/parsing';
+import { LabelType } from './types';
 
 export class NodePosition {
   from: number;
@@ -138,13 +143,14 @@ function getMatchersWithFilter(query: string, label: string, operator: string, v
  *
  * This operates on substrings of the query with labels and operates just on those. This makes this
  * more robust and can alter even invalid queries, and preserves in general the query structure and whitespace.
- *
- * @param query
- * @param key
- * @param value
- * @param operator
  */
-export function addLabelToQuery(query: string, key: string, operator: string, value: string): string {
+export function addLabelToQuery(
+  query: string,
+  key: string,
+  operator: string,
+  value: string,
+  labelType?: LabelType | null
+): string {
   if (!key || !value) {
     throw new Error('Need label to add to query.');
   }
@@ -154,6 +160,8 @@ export function addLabelToQuery(query: string, key: string, operator: string, va
     return query;
   }
 
+  const parserPositions = getParserPositions(query);
+  const labelFilterPositions = getLabelFilterPositions(query);
   const hasStreamSelectorMatchers = getMatcherInStreamPositions(query);
   const everyStreamSelectorHasMatcher = streamSelectorPositions.every((streamSelectorPosition) =>
     hasStreamSelectorMatchers.some(
@@ -161,17 +169,35 @@ export function addLabelToQuery(query: string, key: string, operator: string, va
         matcherPosition.from >= streamSelectorPosition.from && matcherPosition.to <= streamSelectorPosition.to
     )
   );
-  const parserPositions = getParserPositions(query);
-  const labelFilterPositions = getLabelFilterPositions(query);
 
   const filter = toLabelFilter(key, value, operator);
-  // If we have non-empty stream selector and parser/label filter, we want to add a new label filter after the last one.
-  // If some of the stream selectors don't have matchers, we want to add new matcher to the all stream selectors.
-  if (everyStreamSelectorHasMatcher && (labelFilterPositions.length || parserPositions.length)) {
-    const positionToAdd = findLastPosition([...labelFilterPositions, ...parserPositions]);
+  if (labelType === LabelType.Parsed || labelType === LabelType.StructuredMetadata) {
+    const positionToAdd = findLastPosition([...streamSelectorPositions, ...labelFilterPositions, ...parserPositions]);
     return addFilterAsLabelFilter(query, [positionToAdd], filter);
-  } else {
+  } else if (labelType === LabelType.Indexed) {
     return addFilterToStreamSelector(query, streamSelectorPositions, filter);
+  } else {
+    // labelType is not set, so we need to figure out where to add the label
+    // if we don't have a parser, or have empty stream selectors, we will just add it to the stream selector
+    if (parserPositions.length === 0 || everyStreamSelectorHasMatcher === false) {
+      return addFilterToStreamSelector(query, streamSelectorPositions, filter);
+    } else {
+      // If `labelType` is not set, it indicates a potential metric query (`labelType` is present only in log queries that came from a Loki instance supporting the `categorize-labels` API). In case we are not adding the label to stream selectors we need to find the last position to add in each expression.
+      // E.g. in `sum(rate({foo="bar"} | logfmt [$__auto])) / sum(rate({foo="baz"} | logfmt [$__auto]))` we need to add the label at two places.
+      const subExpressions = findLeaves(getNodePositionsFromQuery(query, [Expr]));
+      const parserFilterPositions = [...parserPositions, ...labelFilterPositions];
+
+      // find last position for each subexpression
+      const lastPositionsPerExpression = subExpressions.map((subExpression) => {
+        return findLastPosition(
+          parserFilterPositions.filter((p) => {
+            return subExpression.contains(p);
+          })
+        );
+      });
+
+      return addFilterAsLabelFilter(query, lastPositionsPerExpression, filter);
+    }
   }
 }
 
@@ -255,9 +281,9 @@ export function getStreamSelectorPositions(query: string): NodePosition[] {
   const tree = parser.parse(query);
   const positions: NodePosition[] = [];
   tree.iterate({
-    enter: ({ type, from, to }): false | void => {
+    enter: ({ type, node }): false | void => {
       if (type.id === Selector) {
-        positions.push(new NodePosition(from, to, type));
+        positions.push(NodePosition.fromNode(node));
         return false;
       }
     },
@@ -265,19 +291,6 @@ export function getStreamSelectorPositions(query: string): NodePosition[] {
   return positions;
 }
 
-function getMatcherInStreamPositions(query: string): NodePosition[] {
-  const tree = parser.parse(query);
-  const positions: NodePosition[] = [];
-  tree.iterate({
-    enter: ({ node }): false | void => {
-      if (node.type.id === Selector) {
-        positions.push(...getAllPositionsInNodeByType(query, node, Matcher));
-      }
-    },
-  });
-  return positions;
-}
-
 /**
  * Parse the string and get all LabelParser positions in the query.
  * @param query
@@ -285,10 +298,11 @@ function getMatcherInStreamPositions(query: string): NodePosition[] {
 export function getParserPositions(query: string): NodePosition[] {
   const tree = parser.parse(query);
   const positions: NodePosition[] = [];
+  const parserNodeTypes = [LabelParser, JsonExpressionParser, LogfmtParser, LogfmtExpressionParser];
   tree.iterate({
-    enter: ({ type, from, to }): false | void => {
-      if (type.id === LabelParser || type.id === JsonExpressionParser) {
-        positions.push(new NodePosition(from, to, type));
+    enter: ({ type, node }): false | void => {
+      if (parserNodeTypes.includes(type.id)) {
+        positions.push(NodePosition.fromNode(node));
         return false;
       }
     },
@@ -304,9 +318,9 @@ export function getLabelFilterPositions(query: string): NodePosition[] {
   const tree = parser.parse(query);
   const positions: NodePosition[] = [];
   tree.iterate({
-    enter: ({ type, from, to }): false | void => {
+    enter: ({ type, node }): false | void => {
       if (type.id === LabelFilter) {
-        positions.push(new NodePosition(from, to, type));
+        positions.push(NodePosition.fromNode(node));
         return false;
       }
     },
@@ -322,9 +336,9 @@ function getLineFiltersPositions(query: string): NodePosition[] {
   const tree = parser.parse(query);
   const positions: NodePosition[] = [];
   tree.iterate({
-    enter: ({ type, from, to }): false | void => {
+    enter: ({ type, node }): false | void => {
       if (type.id === LineFilters) {
-        positions.push(new NodePosition(from, to, type));
+        positions.push(NodePosition.fromNode(node));
         return false;
       }
     },
@@ -340,9 +354,9 @@ function getLogQueryPositions(query: string): NodePosition[] {
   const tree = parser.parse(query);
   const positions: NodePosition[] = [];
   tree.iterate({
-    enter: ({ type, from, to, node }): false | void => {
+    enter: ({ type, node }): false | void => {
       if (type.id === LogExpr) {
-        positions.push(new NodePosition(from, to, type));
+        positions.push(NodePosition.fromNode(node));
         return false;
       }
 
@@ -507,14 +521,14 @@ function addLabelFormat(
   return newQuery;
 }
 
-export function addLineFilter(query: string): string {
+export function addLineFilter(query: string, value = '', operator = '|='): string {
   const streamSelectorPositions = getStreamSelectorPositions(query);
   if (!streamSelectorPositions.length) {
     return query;
   }
   const streamSelectorEnd = streamSelectorPositions[0].to;
 
-  const newQueryExpr = query.slice(0, streamSelectorEnd) + ' |= ``' + query.slice(streamSelectorEnd);
+  const newQueryExpr = query.slice(0, streamSelectorEnd) + ` ${operator} \`${value}\`` + query.slice(streamSelectorEnd);
   return newQueryExpr;
 }
 
@@ -546,10 +560,23 @@ function labelExists(labels: QueryBuilderLabelFilter[], filter: QueryBuilderLabe
  * @param positions
  */
 export function findLastPosition(positions: NodePosition[]): NodePosition {
+  if (!positions.length) {
+    return new NodePosition(0, 0);
+  }
   return positions.reduce((prev, current) => (prev.to > current.to ? prev : current));
 }
 
-function getAllPositionsInNodeByType(query: string, node: SyntaxNode, type: number): NodePosition[] {
+/**
+ * Gets all leaves of the nodes given. Leaves are nodes that don't contain any other nodes.
+ *
+ * @param {NodePosition[]} nodes
+ * @return
+ */
+function findLeaves(nodes: NodePosition[]): NodePosition[] {
+  return nodes.filter((node) => nodes.every((n) => node.contains(n) === false || node === n));
+}
+
+function getAllPositionsInNodeByType(node: SyntaxNode, type: number): NodePosition[] {
   if (node.type.id === type) {
     return [NodePosition.fromNode(node)];
   }
@@ -558,9 +585,22 @@ function getAllPositionsInNodeByType(query: string, node: SyntaxNode, type: numb
   let pos = 0;
   let child = node.childAfter(pos);
   while (child) {
-    positions.push(...getAllPositionsInNodeByType(query, child, type));
+    positions.push(...getAllPositionsInNodeByType(child, type));
     pos = child.to;
     child = node.childAfter(pos);
   }
   return positions;
 }
+
+function getMatcherInStreamPositions(query: string): NodePosition[] {
+  const tree = parser.parse(query);
+  const positions: NodePosition[] = [];
+  tree.iterate({
+    enter: ({ node }): false | void => {
+      if (node.type.id === Selector) {
+        positions.push(...getAllPositionsInNodeByType(node, Matcher));
+      }
+    },
+  });
+  return positions;
+}
