@@ -1,8 +1,7 @@
 import { of } from 'rxjs';
 import { getQueryOptions } from 'test/helpers/getQueryOptions';
 
-import { dateTime } from '@grafana/data';
-import { LoadingState } from '@grafana/schema';
+import { dateTime, LoadingState } from '@grafana/data';
 
 import { LokiDatasource } from './datasource';
 import * as logsTimeSplit from './logsTimeSplitting';
@@ -13,6 +12,9 @@ import { trackGroupedQueries } from './tracking';
 import { LokiQuery, LokiQueryType } from './types';
 
 jest.mock('./tracking');
+jest.mock('uuid', () => ({
+  v4: jest.fn().mockReturnValue('uuid'),
+}));
 
 describe('runSplitQuery()', () => {
   let datasource: LokiDatasource;
@@ -40,6 +42,14 @@ describe('runSplitQuery()', () => {
     });
   });
 
+  test('Returns a DataQueryResponse with the expected attributes', async () => {
+    await expect(runSplitQuery(datasource, request)).toEmitValuesWith((response) => {
+      expect(response[0].data).toBeDefined();
+      expect(response[0].state).toBe(LoadingState.Done);
+      expect(response[0].key).toBeDefined();
+    });
+  });
+
   test('Correctly splits queries without step', async () => {
     await expect(runSplitQuery(datasource, request)).toEmitValuesWith(() => {
       expect(datasource.runQuery).toHaveBeenNthCalledWith(
@@ -202,6 +212,7 @@ describe('runSplitQuery()', () => {
           {
             data: [],
             state: LoadingState.Done,
+            key: 'uuid',
           },
           [
             {
@@ -234,6 +245,7 @@ describe('runSplitQuery()', () => {
           {
             data: [],
             state: LoadingState.Done,
+            key: 'uuid',
           },
           [
             {
