@@ -1,10 +1,9 @@
 import { render, screen } from '@testing-library/react';
 import React from 'react';
 
-import { DataSourcePluginMeta } from '@grafana/data';
 import { addOperation } from 'app/plugins/datasource/prometheus/querybuilder/shared/OperationList.testUtils';
 
-import { LokiDatasource } from '../../datasource';
+import { createLokiDatasource } from '../../mocks';
 
 import { LokiQueryBuilderContainer } from './LokiQueryBuilderContainer';
 
@@ -15,21 +14,7 @@ describe('LokiQueryBuilderContainer', () => {
         expr: '{job="testjob"}',
         refId: 'A',
       },
-      datasource: new LokiDatasource(
-        {
-          id: 1,
-          uid: '',
-          type: 'loki',
-          name: 'loki-test',
-          access: 'proxy',
-          url: '',
-          jsonData: {},
-          meta: {} as DataSourcePluginMeta,
-          readOnly: false,
-        },
-        undefined,
-        undefined
-      ),
+      datasource: createLokiDatasource(),
       onChange: jest.fn(),
       onRunQuery: () => {},
       showExplain: false,
@@ -42,7 +27,7 @@ describe('LokiQueryBuilderContainer', () => {
     await addOperation('Range functions', 'Rate');
     expect(await screen.findByText('Rate')).toBeInTheDocument();
     expect(props.onChange).toBeCalledWith({
-      expr: 'rate({job="testjob"} [$__interval])',
+      expr: 'rate({job="testjob"} [$__auto])',
       refId: 'A',
     });
   });
