@@ -11,6 +11,116 @@ describe('buildVisualQueryFromString', () => {
     );
   });
 
+  it('parses simple binary comparison', () => {
+    expect(buildVisualQueryFromString('count_over_time({app="aggregator"} [$__auto]) == 11')).toEqual({
+      query: {
+        labels: [
+          {
+            label: 'app',
+            op: '=',
+            value: 'aggregator',
+          },
+        ],
+        operations: [
+          {
+            id: LokiOperationId.CountOverTime,
+            params: ['$__auto'],
+          },
+          {
+            id: LokiOperationId.EqualTo,
+            // defined in getSimpleBinaryRenderer, the first argument is the bool value, and the second is the comparison operator
+            params: [11, false],
+          },
+        ],
+      },
+      errors: [],
+    });
+  });
+
+  // This still fails because loki doesn't properly parse the bool operator
+  it('parses simple query with label-values with boolean operator', () => {
+    expect(buildVisualQueryFromString('count_over_time({app="aggregator"} [$__auto]) == bool 12')).toEqual({
+      query: {
+        labels: [
+          {
+            label: 'app',
+            op: '=',
+            value: 'aggregator',
+          },
+        ],
+        operations: [
+          {
+            id: LokiOperationId.CountOverTime,
+            params: ['$__auto'],
+          },
+          {
+            id: LokiOperationId.EqualTo,
+            // defined in getSimpleBinaryRenderer, the first argument is the bool value, and the second is the comparison operator
+            params: [12, true],
+          },
+        ],
+      },
+      errors: [],
+    });
+  });
+
+  it('parses binary operation with query', () => {
+    expect(
+      // There is no capability for "bool" in the query builder for (nested) binary operation with query as of now, it will always be stripped out
+      buildVisualQueryFromString(
+        'max by(stream) (count_over_time({app="aggregator"}[1m])) > bool ignoring(stream) avg(count_over_time({app="aggregator"}[1m]))'
+      )
+    ).toEqual({
+      query: {
+        binaryQueries: [
+          {
+            // nested binary operation
+            operator: '>',
+            query: {
+              labels: [
+                {
+                  label: 'app',
+                  op: '=',
+                  value: 'aggregator',
+                },
+              ],
+              operations: [
+                {
+                  id: 'count_over_time',
+                  params: ['1m'],
+                },
+                {
+                  id: 'avg',
+                  params: [],
+                },
+              ],
+            },
+            vectorMatches: 'stream',
+            vectorMatchesType: 'ignoring',
+          },
+        ],
+        labels: [
+          {
+            label: 'app',
+            op: '=',
+            value: 'aggregator',
+          },
+        ],
+        operations: [
+          {
+            id: 'count_over_time',
+            params: ['1m'],
+          },
+          {
+            id: '__max_by',
+            params: ['stream'],
+          },
+        ],
+      },
+      errors: [],
+    });
+  });
+
   it('parses simple query with label-values', () => {
     expect(buildVisualQueryFromString('{app="frontend"}')).toEqual(
       noErrors({
@@ -61,6 +171,26 @@ describe('buildVisualQueryFromString', () => {
     );
   });
 
+  it.each([
+    ['|=', LokiOperationId.LineContains],
+    ['!=', LokiOperationId.LineContainsNot],
+    ['|~', LokiOperationId.LineMatchesRegex],
+    ['!~', LokiOperationId.LineMatchesRegexNot],
+  ])('parses query with line filter and `or` statements', (op: string, id: LokiOperationId) => {
+    expect(buildVisualQueryFromString(`{app="frontend"} ${op} "line" or "text"`)).toEqual(
+      noErrors({
+        labels: [
+          {
+            op: '=',
+            value: 'frontend',
+            label: 'app',
+          },
+        ],
+        operations: [{ id, params: ['line', 'text'] }],
+      })
+    );
+  });
+
   it('parses query with line filters and escaped characters', () => {
     expect(buildVisualQueryFromString('{app="frontend"} |= "\\\\line"')).toEqual(
       noErrors({
@@ -119,12 +249,28 @@ describe('buildVisualQueryFromString', () => {
         ],
         operations: [
           { id: LokiOperationId.LineFilterIpMatches, params: ['|=', '192.168.4.5/16'] },
-          { id: LokiOperationId.Logfmt, params: [] },
+          { id: LokiOperationId.Logfmt, params: [false, false] },
         ],
       })
     );
   });
 
+  it('returns error when parsing ambiguous query', () => {
+    //becomes topk(5, count_over_time({app="aggregator"} [1m])) / count_over_time({cluster="dev-eu-west-2"} [1m])
+    const context = buildVisualQueryFromString(
+      'topk(5,count_over_time({app="aggregator"}[1m])/count_over_time({cluster="dev-eu-west-2"}[1m]))'
+    );
+    expect(context).toMatchObject({
+      errors: [
+        {
+          from: 7,
+          text: 'Query parsing is ambiguous.',
+          to: 93,
+        },
+      ],
+    });
+  });
+
   it('parses query with matcher label filter', () => {
     expect(buildVisualQueryFromString('{app="frontend"} | bar="baz"')).toEqual(
       noErrors({
@@ -209,7 +355,7 @@ describe('buildVisualQueryFromString', () => {
           },
         ],
         operations: [
-          { id: LokiOperationId.Logfmt, params: [] },
+          { id: LokiOperationId.Logfmt, params: [false, false] },
           { id: LokiOperationId.LabelFilterIpMatches, params: ['address', '=', '192.168.4.5/16'] },
         ],
       })
@@ -260,7 +406,7 @@ describe('buildVisualQueryFromString', () => {
           },
         ],
         operations: [
-          { id: LokiOperationId.Logfmt, params: [] },
+          { id: LokiOperationId.Logfmt, params: [false, false] },
           { id: LokiOperationId.Unwrap, params: ['bytes_processed', ''] },
           { id: LokiOperationId.SumOverTime, params: ['1m'] },
         ],
@@ -281,7 +427,7 @@ describe('buildVisualQueryFromString', () => {
           },
         ],
         operations: [
-          { id: LokiOperationId.Logfmt, params: [] },
+          { id: LokiOperationId.Logfmt, params: [false, false] },
           { id: LokiOperationId.Unwrap, params: ['duration', ''] },
           { id: LokiOperationId.LabelFilterNoErrors, params: [] },
           { id: LokiOperationId.SumOverTime, params: ['1m'] },
@@ -303,7 +449,7 @@ describe('buildVisualQueryFromString', () => {
           },
         ],
         operations: [
-          { id: LokiOperationId.Logfmt, params: [] },
+          { id: LokiOperationId.Logfmt, params: [false, false] },
           { id: LokiOperationId.Unwrap, params: ['duration', ''] },
           { id: LokiOperationId.LabelFilter, params: ['label', '=', 'value'] },
           { id: LokiOperationId.SumOverTime, params: ['1m'] },
@@ -326,7 +472,7 @@ describe('buildVisualQueryFromString', () => {
           },
         ],
         operations: [
-          { id: LokiOperationId.Logfmt, params: [] },
+          { id: LokiOperationId.Logfmt, params: [false, false] },
           { id: LokiOperationId.Unwrap, params: ['label', 'duration'] },
           { id: LokiOperationId.SumOverTime, params: ['5m'] },
         ],
@@ -360,7 +506,7 @@ describe('buildVisualQueryFromString', () => {
           },
         ],
         operations: [
-          { id: LokiOperationId.Logfmt, params: [] },
+          { id: LokiOperationId.Logfmt, params: [false, false] },
           { id: LokiOperationId.Decolorize, params: [] },
           { id: LokiOperationId.LabelFilterNoErrors, params: [] },
         ],
@@ -425,7 +571,8 @@ describe('buildVisualQueryFromString', () => {
   });
 
   it('parses metrics query with function and aggregation with grouping at the end', () => {
-    expect(buildVisualQueryFromString('sum(rate({app="frontend"} | json [5m])) without(job,name)')).toEqual(
+    const expression = 'sum(rate({app="frontend"} | json [5m])) without(job,name)';
+    expect(buildVisualQueryFromString(expression)).toEqual(
       noErrors({
         labels: [
           {
@@ -477,7 +624,7 @@ describe('buildVisualQueryFromString', () => {
           },
         ],
         operations: [
-          { id: LokiOperationId.Logfmt, params: [] },
+          { id: LokiOperationId.Logfmt, params: [false, false] },
           { id: LokiOperationId.LabelFilterNoErrors, params: [] },
           { id: LokiOperationId.CountOverTime, params: ['5m'] },
           { id: LokiOperationId.Sum, params: [] },
@@ -557,7 +704,9 @@ describe('buildVisualQueryFromString', () => {
   });
 
   it('parses query with multiple label format', () => {
-    expect(buildVisualQueryFromString('{app="frontend"} | label_format renameTo=original, bar=baz')).toEqual(
+    // Converted to {app="frontend"} | label_format renameTo=original | label_format bar=baz by visual query builder
+    const expression = '{app="frontend"} | label_format renameTo=original, bar=baz';
+    expect(buildVisualQueryFromString(expression)).toEqual(
       noErrors({
         labels: [
           {
@@ -605,9 +754,10 @@ describe('buildVisualQueryFromString', () => {
   });
 
   it('parses chained binary query', () => {
-    expect(
-      buildVisualQueryFromString('rate({project="bar"}[5m]) * 2 / rate({project="foo"}[5m]) + rate({app="test"}[1m])')
-    ).toEqual(
+    const expression = 'rate({project="bar"}[5m]) * 2 / rate({project="foo"}[5m]) + rate({app="test"}[1m])';
+    // is converted to (rate({project="bar"} [5m]) * 2) / (rate({project="foo"} [5m]) + rate({app="test"} [1m])) by visual query builder
+    // Note the extra parenthesis around the first binary operation expression: (rate({project="bar"} [5m]) * 2)
+    expect(buildVisualQueryFromString(expression)).toEqual(
       noErrors({
         labels: [{ op: '=', value: 'bar', label: 'project' }],
         operations: [
@@ -667,7 +817,9 @@ describe('buildVisualQueryFromString', () => {
   });
 
   it('parses a regexp with no param', () => {
-    expect(buildVisualQueryFromString('{app="frontend"} | regexp ')).toEqual(
+    const expression = '{app="frontend"} | regexp ';
+    // Converted to {app="frontend"} | regexp `` by visual query builder
+    expect(buildVisualQueryFromString(expression)).toEqual(
       noErrors({
         labels: [
           {
@@ -746,6 +898,143 @@ describe('buildVisualQueryFromString', () => {
       },
     });
   });
+
+  it('parses a log query with drop and no labels', () => {
+    expect(buildVisualQueryFromString('{app="frontend"} | drop')).toEqual(
+      noErrors({
+        labels: [
+          {
+            op: '=',
+            value: 'frontend',
+            label: 'app',
+          },
+        ],
+        operations: [{ id: LokiOperationId.Drop, params: [] }],
+      })
+    );
+  });
+
+  it('parses a log query with drop and labels', () => {
+    expect(buildVisualQueryFromString('{app="frontend"} | drop id, email')).toEqual(
+      noErrors({
+        labels: [
+          {
+            op: '=',
+            value: 'frontend',
+            label: 'app',
+          },
+        ],
+        operations: [{ id: LokiOperationId.Drop, params: ['id', 'email'] }],
+      })
+    );
+  });
+
+  it('parses a log query with drop, labels and expressions', () => {
+    expect(buildVisualQueryFromString('{app="frontend"} | drop id, email, test="test1"')).toEqual(
+      noErrors({
+        labels: [
+          {
+            op: '=',
+            value: 'frontend',
+            label: 'app',
+          },
+        ],
+        operations: [{ id: LokiOperationId.Drop, params: ['id', 'email', 'test="test1"'] }],
+      })
+    );
+  });
+
+  it('parses a log query with keep and no labels', () => {
+    expect(buildVisualQueryFromString('{app="frontend"} | keep')).toEqual(
+      noErrors({
+        labels: [
+          {
+            op: '=',
+            value: 'frontend',
+            label: 'app',
+          },
+        ],
+        operations: [{ id: LokiOperationId.Keep, params: [] }],
+      })
+    );
+  });
+
+  it('parses a log query with keep and labels', () => {
+    expect(buildVisualQueryFromString('{app="frontend"} | keep id, email')).toEqual(
+      noErrors({
+        labels: [
+          {
+            op: '=',
+            value: 'frontend',
+            label: 'app',
+          },
+        ],
+        operations: [{ id: LokiOperationId.Keep, params: ['id', 'email'] }],
+      })
+    );
+  });
+
+  it('parses a log query with keep, labels and expressions', () => {
+    expect(buildVisualQueryFromString('{app="frontend"} | keep id, email, test="test1"')).toEqual(
+      noErrors({
+        labels: [
+          {
+            op: '=',
+            value: 'frontend',
+            label: 'app',
+          },
+        ],
+        operations: [{ id: LokiOperationId.Keep, params: ['id', 'email', 'test="test1"'] }],
+      })
+    );
+  });
+
+  it('parses query with logfmt parser', () => {
+    expect(buildVisualQueryFromString('{label="value"} | logfmt')).toEqual(
+      noErrors({
+        labels: [
+          {
+            op: '=',
+            value: 'value',
+            label: 'label',
+          },
+        ],
+        operations: [{ id: LokiOperationId.Logfmt, params: [false, false] }],
+      })
+    );
+  });
+
+  it('parses query with logfmt parser and flags', () => {
+    expect(buildVisualQueryFromString('{label="value"} | logfmt --keep-empty --strict')).toEqual(
+      noErrors({
+        labels: [
+          {
+            op: '=',
+            value: 'value',
+            label: 'label',
+          },
+        ],
+        operations: [{ id: LokiOperationId.Logfmt, params: [true, true] }],
+      })
+    );
+  });
+
+  it('parses query with logfmt parser, flags, and labels', () => {
+    expect(
+      buildVisualQueryFromString('{label="value"} | logfmt --keep-empty --strict label1, label2, label3="label4"')
+    ).toEqual(
+      noErrors({
+        labels: [
+          {
+            op: '=',
+            value: 'value',
+            label: 'label',
+          },
+        ],
+        operations: [{ id: LokiOperationId.Logfmt, params: [true, true, 'label1', 'label2', 'label3="label4"'] }],
+      })
+    );
+  });
 });
 
 function noErrors(query: LokiVisualQuery) {
