@@ -1,5 +1,7 @@
 import { SQLOptions, SQLQuery } from 'app/features/plugins/sql/types';
 
-export interface MySQLOptions extends SQLOptions {}
+export interface MySQLOptions extends SQLOptions {
+  allowCleartextPasswords?: boolean;
+}
 
 export interface MySQLQuery extends SQLQuery {}
