@@ -1,5 +1,6 @@
 import { HistoryItem } from '@grafana/data';
 
+import { PrometheusDatasource } from '../../datasource';
 import type PromQlLanguageProvider from '../../language_provider';
 import { PromQuery } from '../../types';
 
@@ -16,4 +17,5 @@ export type Props = {
   onBlur: (value: string) => void;
   // onChange will never initiate a query, it just denotes that a query value has been changed
   onChange: (value: string) => void;
+  datasource: PrometheusDatasource;
 };
