@@ -12,12 +12,10 @@ import { ConfigSubSection } from '@grafana/experimental';
 import { getBackendSrv } from '@grafana/runtime/src';
 import { InlineField, Input, Select, Switch, useTheme2 } from '@grafana/ui';
 
-import config from '../../../../core/config';
 import { useUpdateDatasource } from '../../../../features/datasources/state';
-import { PromApplication, PromBuildInfoResponse } from '../../../../types/unified-alerting-dto';
 import { QueryEditorMode } from '../querybuilder/shared/types';
 import { defaultPrometheusQueryOverlapWindow } from '../querycache/QueryCache';
-import { PrometheusCacheLevel, PromOptions } from '../types';
+import { PromApplication, PromBuildInfoResponse, PrometheusCacheLevel, PromOptions } from '../types';
 
 import { docsTip, overhaulStyles, PROM_CONFIG_LABEL_WIDTH, validateInput } from './ConfigEditor';
 import { ExemplarsSettings } from './ExemplarsSettings';
@@ -198,7 +196,12 @@ export const PromSettings = (props: Props) => {
                     spellCheck={false}
                     placeholder="15s"
                     onChange={onChangeHandler('timeInterval', options, onOptionsChange)}
-                    onBlur={(e) => updateValidDuration({ ...validDuration, timeInterval: e.currentTarget.value })}
+                    onBlur={(e) =>
+                      updateValidDuration({
+                        ...validDuration,
+                        timeInterval: e.currentTarget.value,
+                      })
+                    }
                   />
                   {validateInput(validDuration.timeInterval, DURATION_REGEX, durationError)}
                 </>
@@ -222,7 +225,12 @@ export const PromSettings = (props: Props) => {
                     onChange={onChangeHandler('queryTimeout', options, onOptionsChange)}
                     spellCheck={false}
                     placeholder="60s"
-                    onBlur={(e) => updateValidDuration({ ...validDuration, queryTimeout: e.currentTarget.value })}
+                    onBlur={(e) =>
+                      updateValidDuration({
+                        ...validDuration,
+                        queryTimeout: e.currentTarget.value,
+                      })
+                    }
                   />
                   {validateInput(validDuration.queryTimeout, DURATION_REGEX, durationError)}
                 </>
@@ -301,7 +309,7 @@ export const PromSettings = (props: Props) => {
                   <>
                     Set this to the type of your prometheus database, e.g. Prometheus, Cortex, Mimir or Thanos. Changing
                     this field will save your current settings, and attempt to detect the version. Certain types of
-                    Prometheus support or do not support various APIs. For example, some types support regex matching
+                    Prometheus supports or does not support various APIs. For example, some types support regex matching
                     for label queries to improve performance. Some types have an API for metadata. If you set this
                     incorrectly you may experience odd behavior when querying metrics and labels. Please check your
                     Prometheus documentation to ensure you enter the correct type. {docsTip()}
@@ -362,33 +370,32 @@ export const PromSettings = (props: Props) => {
               </div>
             )}
           </div>
-          {config.featureToggles.prometheusResourceBrowserCache && (
-            <div className="gf-form-inline">
-              <div className="gf-form max-width-30">
-                <InlineField
-                  label="Cache level"
-                  labelWidth={PROM_CONFIG_LABEL_WIDTH}
-                  tooltip={
-                    <>
-                      Sets the browser caching level for editor queries. Higher cache settings are recommended for high
-                      cardinality data sources.
-                    </>
+
+          <div className="gf-form-inline">
+            <div className="gf-form max-width-30">
+              <InlineField
+                label="Cache level"
+                labelWidth={PROM_CONFIG_LABEL_WIDTH}
+                tooltip={
+                  <>
+                    Sets the browser caching level for editor queries. Higher cache settings are recommended for high
+                    cardinality data sources.
+                  </>
+                }
+                interactive={true}
+                disabled={options.readOnly}
+              >
+                <Select
+                  width={40}
+                  onChange={onChangeHandler('cacheLevel', options, onOptionsChange)}
+                  options={cacheValueOptions}
+                  value={
+                    cacheValueOptions.find((o) => o.value === options.jsonData.cacheLevel) ?? PrometheusCacheLevel.Low
                   }
-                  interactive={true}
-                  disabled={options.readOnly}
-                >
-                  <Select
-                    width={40}
-                    onChange={onChangeHandler('cacheLevel', options, onOptionsChange)}
-                    options={cacheValueOptions}
-                    value={
-                      cacheValueOptions.find((o) => o.value === options.jsonData.cacheLevel) ?? PrometheusCacheLevel.Low
-                    }
-                  />
-                </InlineField>
-              </div>
+                />
+              </InlineField>
             </div>
-          )}
+          </div>
 
           <div className="gf-form-inline">
             <div className="gf-form max-width-30">
@@ -431,7 +438,10 @@ export const PromSettings = (props: Props) => {
                 <>
                   <Input
                     onBlur={(e) =>
-                      updateValidDuration({ ...validDuration, incrementalQueryOverlapWindow: e.currentTarget.value })
+                      updateValidDuration({
+                        ...validDuration,
+                        incrementalQueryOverlapWindow: e.currentTarget.value,
+                      })
                     }
                     className="width-20"
                     value={options.jsonData.incrementalQueryOverlapWindow ?? defaultPrometheusQueryOverlapWindow}
@@ -449,7 +459,7 @@ export const PromSettings = (props: Props) => {
               <InlineField
                 label="Disable recording rules (beta)"
                 labelWidth={PROM_CONFIG_LABEL_WIDTH}
-                tooltip={<>This feature will disable recording rules Turn this on to improve dashboard performance</>}
+                tooltip={<>This feature will disable recording rules. Turn this on to improve dashboard performance</>}
                 interactive={true}
                 className={styles.switchField}
                 disabled={options.readOnly}
@@ -539,11 +549,11 @@ export const getValueFromEventItem = (eventItem: SyntheticEvent<HTMLInputElement
     return '';
   }
 
-  if (eventItem.hasOwnProperty('currentTarget')) {
+  if ('currentTarget' in eventItem) {
     return eventItem.currentTarget.value;
   }
 
-  return (eventItem as SelectableValue<string>).value;
+  return eventItem.value;
 };
 
 const onChangeHandler =
