@@ -2,8 +2,7 @@ import { css } from '@emotion/css';
 import React, { ComponentType } from 'react';
 
 import { GrafanaTheme2, SelectableValue, toOption } from '@grafana/data';
-import { Stack } from '@grafana/experimental';
-import { AutoSizeInput, Button, Checkbox, Select, useStyles2 } from '@grafana/ui';
+import { AutoSizeInput, Button, Checkbox, Select, useStyles2, Stack } from '@grafana/ui';
 
 import { QueryBuilderOperationParamDef, QueryBuilderOperationParamEditorProps } from '../shared/types';
 
@@ -33,7 +32,7 @@ export function getOperationParamEditor(
 function SimpleInputParamEditor(props: QueryBuilderOperationParamEditorProps) {
   return (
     <AutoSizeInput
-      id={getOperationParamId(props.operationIndex, props.index)}
+      id={getOperationParamId(props.operationId, props.index)}
       defaultValue={props.value?.toString()}
       minWidth={props.paramDef.minWidth}
       placeholder={props.paramDef.placeholder}
@@ -52,8 +51,8 @@ function SimpleInputParamEditor(props: QueryBuilderOperationParamEditorProps) {
 function BoolInputParamEditor(props: QueryBuilderOperationParamEditorProps) {
   return (
     <Checkbox
-      id={getOperationParamId(props.operationIndex, props.index)}
-      value={props.value as boolean}
+      id={getOperationParamId(props.operationId, props.index)}
+      value={Boolean(props.value)}
       onChange={(evt) => props.onChange(props.index, evt.currentTarget.checked)}
     />
   );
@@ -63,16 +62,16 @@ function SelectInputParamEditor({
   paramDef,
   value,
   index,
-  operationIndex,
+  operationId,
   onChange,
 }: QueryBuilderOperationParamEditorProps) {
   const styles = useStyles2(getStyles);
-  let selectOptions = paramDef.options as Array<SelectableValue<any>>;
+  let selectOptions = paramDef.options as SelectableValue[];
 
   if (!selectOptions[0]?.label) {
     selectOptions = paramDef.options!.map((option) => ({
       label: option.toString(),
-      value: option as string,
+      value: option,
     }));
   }
 
@@ -97,9 +96,9 @@ function SelectInputParamEditor({
   }
 
   return (
-    <Stack gap={0.5} direction="row" alignItems="center" wrap={false}>
+    <Stack gap={0.5} direction="row" alignItems="center">
       <Select
-        id={getOperationParamId(operationIndex, index)}
+        id={getOperationParamId(operationId, index)}
         value={valueOption}
         options={selectOptions}
         placeholder={paramDef.placeholder}
