@@ -1,8 +1,6 @@
-import { DataSourceJsonData, QueryResultMeta, ScopedVars } from '@grafana/data';
+import { DataSourceJsonData } from '@grafana/data';
 import { DataQuery } from '@grafana/schema';
 
-import { PromApplication } from '../../../types/unified-alerting-dto';
-
 import { Prometheus as GenPromQuery } from './dataquery.gen';
 import { QueryBuilderLabelFilter, QueryEditorMode } from './querybuilder/shared/types';
 
@@ -30,11 +28,17 @@ export enum PrometheusCacheLevel {
   None = 'None',
 }
 
+export enum PromApplication {
+  Cortex = 'Cortex',
+  Mimir = 'Mimir',
+  Prometheus = 'Prometheus',
+  Thanos = 'Thanos',
+}
+
 export interface PromOptions extends DataSourceJsonData {
   timeInterval?: string;
   queryTimeout?: string;
   httpMethod?: string;
-  directUrl?: string;
   customQueryParameters?: string;
   disableMetricsLookup?: boolean;
   exemplarTraceIdDestinations?: ExemplarTraceIdDestination[];
@@ -46,6 +50,7 @@ export interface PromOptions extends DataSourceJsonData {
   incrementalQueryOverlapWindow?: string;
   disableRecordingRules?: boolean;
   sigV4Auth?: boolean;
+  oauthPassThru?: boolean;
 }
 
 export type ExemplarTraceIdDestination = {
@@ -73,56 +78,6 @@ export interface PromMetricsMetadata {
   [metric: string]: PromMetricsMetadataItem;
 }
 
-export interface PromDataSuccessResponse<T = PromData> {
-  status: 'success';
-  data: T;
-}
-
-export interface PromDataErrorResponse<T = PromData> {
-  status: 'error';
-  errorType: string;
-  error: string;
-  data: T;
-}
-
-export type PromData = PromMatrixData | PromVectorData | PromScalarData | PromExemplarData[];
-
-export interface Labels {
-  [index: string]: any;
-}
-
-export interface Exemplar {
-  labels: Labels;
-  value: number;
-  timestamp: number;
-}
-
-export interface PromExemplarData {
-  seriesLabels: PromMetric;
-  exemplars: Exemplar[];
-}
-
-export interface PromVectorData {
-  resultType: 'vector';
-  result: Array<{
-    metric: PromMetric;
-    value: PromValue;
-  }>;
-}
-
-export interface PromMatrixData {
-  resultType: 'matrix';
-  result: Array<{
-    metric: PromMetric;
-    values: PromValue[];
-  }>;
-}
-
-export interface PromScalarData {
-  resultType: 'scalar';
-  result: PromValue;
-}
-
 export type PromValue = [number, any];
 
 export interface PromMetric {
@@ -131,39 +86,20 @@ export interface PromMetric {
   [index: string]: any;
 }
 
-export function isMatrixData(result: MatrixOrVectorResult): result is PromMatrixData['result'][0] {
-  return 'values' in result;
-}
-
-export function isExemplarData(result: PromData): result is PromExemplarData[] {
-  if (result == null || !Array.isArray(result)) {
-    return false;
-  }
-  return result.length ? 'exemplars' in result[0] : false;
-}
-
-export type MatrixOrVectorResult = PromMatrixData['result'][0] | PromVectorData['result'][0];
-
-export interface TransformOptions {
-  format?: string;
-  step?: number;
-  legendFormat?: string;
-  start: number;
-  end: number;
-  query: string;
-  responseListLength: number;
-  scopedVars?: ScopedVars;
-  refId: string;
-  valueWithRefId?: boolean;
-  meta: QueryResultMeta;
-}
-
-export interface PromLabelQueryResponse {
+export interface PromBuildInfoResponse {
   data: {
-    status: string;
-    data: string[];
+    application?: string;
+    version: string;
+    revision: string;
+    features?: {
+      ruler_config_api?: 'true' | 'false';
+      alertmanager_config_api?: 'true' | 'false';
+      query_sharding?: 'true' | 'false';
+      federated_rules?: 'true' | 'false';
+    };
+    [key: string]: unknown;
   };
-  cancelled?: boolean;
+  status: 'success';
 }
 
 /**
@@ -183,6 +119,7 @@ export enum PromVariableQueryType {
   MetricNames,
   VarQueryResult,
   SeriesQuery,
+  ClassicQuery,
 }
 
 export interface PromVariableQuery extends DataQuery {
@@ -195,6 +132,7 @@ export interface PromVariableQuery extends DataQuery {
   seriesQuery?: string;
   labelFilters?: QueryBuilderLabelFilter[];
   match?: string;
+  classicQuery?: string;
 }
 
 export type StandardPromVariableQuery = {
