@@ -18,6 +18,7 @@ import { Divider } from 'app/core/components/Divider';
 import { NodeGraphSection } from 'app/core/components/NodeGraphSettings';
 import { TraceToLogsSection } from 'app/core/components/TraceToLogs/TraceToLogsSettings';
 import { TraceToMetricsSection } from 'app/core/components/TraceToMetrics/TraceToMetricsSettings';
+import { TraceToProfilesSection } from 'app/core/components/TraceToProfiles/TraceToProfilesSettings';
 import { SpanBarSection } from 'app/features/explore/TraceView/components/settings/SpanBarSettings';
 
 import { LokiSearchSettings } from './LokiSearchSettings';
@@ -39,27 +40,20 @@ export const ConfigEditor = ({ options, onOptionsChange }: Props) => {
       />
 
       <Divider />
-
-      <ConnectionSettings config={options} onChange={onOptionsChange} />
+      <ConnectionSettings config={options} onChange={onOptionsChange} urlPlaceholder="http://localhost:3200" />
 
       <Divider />
-
       <Auth
         {...convertLegacyAuthProps({
           config: options,
           onChange: onOptionsChange,
         })}
       />
-      {config.secureSocksDSProxyEnabled && (
-        <SecureSocksProxySettings options={options} onOptionsChange={onOptionsChange} />
-      )}
 
       <Divider />
-
       <TraceToLogsSection options={options} onOptionsChange={onOptionsChange} />
 
       <Divider />
-
       {config.featureToggles.traceToMetrics ? (
         <>
           <TraceToMetricsSection options={options} onOptionsChange={onOptionsChange} />
@@ -67,6 +61,13 @@ export const ConfigEditor = ({ options, onOptionsChange }: Props) => {
         </>
       ) : null}
 
+      {config.featureToggles.traceToProfiles && (
+        <>
+          <TraceToProfilesSection options={options} onOptionsChange={onOptionsChange} />
+          <Divider />
+        </>
+      )}
+
       <ConfigSection
         title="Additional settings"
         description="Additional settings are optional settings that can be configured for more control over your data source."
@@ -75,14 +76,20 @@ export const ConfigEditor = ({ options, onOptionsChange }: Props) => {
       >
         <AdvancedHttpSettings config={options} onChange={onOptionsChange} />
 
-        <Divider hideLine={true} />
+        {config.secureSocksDSProxyEnabled && (
+          <>
+            <Divider hideLine />
+            <SecureSocksProxySettings options={options} onOptionsChange={onOptionsChange} />
+          </>
+        )}
 
+        <Divider hideLine />
         <ConfigSubSection
           title="Service graph"
           description={
             <ConfigDescriptionLink
               description="Select a Prometheus data source that contains the service graph data."
-              suffix="tempo/#service-graph"
+              suffix="tempo/configure-tempo-data-source/#service-graph"
               feature="the service graph"
             />
           }
@@ -90,17 +97,16 @@ export const ConfigEditor = ({ options, onOptionsChange }: Props) => {
           <ServiceGraphSettings options={options} onOptionsChange={onOptionsChange} />
         </ConfigSubSection>
 
-        <Divider hideLine={true} />
-
+        <Divider hideLine />
         <NodeGraphSection options={options} onOptionsChange={onOptionsChange} />
-        <Divider hideLine={true} />
 
+        <Divider hideLine />
         <ConfigSubSection
           title="Tempo search"
           description={
             <ConfigDescriptionLink
               description="Modify how traces are searched."
-              suffix="tempo/#tempo-search"
+              suffix="tempo/configure-tempo-data-source/#tempo-search"
               feature="Tempo search"
             />
           }
@@ -108,14 +114,13 @@ export const ConfigEditor = ({ options, onOptionsChange }: Props) => {
           <TraceQLSearchSettings options={options} onOptionsChange={onOptionsChange} />
         </ConfigSubSection>
 
-        <Divider hideLine={true} />
-
+        <Divider hideLine />
         <ConfigSubSection
           title="Loki search"
           description={
             <ConfigDescriptionLink
               description="Select a Loki data source to search for traces. Derived fields must be configured in the Loki data source."
-              suffix="tempo/#loki-search"
+              suffix="tempo/configure-tempo-data-source/#loki-search"
               feature="Loki search"
             />
           }
@@ -123,14 +128,13 @@ export const ConfigEditor = ({ options, onOptionsChange }: Props) => {
           <LokiSearchSettings options={options} onOptionsChange={onOptionsChange} />
         </ConfigSubSection>
 
-        <Divider hideLine={true} />
-
+        <Divider hideLine />
         <ConfigSubSection
           title="TraceID query"
           description={
             <ConfigDescriptionLink
               description="Modify how TraceID queries are run."
-              suffix="tempo/#traceid-query"
+              suffix="tempo/configure-tempo-data-source/#traceid-query"
               feature="the TraceID query"
             />
           }
@@ -138,8 +142,7 @@ export const ConfigEditor = ({ options, onOptionsChange }: Props) => {
           <QuerySettings options={options} onOptionsChange={onOptionsChange} />
         </ConfigSubSection>
 
-        <Divider hideLine={true} />
-
+        <Divider hideLine />
         <SpanBarSection options={options} onOptionsChange={onOptionsChange} />
       </ConfigSection>
     </div>
