@@ -9,6 +9,8 @@ import { Scope, TempoJsonData } from '../types';
 import { CompletionProvider } from './autocomplete';
 import { intrinsics, scopes } from './traceql';
 
+const emptyPosition = {} as monacoTypes.Position;
+
 jest.mock('@grafana/runtime', () => ({
   ...jest.requireActual('@grafana/runtime'),
 }));
@@ -16,10 +18,7 @@ jest.mock('@grafana/runtime', () => ({
 describe('CompletionProvider', () => {
   it('suggests tags, intrinsics and scopes (API v1)', async () => {
     const { provider, model } = setup('{}', 1, v1Tags);
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
+    const result = await provider.provideCompletionItems(model, emptyPosition);
     expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual([
       ...scopes.map((s) => expect.objectContaining({ label: s, insertText: s })),
       ...intrinsics.map((s) => expect.objectContaining({ label: s, insertText: s })),
@@ -31,10 +30,7 @@ describe('CompletionProvider', () => {
 
   it('suggests tags, intrinsics and scopes (API v2)', async () => {
     const { provider, model } = setup('{}', 1, undefined, v2Tags);
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
+    const result = await provider.provideCompletionItems(model, emptyPosition);
     expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual([
       ...scopes.map((s) => expect.objectContaining({ label: s, insertText: s })),
       ...intrinsics.map((s) => expect.objectContaining({ label: s, insertText: s })),
@@ -45,7 +41,7 @@ describe('CompletionProvider', () => {
   });
 
   it('does not wrap the tag value in quotes if the type in the response is something other than "string"', async () => {
-    const { provider, model } = setup('{foo=}', 5, v1Tags);
+    const { provider, model } = setup('{.foo=}', 6, v1Tags);
 
     jest.spyOn(provider.languageProvider, 'getOptionsV2').mockImplementation(
       () =>
@@ -60,17 +56,14 @@ describe('CompletionProvider', () => {
         })
     );
 
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
+    const result = await provider.provideCompletionItems(model, emptyPosition);
     expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual([
       expect.objectContaining({ label: 'foobar', insertText: 'foobar' }),
     ]);
   });
 
   it('wraps the tag value in quotes if the type in the response is set to "string"', async () => {
-    const { provider, model } = setup('{foo=}', 5, v1Tags);
+    const { provider, model } = setup('{.foo=}', 6, v1Tags);
 
     jest.spyOn(provider.languageProvider, 'getOptionsV2').mockImplementation(
       () =>
@@ -85,17 +78,14 @@ describe('CompletionProvider', () => {
         })
     );
 
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
+    const result = await provider.provideCompletionItems(model, emptyPosition);
     expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual([
       expect.objectContaining({ label: 'foobar', insertText: '"foobar"' }),
     ]);
   });
 
   it('inserts the tag value without quotes if the user has entered quotes', async () => {
-    const { provider, model } = setup('{foo="}', 6, v1Tags);
+    const { provider, model } = setup('{.foo="}', 6, v1Tags);
 
     jest.spyOn(provider.languageProvider, 'getOptionsV2').mockImplementation(
       () =>
@@ -109,30 +99,21 @@ describe('CompletionProvider', () => {
         })
     );
 
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
+    const result = await provider.provideCompletionItems(model, emptyPosition);
     expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual([
       expect.objectContaining({ label: 'foobar', insertText: 'foobar' }),
     ]);
   });
 
   it('suggests nothing without tags', async () => {
-    const { provider, model } = setup('{foo="}', 7, emptyTags);
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
+    const { provider, model } = setup('{.foo="}', 8, emptyTags);
+    const result = await provider.provideCompletionItems(model, emptyPosition);
     expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual([]);
   });
 
   it('suggests tags on empty input (API v1)', async () => {
     const { provider, model } = setup('', 0, v1Tags);
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
+    const result = await provider.provideCompletionItems(model, emptyPosition);
     expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual([
       ...scopes.map((s) => expect.objectContaining({ label: s, insertText: `{ ${s}` })),
       ...intrinsics.map((s) => expect.objectContaining({ label: s, insertText: `{ ${s}` })),
@@ -144,10 +125,7 @@ describe('CompletionProvider', () => {
 
   it('suggests tags on empty input (API v2)', async () => {
     const { provider, model } = setup('', 0, undefined, v2Tags);
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
+    const result = await provider.provideCompletionItems(model, emptyPosition);
     expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual([
       ...scopes.map((s) => expect.objectContaining({ label: s, insertText: `{ ${s}` })),
       ...intrinsics.map((s) => expect.objectContaining({ label: s, insertText: `{ ${s}` })),
@@ -159,10 +137,7 @@ describe('CompletionProvider', () => {
 
   it('only suggests tags after typing the global attribute scope (API v1)', async () => {
     const { provider, model } = setup('{.}', 2, v1Tags);
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
+    const result = await provider.provideCompletionItems(model, emptyPosition);
     expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual(
       v1Tags.map((s) => expect.objectContaining({ label: s, insertText: s }))
     );
@@ -170,32 +145,15 @@ describe('CompletionProvider', () => {
 
   it('only suggests tags after typing the global attribute scope (API v2)', async () => {
     const { provider, model } = setup('{.}', 2, undefined, v2Tags);
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
+    const result = await provider.provideCompletionItems(model, emptyPosition);
     expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual(
       ['cluster', 'container', 'db'].map((s) => expect.objectContaining({ label: s, insertText: s }))
     );
   });
 
-  it('suggests operators after a space after the tag name', async () => {
-    const { provider, model } = setup('{ foo }', 6, v1Tags);
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
-    expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual(
-      CompletionProvider.operators.map((s) => expect.objectContaining({ label: s, insertText: s }))
-    );
-  });
-
   it('suggests tags after a scope (API v1)', async () => {
     const { provider, model } = setup('{ resource. }', 11, v1Tags);
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
+    const result = await provider.provideCompletionItems(model, emptyPosition);
     expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual(
       v1Tags.map((s) => expect.objectContaining({ label: s, insertText: s }))
     );
@@ -203,10 +161,7 @@ describe('CompletionProvider', () => {
 
   it('suggests correct tags after the resource scope (API v2)', async () => {
     const { provider, model } = setup('{ resource. }', 11, undefined, v2Tags);
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
+    const result = await provider.provideCompletionItems(model, emptyPosition);
     expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual(
       ['cluster', 'container'].map((s) => expect.objectContaining({ label: s, insertText: s }))
     );
@@ -214,49 +169,200 @@ describe('CompletionProvider', () => {
 
   it('suggests correct tags after the span scope (API v2)', async () => {
     const { provider, model } = setup('{ span. }', 7, undefined, v2Tags);
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
+    const result = await provider.provideCompletionItems(model, emptyPosition);
     expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual(
       ['db'].map((s) => expect.objectContaining({ label: s, insertText: s }))
     );
   });
 
   it('suggests logical operators and close bracket after the value', async () => {
-    const { provider, model } = setup('{foo=300 }', 9, v1Tags);
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
+    const { provider, model } = setup('{.foo=300 }', 10, v1Tags);
+    const result = await provider.provideCompletionItems(model, emptyPosition);
+    expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual(
+      [...CompletionProvider.logicalOps, ...CompletionProvider.arithmeticOps, ...CompletionProvider.comparisonOps].map(
+        (s) => expect.objectContaining({ label: s.label, insertText: s.insertText })
+      )
     );
+  });
+
+  it('suggests spanset combining operators after spanset selector', async () => {
+    const { provider, model } = setup('{.foo=300} ', 11);
+    const result = await provider.provideCompletionItems(model, emptyPosition);
+    expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual(
+      CompletionProvider.spansetOps.map((s) => expect.objectContaining({ label: s.label, insertText: s.insertText }))
+    );
+  });
+
+  it.each([
+    ['{.foo=300} | ', 13],
+    ['{.foo=300} && {.bar=200} | ', 27],
+    ['{.foo=300} && {.bar=300} && {.foo=300} | ', 41],
+  ])(
+    'suggests operators that go after `|` (aggregators, selectorts, ...) - %s, %i',
+    async (input: string, offset: number) => {
+      const { provider, model } = setup(input, offset, undefined, v2Tags);
+      const result = await provider.provideCompletionItems(model, emptyPosition);
+      expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual([
+        ...CompletionProvider.functions.map((s) =>
+          expect.objectContaining({ label: s.label, insertText: s.insertText, documentation: s.documentation })
+        ),
+        ...scopes.map((s) => expect.objectContaining({ label: s, insertText: s })),
+        ...intrinsics.map((s) => expect.objectContaining({ label: s, insertText: s })),
+        expect.objectContaining({ label: 'cluster', insertText: '.cluster' }),
+        expect.objectContaining({ label: 'container', insertText: '.container' }),
+        expect.objectContaining({ label: 'db', insertText: '.db' }),
+      ]);
+    }
+  );
+
+  it.each([
+    ['{.foo=300} | avg(.value) ', 25],
+    ['{.foo=300} && {.foo=300} | avg(.value) ', 39],
+  ])(
+    'suggests comparison operators after aggregator (avg, max, ...) - %s, %i',
+    async (input: string, offset: number) => {
+      const { provider, model } = setup(input, offset);
+      const result = await provider.provideCompletionItems(model, emptyPosition);
+      expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual(
+        CompletionProvider.comparisonOps.map((s) =>
+          expect.objectContaining({ label: s.label, insertText: s.insertText })
+        )
+      );
+    }
+  );
+
+  it.each([
+    ['{.foo=300} | avg(.value) = ', 27],
+    ['{.foo=300} && {.foo=300} | avg(.value) = ', 41],
+  ])('does not suggest after aggregator and comparison operator - %s, %i', async (input: string, offset: number) => {
+    const { provider, model } = setup(input, offset);
+    const result = await provider.provideCompletionItems(model, emptyPosition);
+    expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual([]);
+  });
+
+  it('suggests when `}` missing', async () => {
+    const { provider, model } = setup('{ span.http.status_code ', 24);
+    const result = await provider.provideCompletionItems(model, emptyPosition);
+    expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual(
+      [...CompletionProvider.comparisonOps, ...CompletionProvider.logicalOps].map((s) =>
+        expect.objectContaining({ label: s.label, insertText: s.insertText })
+      )
+    );
+  });
+
+  it.each([
+    ['{ .foo }', 7],
+    ['{.foo   300}', 6],
+    ['{.foo   300}', 7],
+    ['{.foo   300}', 8],
+    ['{.foo  300 && .bar = 200}', 6],
+    ['{.foo  300 && .bar = 200}', 7],
+    ['{.foo  300 && .bar  200}', 19],
+    ['{.foo  300 && .bar  200}', 20],
+    ['{ .foo = 1 && .bar }', 19],
+    ['{ .foo = 1 && .bar  }', 19],
+  ])('suggests with incomplete spanset - %s, %i', async (input: string, offset: number) => {
+    const { provider, model } = setup(input, offset);
+    const result = await provider.provideCompletionItems(model, emptyPosition);
+    expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual(
+      [...CompletionProvider.comparisonOps, ...CompletionProvider.logicalOps, ...CompletionProvider.arithmeticOps].map(
+        (s) => expect.objectContaining({ label: s.label, insertText: s.insertText })
+      )
+    );
+  });
+
+  it.each([
+    ['{ .foo }', 6],
+    ['{.foo   300}', 5],
+    ['{.foo  300 && .bar = 200}', 5],
+    ['{ .foo = 1 && .bar }', 18],
+  ])('suggests with incomplete spanset with no space before cursor - %s, %i', async (input: string, offset: number) => {
+    const { provider, model } = setup(input, offset);
+    const result = await provider.provideCompletionItems(model, emptyPosition);
+    expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual([]);
+  });
+
+  it.each([
+    ['{ span.d }', 8],
+    ['{ span.db }', 9],
+  ])('suggests to complete attribute - %s, %i', async (input: string, offset: number) => {
+    const { provider, model } = setup(input, offset, undefined, v2Tags);
+    const result = await provider.provideCompletionItems(model, emptyPosition);
     expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual([
-      ...CompletionProvider.logicalOps.map((s) => expect.objectContaining({ label: s, insertText: s })),
-      expect.objectContaining({ label: '}', insertText: '}' }),
+      expect.objectContaining({ label: 'db', insertText: 'db' }),
     ]);
   });
 
-  it('suggests tag values after a space inside a string', async () => {
-    const { provider, model } = setup('{foo="bar test " }', 15, v1Tags);
+  it.each([
+    ['{.foo=1}  {.bar=2}', 8],
+    ['{.foo=1}  {.bar=2}', 9],
+    ['{.foo=1}  {.bar=2}', 10],
+  ])(
+    'suggests spanset combining operators in an incomplete, multi-spanset query - %s, %i',
+    async (input: string, offset: number) => {
+      const { provider, model } = setup(input, offset);
+      const result = await provider.provideCompletionItems(model, emptyPosition);
+      expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual(
+        CompletionProvider.spansetOps.map((completionItem) =>
+          expect.objectContaining({
+            detail: completionItem.detail,
+            documentation: completionItem.documentation,
+            insertText: completionItem.insertText,
+            label: completionItem.label,
+          })
+        )
+      );
+    }
+  );
 
-    jest.spyOn(provider.languageProvider, 'getOptionsV2').mockImplementation(
-      () =>
-        new Promise((resolve) => {
-          resolve([
-            {
-              value: 'foobar',
-              label: 'foobar',
-            },
-          ]);
-        })
+  it.each([
+    // After spanset
+    ['{ span.http.status_code = 200 &&  }', 33],
+    ['{ span.http.status_code = 200 ||  }', 33],
+    ['{ span.http.status_code = 200 &&   }', 34],
+    ['{ span.http.status_code = 200 ||   }', 34],
+    ['{ span.http.status_code = 200 &&   }', 35],
+    ['{ span.http.status_code = 200 ||   }', 35],
+    ['{ .foo = 200 } &&  ', 18],
+    ['{ .foo = 200 } &&  ', 19],
+    ['{ .foo = 200 } || ', 18],
+    ['{ .foo = 200 } >> ', 18],
+    // Between spansets
+    ['{ .foo = 1 } &&  { .bar = 2 }', 16],
+    // Inside `()`
+    ['{.foo=1} | avg()', 15],
+    ['{.foo=1} | avg() < 1s', 15],
+    ['{.foo=1} | max() = 3', 15],
+    ['{.foo=1} | by()', 14],
+    ['{.foo=1} | select()', 18],
+  ])('suggests attributes - %s, %i', async (input: string, offset: number) => {
+    const { provider, model } = setup(input, offset);
+    const result = await provider.provideCompletionItems(model, emptyPosition);
+    expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual(
+      [...scopes, ...intrinsics].map((s) => expect.objectContaining({ label: s }))
     );
-    const result = await provider.provideCompletionItems(
-      model as unknown as monacoTypes.editor.ITextModel,
-      {} as monacoTypes.Position
-    );
-    expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual([
-      expect.objectContaining({ label: 'foobar', insertText: 'foobar' }),
-    ]);
   });
+
+  it.each([
+    ['{span.ht', 8],
+    ['{span.http', 10],
+    ['{span.http.', 11],
+    ['{span.http.status', 17],
+  ])(
+    'suggests attributes when containing trigger characters and missing `}`- %s, %i',
+    async (input: string, offset: number) => {
+      const { provider, model } = setup(input, offset, undefined, [
+        {
+          name: 'span',
+          tags: ['http.status_code'],
+        },
+      ]);
+      const result = await provider.provideCompletionItems(model, emptyPosition);
+      expect((result! as monacoTypes.languages.CompletionList).suggestions).toEqual([
+        expect.objectContaining({ label: 'http.status_code', insertText: 'http.status_code' }),
+      ]);
+    }
+  );
 });
 
 function setup(value: string, offset: number, tagsV1?: string[], tagsV2?: Scope[]) {
@@ -288,7 +394,7 @@ function setup(value: string, offset: number, tagsV1?: string[], tagsV2?: Scope[
     },
   } as any;
 
-  return { provider, model };
+  return { provider, model } as unknown as { provider: CompletionProvider; model: monacoTypes.editor.ITextModel };
 }
 
 function makeModel(value: string, offset: number) {
