@@ -2,9 +2,9 @@ import { useDialog } from '@react-aria/dialog';
 import { useOverlay } from '@react-aria/overlays';
 import React, { createRef } from 'react';
 
-import { VizTooltipContainer } from '@grafana/ui';
+import { Portal, VizTooltipContainer } from '@grafana/ui';
+import { ComplexDataHoverView } from 'app/features/visualization/data-hover/ComplexDataHoverView';
 
-import { ComplexDataHoverView } from './components/ComplexDataHoverView';
 import { GeomapHoverPayload } from './event';
 
 interface Props {
@@ -21,11 +21,13 @@ export const GeomapTooltip = ({ ttip, onClose, isOpen }: Props) => {
   return (
     <>
       {ttip && ttip.layers && (
-        <VizTooltipContainer position={{ x: ttip.pageX, y: ttip.pageY }} offset={{ x: 10, y: 10 }} allowPointerEvents>
-          <section ref={ref} {...overlayProps} {...dialogProps}>
-            <ComplexDataHoverView layers={ttip.layers} isOpen={isOpen} onClose={onClose} />
-          </section>
-        </VizTooltipContainer>
+        <Portal>
+          <VizTooltipContainer position={{ x: ttip.pageX, y: ttip.pageY }} offset={{ x: 10, y: 10 }} allowPointerEvents>
+            <section ref={ref} {...overlayProps} {...dialogProps}>
+              <ComplexDataHoverView layers={ttip.layers} isOpen={isOpen} onClose={onClose} />
+            </section>
+          </VizTooltipContainer>
+        </Portal>
       )}
     </>
   );
