@@ -1,17 +1,17 @@
 import { FieldColorModeId, FieldConfigProperty, FieldMatcherID, PanelModel } from '@grafana/data';
 import { LegendDisplayMode } from '@grafana/schema';
 
-import { PanelOptions, PieChartLabels, PieChartLegendValues, PieChartType } from './models.gen';
+import { Options, PieChartLabels, PieChartLegendValues, PieChartType } from './panelcfg.gen';
 
 export const PieChartPanelChangedHandler = (
-  panel: PanelModel<Partial<PanelOptions>> | any,
+  panel: PanelModel<Partial<Options>> | any,
   prevPluginId: string,
   prevOptions: any
 ) => {
   if (prevPluginId === 'grafana-piechart-panel' && prevOptions.angular) {
     const angular = prevOptions.angular;
     const overrides = [];
-    let options: PanelOptions = panel.options;
+    let options: Options = panel.options;
 
     // Migrate color overrides for series
     if (angular.aliasColors) {
@@ -102,10 +102,6 @@ export const PieChartPanelChangedHandler = (
       if (angular.legend.percentage) {
         options.legend.values.push(PieChartLegendValues.Percent);
       }
-      if (!angular.legend.percentage && !angular.legend.values) {
-        // If you deselect both value and percentage in the old pie chart plugin, the legend is hidden.
-        options.legend.showLegend = false;
-      }
     }
 
     // Set up labels when the old piechart is using 'on graph', for the legend option.
